@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: AboutDialog.h,v 1.9 2004/01/26 11:17:48 comix Exp $
+ * $Id: AboutDialog.h,v 1.10 2004/03/22 12:49:26 comix Exp $
  *
  */
 
@@ -41,8 +41,7 @@ class AboutDialog : public AboutDialog_UI {
 	Q_OBJECT
 	private:
 		void okBtnClicked();
-		/* what's this??? */
-		void languageChange();
+	
 	public:
 		/** Constructor */
 		AboutDialog(QWidget* parent);
