@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: ExportSongDialog.h,v 1.4 2004/01/26 11:17:48 comix Exp $
+ * $Id: ExportSongDialog.h,v 1.6 2004/05/03 14:02:19 comix Exp $
  *
  */
 
@@ -26,13 +26,6 @@
 #ifndef EXPORT_SONG_DIALOG_H
 #define EXPORT_SONG_DIALOG_H
 
-#include <iostream>
-using std::cout;
-using std::cerr;
-using std::endl;
-
-#include <string>
-using std::string;
 
 #include "qfiledialog.h"
 #include "qpixmap.h"
@@ -41,18 +34,15 @@ using std::string;
 #include "qpushbutton.h"
 
 
-
 #include "ExportSongDialog_UI.h"
 
 
-/**
- * Dialog for exporting song
- */
-class ExportSongDialog : public ExportSongDialog_UI {
+///
+/// Dialog for exporting song
+///
+class ExportSongDialog : public ExportSongDialog_UI 
+{
 	Q_OBJECT
-	private:
-		/** ??? */
-		void languageChange();
 
 	public:
 		ExportSongDialog(QWidget* parent);
