@@ -18,27 +18,36 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: MainForm.cpp,v 1.77 2004/03/12 13:02:19 comix Exp $
+ * $Id: MainForm.cpp,v 1.94 2004/09/06 09:41:48 comix Exp $
  *
  */
 
 
 #include "MainForm.h"
-#include "qaccel.h"
-
 #include "AboutDialog.h"
 #include "PlayerControl.h"
 #include "ExportSongDialog.h"
+#include "Mixer.h"
+#include "HelpBrowser.h"
+#include "PatternEditorPanel.h"
+#include "SongEditor.h"
+#include "DrumkitManager.h"
+#include "AudioEngineInfoForm.h"
+#include "LadspaFXProperties.h"
+#include "InstrumentPropertiesDialog.h"
 
+#include "../lib/Hydrogen.h"
+#include "../lib/smf/SMF.h"
+
+#include "qaccel.h"
+#include "qinputdialog.h"
+#include "qmessagebox.h"
 #include <sys/time.h>
 
-//----------------------------------------------------------------------------
-/**
- * Constructor
- */
+
+
 MainForm::MainForm(QApplication *app, string songFilename ) : QMainWindow( 0, 0, 0 ), Object( "MainForm   " )
 {
-//	cout << "MainForm init" << endl;
 	setIcon( QPixmap( QString(IMG_PATH) + QString( "/img/icon32.png") ) );
 
 	m_pQApp = app;
@@ -58,7 +67,7 @@ MainForm::MainForm(QApplication *app, string songFilename ) : QMainWindow( 0, 0,
 		}
 	}
 	else {
-		PreferencesMng *pref = PreferencesMng::getInstance();
+		Preferences *pref = Preferences::getInstance();
 		bool restoreLastSong = pref->isRestoreLastSongEnabled();
 		string filename = pref->getLastSongFilename();
 		if ( restoreLastSong && (filename != "" )) {
@@ -79,13 +88,6 @@ MainForm::MainForm(QApplication *app, string songFilename ) : QMainWindow( 0, 0,
 
 	createMenuBar();
 
-	// create toolbar with player control
-	QToolBar * fileTools = new QToolBar( this, "file operations" );
-        fileTools->setMovingEnabled( false );
-	fileTools->setLabel( "Hydrogen control panel" );
-	PlayerControl *playerControl;
-	playerControl = new PlayerControl( fileTools );
-
 	h2app->setStatusBarMessage( trUtf8("Hydrogen Ready."), 10000 );
 
 	initKeyInstMap();
@@ -93,9 +95,10 @@ MainForm::MainForm(QApplication *app, string songFilename ) : QMainWindow( 0, 0,
 	// we need to do all this to support the keyboard playing
 	// for all the window modes
 	h2app->getMixer()->installEventFilter (this);
-	h2app->getPatternEditor()->installEventFilter (this);
+	h2app->getPatternEditorPanel()->installEventFilter (this);
 	h2app->getSongEditorPanel()->installEventFilter (this);
-	playerControl->installEventFilter(this);
+	h2app->getPlayerControl()->installEventFilter(this);
+	h2app->getInstrumentProperties()->installEventFilter(this);
 
 	QAccel *a = new QAccel( this );
         a->connectItem( a->insertItem(Key_Space), this, SLOT( onPlayStopAccelEvent() ) );
@@ -109,17 +112,10 @@ MainForm::MainForm(QApplication *app, string songFilename ) : QMainWindow( 0, 0,
 	a->connectItem( a->insertItem(Key_Backslash), this, SLOT( onTapTempoAccelEvent() ) );
 
 	installEventFilter( this );
-
 }
 
 
 
-
-
-//----------------------------------------------------------------------------
-/**
- * Destructor
- */
 MainForm::~MainForm() {
 	if ( ((Hydrogen::getInstance())->getState() == PLAYING) ) {
 		(Hydrogen::getInstance())->stop();
@@ -135,123 +131,165 @@ MainForm::~MainForm() {
 
 
 
-
-//----------------------------------------------------------------------------
-/**
- * Create the menubar
- */
+///
+/// Create the menubar
+///
 void MainForm::createMenuBar() {
-	// actions
-	menuItem_file_open = new QAction( this, "menuItem_file_open" );
-	menuItem_file_open->setText( trUtf8( "Open" ) );
-
-	menuItem_file_openDemo = new QAction( this, "menuItem_file_openDemo" );
-	menuItem_file_openDemo->setText( trUtf8( "Open Demo" ) );
-
-	menuItem_file_quit = new QAction( this, "menuItem_file_quit" );
-	menuItem_file_quit->setText( trUtf8( "Quit" ) );
-	menuItem_file_new = new QAction( this, "menuItem_file_new" );
-	menuItem_file_new->setText( trUtf8( "New" ) );
-	menuItem_file_save = new QAction( this, "menuItem_file_save" );
-	menuItem_file_save->setText( trUtf8( "Save" ) );
-	menuItem_file_save_as = new QAction( this, "menuItem_file_save_as" );
-	menuItem_file_save_as->setText( trUtf8( "Save as..." ) );
-	menuItem_file_export = new QAction( this, "menuItem_file_export" );
-	menuItem_file_export->setText( trUtf8( "Export" ) );
-	menuItem_file_preferences = new QAction( this, "menuItem_file_preferences" );
-	menuItem_file_preferences->setText( trUtf8( "Preferences" ) );
-
-	menuItem_window_showMixer = new QAction( this, "menuItem_window_showMixer" );
-	menuItem_window_showMixer->setText( trUtf8( "Show mixer" ) );
-
-	menuItem_window_showAudioEngineInfo = new QAction( this, "menuItem_window_showAudioEngineInfo" );
-	menuItem_window_showAudioEngineInfo->setText( trUtf8( "Show audio engine info" ) );
-
-	menuItem_window_showSongEditor = new QAction( this, "menuItem_window_showSongEditor" );
-	menuItem_window_showSongEditor->setText( trUtf8( "Show song editor" ) );
-
-	menuItem_window_showDrumkitManager = new QAction( this, "menuItem_window_showDrumkitManager" );
-	menuItem_window_showDrumkitManager->setText( trUtf8( "Show drumkit manager" ) );
-
-	menuItem_help_manual = new QAction( this, "menuItem_help_manual" );
-	menuItem_help_manual->setText( trUtf8( "User manual" ) );
-
-	menuItem_help_about = new QAction( this, "menuItem_help_about" );
-	menuItem_help_about->setText( trUtf8( "About" ) );
-
-	m_pRecentFilesPopupMenu = new QPopupMenu( this );
-
 	// menubar
 	m_pMenubar = new QMenuBar( this, "m_pMenubar" );
 
+	// FILE menu
 	m_pFilePopupMenu = new QPopupMenu( this );			// FILE MENU
-	menuItem_file_new->addTo( m_pFilePopupMenu );		// FILE->NEW
-	m_pFilePopupMenu->insertSeparator();				// -----
-	menuItem_file_open->addTo( m_pFilePopupMenu );		// FILE->OPEN
-	menuItem_file_openDemo->addTo( m_pFilePopupMenu );	// FILE->OPEN_DEMO
-	m_pFilePopupMenu->insertItem( trUtf8( "Open recent" ), m_pRecentFilesPopupMenu );	// FILE->OPEN_RECENT
-	m_pFilePopupMenu->insertSeparator();				// -----
-	menuItem_file_save->addTo( m_pFilePopupMenu );		// FILE->SAVE_AS
-	menuItem_file_save_as->addTo( m_pFilePopupMenu );		// FILE->SAVE_AS
-	menuItem_file_export->addTo( m_pFilePopupMenu );		// FILE->EXPORT
-	m_pFilePopupMenu->insertSeparator();				// -----
-	menuItem_file_preferences->addTo( m_pFilePopupMenu );	// FILE->PREFERENCES
-	m_pFilePopupMenu->insertSeparator();				// -----
-	menuItem_file_quit->addTo( m_pFilePopupMenu);		// FILE->QUIT
-
-	updateRecentUsedSongList();
-
 	m_pMenubar->insertItem( trUtf8("&File"), m_pFilePopupMenu );
 
+	menuItem_file_new = new QAction( this, "menuItem_file_new" );
+	menuItem_file_new->setMenuText( trUtf8( "&New" ) );
+	menuItem_file_new->addTo( m_pFilePopupMenu );		// FILE->NEW
+	connect( menuItem_file_new, SIGNAL( activated() ), this, SLOT( action_file_new() ) );
+
+	m_pFilePopupMenu->insertSeparator();				// -----
+
+	menuItem_file_open = new QAction( this, "menuItem_file_open" );
+	menuItem_file_open->setMenuText( trUtf8( "&Open" ) );
+	menuItem_file_open->addTo( m_pFilePopupMenu );		// FILE->OPEN
+	connect( menuItem_file_open, SIGNAL( activated() ), this, SLOT( action_file_open() ) );
+
+	menuItem_file_openDemo = new QAction( this, "menuItem_file_openDemo" );
+	menuItem_file_openDemo->setMenuText( trUtf8( "Open &Demo" ) );
+	menuItem_file_openDemo->addTo( m_pFilePopupMenu );	// FILE->OPEN_DEMO
+	connect( menuItem_file_openDemo, SIGNAL( activated() ), this, SLOT( action_file_openDemo() ) );
+
+	m_pRecentFilesPopupMenu = new QPopupMenu( this );
+	m_pFilePopupMenu->insertItem( trUtf8( "Open &recent" ), m_pRecentFilesPopupMenu );	// FILE->OPEN_RECENT
+
+	m_pFilePopupMenu->insertSeparator();				// -----
+
+	menuItem_file_save = new QAction( this, "menuItem_file_save" );
+	menuItem_file_save->setMenuText( trUtf8( "&Save" ) );
+	menuItem_file_save->addTo( m_pFilePopupMenu );		// FILE->SAVE_AS
+	connect( menuItem_file_save, SIGNAL( activated() ), this, SLOT( action_file_save() ) );
+
+	menuItem_file_save_as = new QAction( this, "menuItem_file_save_as" );
+	menuItem_file_save_as->setMenuText( trUtf8( "Save &as..." ) );
+	menuItem_file_save_as->addTo( m_pFilePopupMenu );		// FILE->SAVE_AS
+	connect( menuItem_file_save_as, SIGNAL( activated() ), this, SLOT( action_file_save_as() ) );
+
+	menuItem_file_export = new QAction( this, "menuItem_file_export" );
+	menuItem_file_export->setMenuText( trUtf8( "&Export" ) );
+	menuItem_file_export->addTo( m_pFilePopupMenu );		// FILE->EXPORT
+	connect( menuItem_file_export, SIGNAL( activated() ), this, SLOT( action_file_export() ) );
+
+
+	menuItem_file_export_midi = new QAction( this, "menuItem_file_export_midi" );
+	menuItem_file_export_midi->setMenuText( trUtf8( "Export &MIDI file" ) );
+	menuItem_file_export_midi->addTo( m_pFilePopupMenu );		// FILE->EXPORT_MIDI
+	connect( menuItem_file_export_midi, SIGNAL( activated() ), this, SLOT( action_file_export_midi() ) );
+
+	m_pFilePopupMenu->insertSeparator();				// -----
+
+	menuItem_file_preferences = new QAction( this, "menuItem_file_preferences" );
+	menuItem_file_preferences->setMenuText( trUtf8( "&Preferences" ) );
+	menuItem_file_preferences->addTo( m_pFilePopupMenu );	// FILE->PREFERENCES
+	connect( menuItem_file_preferences, SIGNAL( activated() ), this, SLOT( action_file_preferences() ) );
+
+	m_pFilePopupMenu->insertSeparator();				// -----
+
+	menuItem_file_quit = new QAction( this, "menuItem_file_quit" );
+	menuItem_file_quit->setMenuText( trUtf8( "&Quit" ) );
+	menuItem_file_quit->addTo( m_pFilePopupMenu);		// FILE->QUIT
+	connect( menuItem_file_quit, SIGNAL( activated() ), this, SLOT( action_file_exit() ) );
+
+	updateRecentUsedSongList();
+	//~ FILE menu
+
+
+	// WINDOW menu
 	m_pWindowPopupMenu = new QPopupMenu( this );
 	m_pMenubar->insertItem( trUtf8( "&Window" ), m_pWindowPopupMenu );
+
+	menuItem_window_showMixer = new QAction( this, "menuItem_window_showMixer" );
+	menuItem_window_showMixer->setMenuText( trUtf8( "Show &mixer" ) );
 	menuItem_window_showMixer->addTo( m_pWindowPopupMenu );
-	if ( ( PreferencesMng::getInstance() )->getInterfaceMode() == "Child frame" ) {	// show only with child frame interface
+	connect( menuItem_window_showMixer, SIGNAL( activated() ), this, SLOT( action_window_showMixer() ) );
+
+
+	menuItem_window_showSongEditor = new QAction( this, "menuItem_window_showSongEditor" );
+	menuItem_window_showSongEditor->setMenuText( trUtf8( "Show &song editor" ) );
+	connect( menuItem_window_showSongEditor, SIGNAL( activated() ), this, SLOT( action_window_showSongEditor() ) );
+	if ( ( Preferences::getInstance() )->getInterfaceMode() != Preferences::TOP_LEVEL ) {	// show only with child frame interface
 		menuItem_window_showSongEditor->addTo( m_pWindowPopupMenu );
 	}
-	menuItem_window_showDrumkitManager->addTo( m_pWindowPopupMenu );
-	m_pWindowPopupMenu->insertSeparator();
-	menuItem_window_showAudioEngineInfo->addTo( m_pWindowPopupMenu );
 
+	menuItem_window_showDrumkitManager = new QAction( this, "menuItem_window_showDrumkitManager" );
+	menuItem_window_showDrumkitManager->setMenuText( trUtf8( "Show &drumkit manager" ) );
+	menuItem_window_showDrumkitManager->addTo( m_pWindowPopupMenu );
+	connect( menuItem_window_showDrumkitManager, SIGNAL( activated() ), this, SLOT( action_window_showDrumkitManager() ) );
+
+	if ( ( Preferences::getInstance() )->getInterfaceMode() != Preferences::SINGLE_PANED ) {
+		menuItem_window_showInstrumentEditor = new QAction( this, "menuItem_showInstrumentEditor" );
+		menuItem_window_showInstrumentEditor->setMenuText( trUtf8( "Show &instrument editor" ) );
+		menuItem_window_showInstrumentEditor->addTo( m_pWindowPopupMenu );
+		connect( menuItem_window_showInstrumentEditor, SIGNAL( activated() ), this, SLOT( action_window_showInstrumentEditor() ) );
+	}
+	m_pWindowPopupMenu->insertSeparator();
+
+	menuItem_window_showAudioEngineInfo = new QAction( this, "menuItem_window_showAudioEngineInfo" );
+	menuItem_window_showAudioEngineInfo->setMenuText( trUtf8( "Show &audio engine info" ) );
+	menuItem_window_showAudioEngineInfo->addTo( m_pWindowPopupMenu );
+	connect( menuItem_window_showAudioEngineInfo, SIGNAL( activated() ), this, SLOT( action_window_showAudioEngineInfo() ) );
+
+	//~ WINDOW menu
+
+
+#ifdef DEBUG_MESSAGES
+	// DEBUG menu
+	m_pDebugPopupMenu = new QPopupMenu( this );
+	m_pMenubar->insertItem( trUtf8("&Debug"), m_pDebugPopupMenu );
+
+
+	menuItem_debug_debugCommand = new QAction( this, "menuItem_debug_debugCommand" );
+	menuItem_debug_debugCommand->setText( "debug action" );
+	menuItem_debug_debugCommand->addTo( m_pDebugPopupMenu );
+	connect( menuItem_debug_debugCommand, SIGNAL( activated() ), this, SLOT( action_debug_debugCommand() ) );
+
+	menuItem_debug_printObjects = new QAction( this, "menuItem_debug_printObjects" );
+	menuItem_debug_printObjects->setText( "Print Objects" );
+	menuItem_debug_printObjects->addTo( m_pDebugPopupMenu );
+	connect( menuItem_debug_printObjects, SIGNAL( activated() ), this, SLOT( action_debug_printObjects() ) );
+	//~ DEBUG menu
+#endif
+
+
+	// HELP menu
 	m_pHelpPopupMenu = new QPopupMenu( this );
-	menuItem_help_manual->addTo( m_pHelpPopupMenu );
-	m_pHelpPopupMenu->insertSeparator();
-	menuItem_help_about->addTo( m_pHelpPopupMenu );
 	m_pMenubar->insertItem( trUtf8( "?" ), m_pHelpPopupMenu );
 
-	// signals and slots connections
-	connect( menuItem_file_open, SIGNAL( activated() ), this, SLOT( action_file_open() ) );
-	connect( menuItem_file_openDemo, SIGNAL( activated() ), this, SLOT( action_file_openDemo() ) );
-	connect( menuItem_file_save, SIGNAL( activated() ), this, SLOT( action_file_save() ) );
-	connect( menuItem_file_save_as, SIGNAL( activated() ), this, SLOT( action_file_save_as() ) );
-	connect( menuItem_file_new, SIGNAL( activated() ), this, SLOT( action_file_new() ) );
-	connect( menuItem_file_quit, SIGNAL( activated() ), this, SLOT( action_file_exit() ) );
-	connect( menuItem_file_preferences, SIGNAL( activated() ), this, SLOT( action_file_preferences() ) );
-	connect( menuItem_file_export, SIGNAL( activated() ), this, SLOT( action_file_export() ) );
-	connect( menuItem_window_showMixer, SIGNAL( activated() ), this, SLOT( action_window_showMixer() ) );
-	connect( menuItem_window_showAudioEngineInfo, SIGNAL( activated() ), this, SLOT( action_window_showAudioEngineInfo() ) );
-	connect( menuItem_window_showSongEditor, SIGNAL( activated() ), this, SLOT( action_window_showSongEditor() ) );
-	connect( menuItem_window_showDrumkitManager, SIGNAL( activated() ), this, SLOT( action_window_showDrumkitManager() ) );
+	menuItem_help_manual = new QAction( this, "menuItem_help_manual" );
+	menuItem_help_manual->setMenuText( trUtf8( "&User manual" ) );
+	menuItem_help_manual->addTo( m_pHelpPopupMenu );
 	connect( menuItem_help_manual, SIGNAL( activated() ), this, SLOT( action_help_manual() ) );
+
+	m_pHelpPopupMenu->insertSeparator();
+
+	menuItem_help_about = new QAction( this, "menuItem_help_about" );
+	menuItem_help_about->setMenuText( trUtf8( "&About" ) );
+	menuItem_help_about->addTo( m_pHelpPopupMenu );
 	connect( menuItem_help_about, SIGNAL( activated() ), this, SLOT( action_help_about() ) );
+	//~ HELP menu
+
+
 
 }
 
 
 
-
-
-//----------------------------------------------------------------------------
-/**
- *
- */
 void MainForm::action_file_exit() {
 	if ( (h2app->getSong())->isModified() ) {
 		switch(
 				QMessageBox::information( this, "Hydrogen",
 						trUtf8("\nThe song has unsaved changes\n"
 						"Do you want to save the changes before exiting?\n"),
-						trUtf8("&Save"), trUtf8("&Discard"), trUtf8("Cancel"),
+						trUtf8("&Save"), trUtf8("&Discard"), trUtf8("&Cancel"),
 						0,      // Enter == button 0
 						2 ) ) { // Escape == button 2
 			case 0:
@@ -280,12 +318,6 @@ void MainForm::action_file_exit() {
 
 
 
-
-
-//----------------------------------------------------------------------------
-/**
- *
- */
 void MainForm::action_file_new() {
 	if ( ((Hydrogen::getInstance())->getState() == PLAYING) ) {
 		(Hydrogen::getInstance())->stop();
@@ -296,7 +328,7 @@ void MainForm::action_file_new() {
 				QMessageBox::information( this, "Hydrogen",
 						trUtf8("\nThe document contains unsaved changes\n"
 						"Do you want to save the changes before exiting?\n"),
-						trUtf8("&Save"), trUtf8("&Discard"), trUtf8("Cancel"),
+						trUtf8("&Save"), trUtf8("&Discard"), trUtf8("&Cancel"),
 						0,      // Enter == button 0
 						2 ) ) { // Escape == button 2
 			case 0: // Save clicked or Alt+S pressed or Enter pressed.
@@ -326,12 +358,8 @@ void MainForm::action_file_new() {
 
 
 
-
-//----------------------------------------------------------------------------
-/**
- *
- */
-void MainForm::action_file_save_as() {
+void MainForm::action_file_save_as()
+{
 	if ( ((Hydrogen::getInstance())->getState() == PLAYING) ) {
 		(Hydrogen::getInstance())->stop();
 	}
@@ -350,7 +378,8 @@ void MainForm::action_file_save_as() {
 	if (lastFilename == "") {
 		defaultFilename = (Hydrogen::getInstance()->getSong()->getName()).c_str();
 		defaultFilename += ".h2song";
-	} else {
+	}
+	else {
 		defaultFilename = lastFilename;
 	}
 
@@ -375,10 +404,7 @@ void MainForm::action_file_save_as() {
 }
 
 
-//----------------------------------------------------------------------------
-/**
- *
- */
+
 void MainForm::action_file_save()
 {
 	if ( ((Hydrogen::getInstance())->getState() == PLAYING) ) {
@@ -395,25 +421,20 @@ void MainForm::action_file_save()
 
 	LocalFileMng mng;
 	song->save( filename.latin1() );
-	( PreferencesMng::getInstance() )->setLastSongFilename( song->getFilename() );
+	( Preferences::getInstance() )->setLastSongFilename( song->getFilename() );
 
 	// add the new loaded song in the "last used song" vector
-	PreferencesMng *pPref = PreferencesMng::getInstance();
+	Preferences *pPref = Preferences::getInstance();
 	vector<string> recentFiles = pPref->getRecentFiles();
 	recentFiles.insert( recentFiles.begin(), filename.latin1() );
 	pPref->setRecentFiles( recentFiles );
 
 	updateRecentUsedSongList();
-
 }
 
 
 
 
-//----------------------------------------------------------------------------
-/**
- *
- */
 void MainForm::action_help_about() {
 	QWidget *parent = this;
 	if (workspace) {
@@ -428,12 +449,6 @@ void MainForm::action_help_about() {
 
 
 
-
-
-//----------------------------------------------------------------------------
-/**
- *
- */
 void MainForm::action_help_manual() {
 	QWidget *parent = this;
 	if (workspace) {
@@ -447,11 +462,6 @@ void MainForm::action_help_manual() {
 
 
 
-
-//----------------------------------------------------------------------------
-/**
- *
- */
 void MainForm::action_file_open() {
 	if ( ((Hydrogen::getInstance())->getState() == PLAYING) ) {
 		(Hydrogen::getInstance())->stop();
@@ -462,7 +472,7 @@ void MainForm::action_file_open() {
 			QMessageBox::information( this, "Hydrogen",
 					trUtf8("\nThe document contains unsaved changes\n"
 					"Do you want to save the changes before exiting?\n"),
-					trUtf8("&Save"), trUtf8("&Discard"), trUtf8("Cancel"),
+					trUtf8("&Save"), trUtf8("&Discard"), trUtf8("&Cancel"),
 					0,      // Enter == button 0
 					2 ) ) { // Escape == button 2
 			case 0: // Save clicked or Alt+S pressed or Enter pressed.
@@ -494,7 +504,7 @@ void MainForm::action_file_open() {
 	fd->setCaption( trUtf8( "Open song" ) );
 	fd->setIcon( QPixmap( QString(IMG_PATH) + QString( "/img/icon32.png") ) );
 
-	// FIXME: impostare il preview
+	/// \todo impostare il preview
 	/*
 	fd->setContentsPreviewEnabled( TRUE );
 	fd->setContentsPreview( "uno", "due" );
@@ -516,11 +526,7 @@ void MainForm::action_file_open() {
 
 
 
-// FIXME: parametrizzare il metodo action_file_open ed eliminare il seguente...
-//----------------------------------------------------------------------------
-/**
- *
- */
+/// \todo parametrizzare il metodo action_file_open ed eliminare il seguente...
 void MainForm::action_file_openDemo() {
 	if ( ((Hydrogen::getInstance())->getState() == PLAYING) ) {
 		(Hydrogen::getInstance())->stop();
@@ -531,7 +537,7 @@ void MainForm::action_file_openDemo() {
 			QMessageBox::information( this, "Hydrogen",
 					trUtf8("\nThe document contains unsaved changes\n"
 					"Do you want to save the changes before exiting?\n"),
-					trUtf8("&Save"), trUtf8("&Discard"), trUtf8("Cancel"),
+					trUtf8("&Save"), trUtf8("&Discard"), trUtf8("&Cancel"),
 					0,      // Enter == button 0
 					2 ) ) { // Escape == button 2
 			case 0: // Save clicked or Alt+S pressed or Enter pressed.
@@ -561,13 +567,13 @@ void MainForm::action_file_openDemo() {
 	fd->setCaption( trUtf8( "Open song" ) );
 	fd->setIcon( QPixmap( QString(IMG_PATH) + QString( "/img/icon32.png") ) );
 
-	// FIXME: impostare il preview
+	/// \todo impostare il preview
 	/*
 	fd->setContentsPreviewEnabled( TRUE );
 	fd->setContentsPreview( "uno", "due" );
 	fd->setPreviewMode( QFileDialog::Contents );
 	*/
-	string demoPath = (PreferencesMng::getInstance())->getDemoPath();
+	string demoPath = (Preferences::getInstance())->getDemoPath();
 	fd->setSelection( QString( demoPath.c_str() ) );
 
 
@@ -585,12 +591,6 @@ void MainForm::action_file_openDemo() {
 
 
 
-
-
-//----------------------------------------------------------------------------
-/**
- *
- */
 void MainForm::action_file_preferences() {
 	if ( ((Hydrogen::getInstance())->getState() == PLAYING) ) {
 		(Hydrogen::getInstance())->stop();
@@ -602,36 +602,23 @@ void MainForm::action_file_preferences() {
 
 
 
-
-
-//----------------------------------------------------------------------------
-/**
- *
- */
 void MainForm::action_window_showMixer() {
-	h2app->showMixer(true);
+
+	h2app->showMixer( true );
 }
 
 
 
 
-
-//----------------------------------------------------------------------------
-/**
- *
- */
 void MainForm::action_window_showAudioEngineInfo() {
 	h2app->showAudioEngineInfoForm();
 }
 
 
 
-
-
-//----------------------------------------------------------------------------
-/**
- * Show the song editor
- */
+///
+/// Shows the song editor
+///
 void MainForm::action_window_showSongEditor() {
 	h2app->getSongEditorPanel()->hide();
 	h2app->getSongEditorPanel()->show();
@@ -640,10 +627,9 @@ void MainForm::action_window_showSongEditor() {
 
 
 
-//----------------------------------------------------------------------------
-/**
- * Window close event
- */
+///
+/// Window close event
+///
 void MainForm::closeEvent( QCloseEvent* ev ) {
 	if ( (h2app->getSong())->isModified() ) {
 		switch(
@@ -688,11 +674,11 @@ void MainForm::closeEvent( QCloseEvent* ev ) {
 
 
 
-
-/**
- *
- */
 void MainForm::action_file_export() {
+	if ( ((Hydrogen::getInstance())->getState() == PLAYING) ) {
+		(Hydrogen::getInstance())->stop();
+	}
+
 	ExportSongDialog *dialog = new ExportSongDialog(this);
 	dialog->exec();
 	delete dialog;
@@ -700,10 +686,6 @@ void MainForm::action_file_export() {
 
 
 
-
-/**
- *
- */
 void MainForm::action_window_showDrumkitManager() {
 	h2app->getDrumkitManager()->hide();
 	h2app->getDrumkitManager()->show();
@@ -712,9 +694,6 @@ void MainForm::action_window_showDrumkitManager() {
 
 
 
-/**
- *
- */
 void MainForm::customEvent( QCustomEvent *ev ) {
 	if ( ev->type() != H2_TEXT_EVENT ) {	// Must be a H2TextEvent
 		return;
@@ -731,13 +710,10 @@ void MainForm::customEvent( QCustomEvent *ev ) {
 
 
 
-/**
- *
- */
 void MainForm::closeAll() {
 
 	// save window properties in the preferences files
-	PreferencesMng *pref = PreferencesMng::getInstance();
+	Preferences *pref = Preferences::getInstance();
 
 	// mainform
 	WindowProperties mainFormProp;
@@ -747,6 +723,19 @@ void MainForm::closeAll() {
 	mainFormProp.width = width();
 	pref->setMainFormProperties( mainFormProp );
 
+	// Instrument properties
+	WindowProperties instrumentEditorProp;
+	if ( h2app->getInstrumentProperties()->parentWidget() != 0 ) {	// use the new MDI interface
+		instrumentEditorProp.x = h2app->getInstrumentProperties()->parentWidget()->x();
+		instrumentEditorProp.y = h2app->getInstrumentProperties()->parentWidget()->y();
+	}
+	else {
+		instrumentEditorProp.x = h2app->getInstrumentProperties()->x();
+		instrumentEditorProp.y = h2app->getInstrumentProperties()->y();
+	}
+	instrumentEditorProp.visible = h2app->getInstrumentProperties()->isShown();
+	pref->setInstrumentEditorProperties( instrumentEditorProp );
+
 	// Save mixer properties
 	WindowProperties mixerProp;
 	if ( h2app->getMixer()->parentWidget() != 0 ) {	// use the new MDI interface
@@ -763,24 +752,24 @@ void MainForm::closeAll() {
 		mixerProp.width = h2app->getMixer()->width();
 		mixerProp.height = h2app->getMixer()->height();
 	}
+	mixerProp.visible = h2app->getMixer()->isShown();
 	pref->setMixerProperties( mixerProp );
 
 	// save pattern editor properties
 	WindowProperties patternEditorProp;
-	if ( h2app->getPatternEditor()->parentWidget() != 0 ) {	// use the new MDI interface
-		patternEditorProp.x = h2app->getPatternEditor()->parentWidget()->x();
-		patternEditorProp.y = h2app->getPatternEditor()->parentWidget()->y();
-//		patternEditorProp.width = h2app->getPatternEditor()->parentWidget()->width();
-//		patternEditorProp.height = h2app->getPatternEditor()->parentWidget()->height();
-		patternEditorProp.width = h2app->getPatternEditor()->width();
-		patternEditorProp.height = h2app->getPatternEditor()->height();
+	if ( h2app->getPatternEditorPanel()->parentWidget() != 0 ) {	// use the new MDI interface
+		patternEditorProp.x = h2app->getPatternEditorPanel()->parentWidget()->x();
+		patternEditorProp.y = h2app->getPatternEditorPanel()->parentWidget()->y();
+		patternEditorProp.width = h2app->getPatternEditorPanel()->width();
+		patternEditorProp.height = h2app->getPatternEditorPanel()->height();
 	}
 	else {
-		patternEditorProp.x = h2app->getPatternEditor()->x();
-		patternEditorProp.y = h2app->getPatternEditor()->y();
-		patternEditorProp.width = h2app->getPatternEditor()->width();
-		patternEditorProp.height = h2app->getPatternEditor()->height();
+		patternEditorProp.x = h2app->getPatternEditorPanel()->x();
+		patternEditorProp.y = h2app->getPatternEditorPanel()->y();
+		patternEditorProp.width = h2app->getPatternEditorPanel()->width();
+		patternEditorProp.height = h2app->getPatternEditorPanel()->height();
 	}
+	patternEditorProp.visible = h2app->getPatternEditorPanel()->isShown();
 	pref->setPatternEditorProperties( patternEditorProp );
 
 	// save song editor properties
@@ -788,20 +777,22 @@ void MainForm::closeAll() {
 	if ( h2app->getSongEditorPanel()->parentWidget() != 0 ) {	// use the new MDI interface
 		songEditorProp.x = h2app->getSongEditorPanel()->parentWidget()->x();
 		songEditorProp.y = h2app->getSongEditorPanel()->parentWidget()->y();
-//		songEditorProp.width = h2app->getSongEditorPanel()->parentWidget()->width();
-//		songEditorProp.height = h2app->getSongEditorPanel()->parentWidget()->height();
-
-		songEditorProp.width = h2app->getSongEditorPanel()->width();
-		songEditorProp.height = h2app->getSongEditorPanel()->height();
 	}
 	else {
 		songEditorProp.x = h2app->getSongEditorPanel()->x();
 		songEditorProp.y = h2app->getSongEditorPanel()->y();
-		songEditorProp.width = h2app->getSongEditorPanel()->width();
-		songEditorProp.height = h2app->getSongEditorPanel()->height();
 	}
+	songEditorProp.width = h2app->getSongEditorPanel()->width();
+	songEditorProp.height = h2app->getSongEditorPanel()->height();
+
+//	cout << "song editor size=" << h2app->getSongEditorPanel()->width() << "x" << h2app->getSongEditorPanel()->height() << endl;
+	QSize size = h2app->getSongEditorPanel()->frameSize();
+//	cout << "song editor size2=" << size.width() << "x" << size.height() << endl;
+
+	songEditorProp.visible = h2app->getSongEditorPanel()->isShown();
 	pref->setSongEditorProperties( songEditorProp );
 
+
 	// save drumkit manager properties
 	WindowProperties drumkitMngProp;
 	if ( h2app->getDrumkitManager()->parentWidget() != 0 ) {	// use the new MDI interface
@@ -816,8 +807,10 @@ void MainForm::closeAll() {
 		drumkitMngProp.width = h2app->getDrumkitManager()->width();
 		drumkitMngProp.height = h2app->getDrumkitManager()->height();
 	}
+	drumkitMngProp.visible = h2app->getDrumkitManager()->isShown();
 	pref->setDrumkitManagerProperties( drumkitMngProp );
 
+
 	// save audio engine info properties
 	WindowProperties audioEngineInfoProp;
 	if ( h2app->getAudioEngineInfoForm()->parentWidget() != 0 ) {	// use the new MDI interface
@@ -828,6 +821,7 @@ void MainForm::closeAll() {
 		audioEngineInfoProp.x = h2app->getAudioEngineInfoForm()->x();
 		audioEngineInfoProp.y = h2app->getAudioEngineInfoForm()->y();
 	}
+	audioEngineInfoProp.visible = h2app->getAudioEngineInfoForm()->isShown();
 	pref->setAudioEngineInfoProperties( audioEngineInfoProp );
 
 
@@ -842,6 +836,7 @@ void MainForm::closeAll() {
 			prop.x = h2app->getLadspaFXProperties(nFX)->x();
 			prop.y = h2app->getLadspaFXProperties(nFX)->y();
 		}
+		prop.visible= h2app->getLadspaFXProperties(nFX)->isShown();
 		pref->setLadspaProperties(nFX, prop);
 	}
 
@@ -849,7 +844,8 @@ void MainForm::closeAll() {
 }
 
 
-// keybings..
+
+// keybindings..
 
 void MainForm::onPlayStopAccelEvent()
 {
@@ -869,6 +865,7 @@ void MainForm::onPlayStopAccelEvent()
 }
 
 
+
 void MainForm::onRestartAccelEvent()
 {
 	Hydrogen* pEngine = ( Hydrogen::getInstance() );
@@ -904,23 +901,28 @@ void MainForm::onBPMMinusAccelEvent()
 }
 
 
+
 void MainForm::onSaveAsAccelEvent()
 {
 	action_file_save_as();
 }
 
+
+
 void MainForm::onSaveAccelEvent()
 {
 	action_file_save();
 }
 
 
+
 void MainForm::onOpenAccelEvent()
 {
 	action_file_open();
 }
 
 
+
 void MainForm::onTapTempoAccelEvent()
 {
 	infoLog( "tap tempo" );
@@ -945,7 +947,7 @@ void MainForm::updateRecentUsedSongList()
 //	infoLog( "updateRecentUsedSongList" );
 	m_pRecentFilesPopupMenu->clear();
 
-	PreferencesMng *pPref = PreferencesMng::getInstance();
+	Preferences *pPref = Preferences::getInstance();
 	vector<string> recentUsedSongs = pPref->getRecentFiles();
 
 	string sFilename = "";
@@ -1008,21 +1010,29 @@ void MainForm::action_file_open_recent0()
 	openSongFile( m_pRecentFileAction0->text().latin1() );
 }
 
+
+
 void MainForm::action_file_open_recent1()
 {
 	openSongFile( m_pRecentFileAction1->text().latin1() );
 }
 
+
+
 void MainForm::action_file_open_recent2()
 {
 	openSongFile( m_pRecentFileAction2->text().latin1() );
 }
 
+
+
 void MainForm::action_file_open_recent3()
 {
 	openSongFile( m_pRecentFileAction3->text().latin1() );
 }
 
+
+
 void MainForm::action_file_open_recent4()
 {
 	openSongFile( m_pRecentFileAction4->text().latin1() );
@@ -1040,7 +1050,7 @@ void MainForm::openSongFile( string sFilename )
 	}
 
 	// add the new loaded song in the "last used song" vector
-	PreferencesMng *pPref = PreferencesMng::getInstance();
+	Preferences *pPref = Preferences::getInstance();
 	vector<string> recentFiles = pPref->getRecentFiles();
 	recentFiles.insert( recentFiles.begin(), sFilename );
 	pPref->setRecentFiles( recentFiles );
@@ -1119,11 +1129,13 @@ void MainForm::initKeyInstMap()
 */
 }
 
+
+
 bool MainForm::eventFilter( QObject *o, QEvent *e )
 {
 	if ( e->type() == QEvent::KeyPress) {
 		// special processing for key press
-//		PreferencesMng *pref = PreferencesMng::getInstance();
+//		Preferences *pref = Preferences::getInstance();
 
 		QKeyEvent *k = (QKeyEvent *)e;
 
@@ -1154,3 +1166,107 @@ bool MainForm::eventFilter( QObject *o, QEvent *e )
 		return FALSE;
         }
 }
+
+
+
+void MainForm::action_window_showInstrumentEditor()
+{
+	HydrogenApp::getInstance()->getInstrumentProperties()->hide();
+	HydrogenApp::getInstance()->getInstrumentProperties()->show();
+}
+
+
+
+/// print the object map
+void MainForm::action_debug_printObjects()
+{
+	infoLog( "[action_debug_printObjects]" );
+	Object::printObjectMap();
+}
+
+
+
+/// Riceve un comando testuale ed esegue una azione di debug
+void MainForm::action_debug_debugCommand()
+{
+	infoLog( "[action_debug_debugCommand]" );
+
+	static QString sLastCommand = "";
+	bool bIsOkPressed;
+	QString cmd = QInputDialog::getText( "Hydrogen", "Command", QLineEdit::Normal, sLastCommand, &bIsOkPressed, this );
+	if (bIsOkPressed) {
+		sLastCommand = cmd;
+
+		if ( cmd == "print current pattern list" ) {
+			Hydrogen *pEngine = Hydrogen::getInstance();
+
+			cout << "*** print current pattern list ***" << endl;
+
+			cout << "Pattern pos: " << pEngine->getPatternPos() << endl;
+
+			cout << endl;
+
+			cout << "----------------------------------------------------------------------" << endl;
+			cout << "Song pattern list" << endl;
+			cout << "----------------------------------------------------------------------" << endl;
+			PatternList *pSongPatternList = pEngine->getSong()->getPatternList();
+			for ( int i = 0; i <pSongPatternList->getSize(); i++ ) {
+				Pattern *pPat = pSongPatternList->get( i );
+				cout << "   |->[" << i << "] " << pPat->getName() << endl;
+			}
+			cout << "----------------------------------------------------------------------" << endl;
+
+			cout << endl;
+
+			cout << "----------------------------------------------------------------------" << endl;
+			cout << "Current pattern list" << endl;
+			cout << "----------------------------------------------------------------------" << endl;
+			PatternList *pCurrentPatternList = pEngine->getCurrentPatternList();
+			for ( int i = 0; i <pCurrentPatternList->getSize(); i++ ) {
+				Pattern *pPat = pCurrentPatternList->get( i );
+				cout << "   |->[" << i << "] " << pPat->getName() << endl;
+			}
+			cout << "----------------------------------------------------------------------" << endl;
+		}
+		else {
+			QMessageBox::warning( this, "Hydrogen", "action not found" );
+		}
+
+	}
+
+}
+
+
+
+void MainForm::action_file_export_midi()
+{
+	if ( ((Hydrogen::getInstance())->getState() == PLAYING) ) {
+		(Hydrogen::getInstance())->stop();
+	}
+
+	QFileDialog *fd = new QFileDialog(this, "File Dialog", TRUE);
+	fd->setMode(QFileDialog::AnyFile);
+	fd->setFilter( trUtf8("Midi file (*.mid)") );
+
+	fd->setCaption( trUtf8( "Export MIDI file" ) );
+	fd->setIcon( QPixmap( QString(IMG_PATH) + QString( "/img/icon32.png") ) );
+
+	QString sFilename = "";
+	if ( fd->exec() == QDialog::Accepted ) {
+		sFilename = fd->selectedFile();
+	}
+
+	if ( sFilename != "" ) {
+		if ( sFilename.endsWith(".mid") == false ) {
+			sFilename += ".mid";
+		}
+
+		Song *pSong = Hydrogen::getInstance()->getSong();
+
+		// create the Standard Midi File object
+		SMFWriter *pSmfWriter = new SMFWriter();
+		pSmfWriter->save( sFilename.latin1(), pSong );
+
+		delete pSmfWriter;
+	}
+}
