@@ -18,147 +18,108 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: Mixer.cpp,v 1.83 2004/02/20 14:09:13 comix Exp $
+ * $Id: Mixer.cpp,v 1.96 2004/09/06 09:41:48 comix Exp $
  *
  */
 
+#include "qinputdialog.h"
 
-#include "Mixer.h"
 #include "lib/Hydrogen.h"
 #include "lib/Song.h"
 
+#include "Mixer.h"
+#include "Button.h"
+#include "MixerLine.h"
 #include "HydrogenApp.h"
+#include "LadspaFXProperties.h"
+#include "PatternEditorPanel.h"
 
 #define MIXER_STRIP_WIDTH	44
 
-/**
- * Constructor
- */
-Mixer::Mixer( QWidget* parent ) : QWidget( parent, "Mixer" ), Object( "Mixer" )
+Mixer::Mixer( QWidget* parent )
+ : QWidget( parent, "Mixer" )
+ , Object( "Mixer" )
 {
-//	cout << "Mixer INIT" << endl;
 
-	mixerHeight = 270;
+	unsigned nMinimumVisibleFadersSize;
+
+	m_nMixerHeight = 270;
 	nMinimumVisibleFadersSize = 5 + MIXER_STRIP_WIDTH * 16 + 5;
 	uint fadersSize = 5 + MIXER_STRIP_WIDTH * MAX_INSTRUMENTS;
 
-	mixerWidth = 5 + MIXER_STRIP_WIDTH * 4 + 70 + 50;	// 4 instruments visible
-	setMinimumSize( mixerWidth, mixerHeight );
+	m_nMixerWidth = 5 + MIXER_STRIP_WIDTH * 4 + 70;	// 4 instruments visible
+	setMinimumSize( m_nMixerWidth, m_nMixerHeight );
 
-	setMaximumSize( fadersSize +  70 + 50, mixerHeight );
-	mixerWidth = 5 + MIXER_STRIP_WIDTH * 16 + 70 + 50;	// 16 instruments visible
-	resize( mixerWidth, mixerHeight );
+	setMaximumSize( fadersSize +  70, m_nMixerHeight );
+	m_nMixerWidth = 5 + MIXER_STRIP_WIDTH * 16 + 70;	// 16 instruments visible
+	resize( m_nMixerWidth, m_nMixerHeight );
 	setCaption( trUtf8( "Mixer" ) );
 	setIcon( QPixmap( QString(IMG_PATH) + QString( "/img/icon32.png") ) );
 
 	// Background image
 	string background_path = string( IMG_PATH ) + string( "/img/mixerPanel/mixer_background.png" );
-	bool ok = background.load( background_path.c_str() );
+	bool ok = m_backgroundPixmap.load( background_path.c_str() );
 	if( ok == false ){
 		errorLog( "Error loading pixmap " + background_path );
 	}
 
-	// Left frame
-	m_pLeftFrame = new QFrame( this );
-	m_pLeftFrame->resize( 50, mixerHeight );
-	m_pLeftFrame->setBackgroundPixmap( background );
-
-	string showMixer_on_path = string(IMG_PATH).append("/img/mixerPanel/showMixer_on.png");
-	string showMixer_off_path = string(IMG_PATH).append("/img/mixerPanel/showMixer_off.png");
-	string showMixer_over_path = string(IMG_PATH).append("/img/mixerPanel/showMixer_over.png");
-	m_pShowFaderPanelBtn = new ToggleButton( m_pLeftFrame, QSize(40, 12), showMixer_on_path, showMixer_off_path, showMixer_over_path );
-	m_pShowFaderPanelBtn->move( 5, 20 );
-	m_pShowFaderPanelBtn->setPressed(true);
-	QToolTip::add( m_pShowFaderPanelBtn, trUtf8( "Show faders panel" ) );
-	connect( m_pShowFaderPanelBtn, SIGNAL(clicked(Button*)), this, SLOT(showFadersPanelClicked(Button*)));
-
-	string showFX_on_path = string(IMG_PATH).append("/img/mixerPanel/showFX_on.png");
-	string showFX_off_path = string(IMG_PATH).append("/img/mixerPanel/showFX_off.png");
-	string showFX_over_path = string(IMG_PATH).append("/img/mixerPanel/showFX_over.png");
-	m_pShowFXPanelBtn = new ToggleButton( m_pLeftFrame, QSize(40, 12), showFX_on_path, showFX_off_path, showFX_over_path );
-	m_pShowFXPanelBtn->move( 5, 40 );
-	m_pShowFXPanelBtn->setPressed(false);
-	QToolTip::add( m_pShowFXPanelBtn, trUtf8( "Show FX panel" ) );
-	connect( m_pShowFXPanelBtn, SIGNAL(clicked(Button*)), this, SLOT( showFXPanelClicked(Button*)));
-
-	string showPeaks_on_path = string(IMG_PATH).append("/img/mixerPanel/showPeaks_on.png");
-	string showPeaks_off_path = string(IMG_PATH).append("/img/mixerPanel/showPeaks_off.png");
-	string showPeaks_over_path = string(IMG_PATH).append("/img/mixerPanel/showPeaks_over.png");
-	m_pShowPeaksBtn = new ToggleButton( m_pLeftFrame, QSize(40, 12), showPeaks_on_path, showPeaks_off_path, showPeaks_over_path );
-	m_pShowPeaksBtn->move( 5, 60 );
-	m_pShowPeaksBtn->setPressed( (PreferencesMng::getInstance())->showInstrumentPeaks() );
-	QToolTip::add( m_pShowPeaksBtn, trUtf8( "Show instrument peaks" ) );
-	connect( m_pShowPeaksBtn, SIGNAL(clicked(Button*)), this, SLOT( showPeaksBtnClicked(Button*)));
-
-
 
 	// fader scroll view
 	m_pFaderScrollView = new QScrollView( this );
-	m_pFaderScrollView->move( 50, 0 );
+	m_pFaderScrollView->move( 0, 0 );
 	m_pFaderScrollView->setVScrollBarMode( QScrollView::AlwaysOff );
 	m_pFaderScrollView->setHScrollBarMode( QScrollView::AlwaysOn );
-	m_pFaderScrollView->resize( nMinimumVisibleFadersSize, mixerHeight );
-//	m_pFaderScrollView->viewport()->setBackgroundPixmap( background );
+	m_pFaderScrollView->resize( nMinimumVisibleFadersSize, m_nMixerHeight );
 
 	// fader frame
 	m_pFaderFrame = new QFrame( m_pFaderScrollView->viewport() );
-	m_pFaderFrame->resize( fadersSize, mixerHeight );
+	m_pFaderFrame->resize( fadersSize, m_nMixerHeight );
 	m_pFaderScrollView->addChild( m_pFaderFrame );
-	m_pFaderFrame->setBackgroundPixmap( background );
+	m_pFaderFrame->setBackgroundPixmap( m_backgroundPixmap );
 
 
 	// fx scroll view
 	m_pFXScrollView = new QScrollView( this );
-	m_pFXScrollView->move( 50, 0 );
+	m_pFXScrollView->move( 0, 0 );
 	m_pFXScrollView->setVScrollBarMode( QScrollView::AlwaysOff );
 	m_pFXScrollView->setHScrollBarMode( QScrollView::AlwaysOn );
-	m_pFXScrollView->resize( nMinimumVisibleFadersSize, mixerHeight );
-//	m_pFXScrollView->viewport()->setBackgroundPixmap( background );
+	m_pFXScrollView->resize( nMinimumVisibleFadersSize, m_nMixerHeight );
 
 	// fX frame
 	m_pFXFrame = new QFrame( m_pFXScrollView->viewport() );
-	m_pFXFrame->resize( fadersSize, mixerHeight );
+	m_pFXFrame->resize( fadersSize, m_nMixerHeight );
 	m_pFXScrollView->addChild( m_pFXFrame );
-	m_pFXFrame->setBackgroundPixmap( background );
+	m_pFXFrame->setBackgroundPixmap( m_backgroundPixmap );
 
 
 
+	this->setBackgroundPixmap( m_backgroundPixmap );
 
 
-	this->setBackgroundPixmap( background );
-
-	m_pShowFaderPanelBtn->setPressed(true);
-
 	m_pFaderScrollView->show();
 	m_pFXScrollView->hide();
 
 	setupMixer();
 
-	timer = new QTimer( this );
-	connect(timer, SIGNAL( timeout() ), this, SLOT( updateMixer() ) );
+	QTimer *pTimer = new QTimer( this );
+	connect( pTimer, SIGNAL( timeout() ), this, SLOT( updateMixer() ) );
+	pTimer->start(50);
 
 	( Hydrogen::getInstance() )->addEngineListener( this );
 }
 
 
 
-
-/**
- * Destructor
- */
-Mixer::~Mixer() {
-//	cout << "Mixer DESTROY" << endl;
+Mixer::~Mixer()
+{
 }
 
 
 
-
-/**
- * Setup the mixer strips
- */
+/// Setup the mixer strips
 void Mixer::setupMixer()
 {
-	uint master_X = mixerWidth - MIXER_STRIP_WIDTH - 5;
+	uint nMaster_X = m_nMixerWidth - MIXER_STRIP_WIDTH - 5;
 
 	Hydrogen *engine = Hydrogen::getInstance();
 	Song *song = engine->getSong();
@@ -180,42 +141,41 @@ void Mixer::setupMixer()
 			mute = instr->isMuted();
 		}
 
-		mixerLine[i] = new MixerLine( m_pFaderFrame );
-		mixerLine[i]->move( xPos, 4 );
-		mixerLine[i]->setVolume( volume );
-		mixerLine[i]->setMuteClicked( mute );
-		mixerLine[i]->setSoloClicked( solo );
-		mixerLine[i]->updateMixerLine();
+		m_pMixerLine[i] = new MixerLine( m_pFaderFrame );
+		m_pMixerLine[i]->move( xPos, 4 );
+		m_pMixerLine[i]->setVolume( volume );
+		m_pMixerLine[i]->setMuteClicked( mute );
+		m_pMixerLine[i]->setSoloClicked( solo );
+		m_pMixerLine[i]->updateMixerLine();
 
-		connect( mixerLine[i], SIGNAL( noteOnClicked(MixerLine*) ), this, SLOT( noteOnClicked(MixerLine*) ) );
-		connect( mixerLine[i], SIGNAL( noteOffClicked(MixerLine*) ), this, SLOT( noteOffClicked(MixerLine*) ) );
-		connect( mixerLine[i], SIGNAL( muteBtnClicked(MixerLine*) ), this, SLOT( muteClicked(MixerLine*) ) );
-		connect( mixerLine[i], SIGNAL( soloBtnClicked(MixerLine*) ), this, SLOT( soloClicked(MixerLine*) ) );
-		connect( mixerLine[i], SIGNAL( loadBtnClicked(MixerLine*) ), this, SLOT( loadClicked(MixerLine*) ) );
-		connect( mixerLine[i], SIGNAL( volumeChanged(MixerLine*) ), this, SLOT( volumeChanged(MixerLine*) ) );
-		connect( mixerLine[i], SIGNAL( instrumentNameClicked(MixerLine*) ), this, SLOT( nameClicked(MixerLine*) ) );
-		connect( mixerLine[i], SIGNAL( instrumentNameSelected(MixerLine*) ), this, SLOT( nameSelected(MixerLine*) ) );
-		connect( mixerLine[i], SIGNAL( panChanged(MixerLine*) ), this, SLOT( panChanged( MixerLine*) ) );
-		connect( mixerLine[i], SIGNAL( knobChanged(MixerLine*, int) ), this, SLOT( knobChanged( MixerLine*, int) ) );
+		connect( m_pMixerLine[i], SIGNAL( noteOnClicked(MixerLine*) ), this, SLOT( noteOnClicked(MixerLine*) ) );
+		connect( m_pMixerLine[i], SIGNAL( noteOffClicked(MixerLine*) ), this, SLOT( noteOffClicked(MixerLine*) ) );
+		connect( m_pMixerLine[i], SIGNAL( muteBtnClicked(MixerLine*) ), this, SLOT( muteClicked(MixerLine*) ) );
+		connect( m_pMixerLine[i], SIGNAL( soloBtnClicked(MixerLine*) ), this, SLOT( soloClicked(MixerLine*) ) );
+		connect( m_pMixerLine[i], SIGNAL( volumeChanged(MixerLine*) ), this, SLOT( volumeChanged(MixerLine*) ) );
+		connect( m_pMixerLine[i], SIGNAL( instrumentNameClicked(MixerLine*) ), this, SLOT( nameClicked(MixerLine*) ) );
+		connect( m_pMixerLine[i], SIGNAL( instrumentNameSelected(MixerLine*) ), this, SLOT( nameSelected(MixerLine*) ) );
+		connect( m_pMixerLine[i], SIGNAL( panChanged(MixerLine*) ), this, SLOT( panChanged( MixerLine*) ) );
+		connect( m_pMixerLine[i], SIGNAL( knobChanged(MixerLine*, int) ), this, SLOT( knobChanged( MixerLine*, int) ) );
 	}
 
-	swingFactorLine = new FxMixerLine( m_pFXFrame );
-	swingFactorLine->move( 5, 4 );
-	swingFactorLine->setName( trUtf8( "Swing factor" ) );
-	connect( swingFactorLine, SIGNAL( volumeChanged(FxMixerLine*) ), this, SLOT( swingChanged(FxMixerLine*) ) );
-	connect( swingFactorLine, SIGNAL( activeBtnClicked(FxMixerLine*) ), this, SLOT( activeBtnChanged( FxMixerLine*) ) );
+	m_pSwingFactorLine = new FxMixerLine( m_pFXFrame );
+	m_pSwingFactorLine->move( 5, 4 );
+	m_pSwingFactorLine->setName( trUtf8( "Swing factor" ) );
+	connect( m_pSwingFactorLine, SIGNAL( volumeChanged(FxMixerLine*) ), this, SLOT( swingChanged(FxMixerLine*) ) );
+	connect( m_pSwingFactorLine, SIGNAL( activeBtnClicked(FxMixerLine*) ), this, SLOT( activeBtnChanged( FxMixerLine*) ) );
 
-	humanizeTimeLine = new FxMixerLine( m_pFXFrame );
-	humanizeTimeLine->move( 5 + MIXER_STRIP_WIDTH, 4 );
-	humanizeTimeLine->setName( trUtf8( "Human time" ) );
-	connect( humanizeTimeLine, SIGNAL( volumeChanged(FxMixerLine*) ), this, SLOT( humanizeChanged(FxMixerLine*) ) );
-	connect( humanizeTimeLine, SIGNAL( activeBtnClicked(FxMixerLine*) ), this, SLOT( activeBtnChanged( FxMixerLine*) ) );
+	m_pHumanizeTimeLine = new FxMixerLine( m_pFXFrame );
+	m_pHumanizeTimeLine->move( 5 + MIXER_STRIP_WIDTH, 4 );
+	m_pHumanizeTimeLine->setName( trUtf8( "Human time" ) );
+	connect( m_pHumanizeTimeLine, SIGNAL( volumeChanged(FxMixerLine*) ), this, SLOT( humanizeChanged(FxMixerLine*) ) );
+	connect( m_pHumanizeTimeLine, SIGNAL( activeBtnClicked(FxMixerLine*) ), this, SLOT( activeBtnChanged( FxMixerLine*) ) );
 
-	humanizeVelocityLine = new FxMixerLine( m_pFXFrame );
-	humanizeVelocityLine->move( 5 + MIXER_STRIP_WIDTH * 2, 4 );
-	humanizeVelocityLine->setName( trUtf8( "Human velocity" ) );
-	connect( humanizeVelocityLine, SIGNAL( volumeChanged(FxMixerLine*) ), this, SLOT( humanizeChanged(FxMixerLine*) ) );
-	connect( humanizeVelocityLine, SIGNAL( activeBtnClicked(FxMixerLine*) ), this, SLOT( activeBtnChanged( FxMixerLine*) ) );
+	m_pHumanizeVelocityLine = new FxMixerLine( m_pFXFrame );
+	m_pHumanizeVelocityLine->move( 5 + MIXER_STRIP_WIDTH * 2, 4 );
+	m_pHumanizeVelocityLine->setName( trUtf8( "Human velocity" ) );
+	connect( m_pHumanizeVelocityLine, SIGNAL( volumeChanged(FxMixerLine*) ), this, SLOT( humanizeChanged(FxMixerLine*) ) );
+	connect( m_pHumanizeVelocityLine, SIGNAL( activeBtnClicked(FxMixerLine*) ), this, SLOT( activeBtnChanged( FxMixerLine*) ) );
 
 	// LADSPA
 	for (uint nFX = 0; nFX < MAX_FX; nFX++) {
@@ -229,19 +189,45 @@ void Mixer::setupMixer()
 	// ~LADSPA
 
 
-//	uint masterVolume = 50;
-	masterLine = new MasterMixerLine( this );
-	masterLine->move( master_X, 4 );
-//	masterLine->setVolume(masterVolume);
-	connect( masterLine, SIGNAL( volumeChanged(MasterMixerLine*) ), this, SLOT( masterVolumeChanged(MasterMixerLine*) ) );
+	m_pMasterLine = new MasterMixerLine( this );
+	m_pMasterLine->move( nMaster_X, 4 );
+	connect( m_pMasterLine, SIGNAL( volumeChanged(MasterMixerLine*) ), this, SLOT( masterVolumeChanged(MasterMixerLine*) ) );
 
+	string showMixer_on_path = string(IMG_PATH).append("/img/mixerPanel/showMixer_on.png");
+	string showMixer_off_path = string(IMG_PATH).append("/img/mixerPanel/showMixer_off.png");
+	string showMixer_over_path = string(IMG_PATH).append("/img/mixerPanel/showMixer_over.png");
+	m_pShowFaderPanelBtn = new ToggleButton( this, QSize(40, 12), showMixer_on_path, showMixer_off_path, showMixer_over_path );
+	m_pShowFaderPanelBtn->move( nMaster_X, 20 );
+	m_pShowFaderPanelBtn->setPressed(true);
+	QToolTip::add( m_pShowFaderPanelBtn, trUtf8( "Show faders panel" ) );
+	connect( m_pShowFaderPanelBtn, SIGNAL(clicked(Button*)), this, SLOT(showFadersPanelClicked(Button*)));
+
+	string showFX_on_path = string(IMG_PATH).append("/img/mixerPanel/showFX_on.png");
+	string showFX_off_path = string(IMG_PATH).append("/img/mixerPanel/showFX_off.png");
+	string showFX_over_path = string(IMG_PATH).append("/img/mixerPanel/showFX_over.png");
+	m_pShowFXPanelBtn = new ToggleButton( this, QSize(40, 12), showFX_on_path, showFX_off_path, showFX_over_path );
+	m_pShowFXPanelBtn->move( nMaster_X, 40 );
+	m_pShowFXPanelBtn->setPressed(false);
+	QToolTip::add( m_pShowFXPanelBtn, trUtf8( "Show FX panel" ) );
+	connect( m_pShowFXPanelBtn, SIGNAL(clicked(Button*)), this, SLOT( showFXPanelClicked(Button*)));
+
+	string showPeaks_on_path = string(IMG_PATH).append("/img/mixerPanel/showPeaks_on.png");
+	string showPeaks_off_path = string(IMG_PATH).append("/img/mixerPanel/showPeaks_off.png");
+	string showPeaks_over_path = string(IMG_PATH).append("/img/mixerPanel/showPeaks_over.png");
+	m_pShowPeaksBtn = new ToggleButton( this, QSize(40, 12), showPeaks_on_path, showPeaks_off_path, showPeaks_over_path );
+	m_pShowPeaksBtn->move( nMaster_X, 60 );
+	m_pShowPeaksBtn->setPressed( (Preferences::getInstance())->showInstrumentPeaks() );
+	QToolTip::add( m_pShowPeaksBtn, trUtf8( "Show instrument peaks" ) );
+	connect( m_pShowPeaksBtn, SIGNAL(clicked(Button*)), this, SLOT( showPeaksBtnClicked(Button*)));
+
+	m_pShowFaderPanelBtn->setPressed(true);
 }
 
 
 
-
 void Mixer::muteClicked(MixerLine* ref) {
 	int nLine = findMixerLineByRef(ref);
+	Hydrogen::getInstance()->setSelectedInstrumentNumber( nLine );
 	bool isMuteClicked = ref->isMuteClicked();
 
 	Hydrogen *engine = Hydrogen::getInstance();
@@ -250,19 +236,12 @@ void Mixer::muteClicked(MixerLine* ref) {
 
 	Instrument *instr = instrList->get(nLine);
 	instr->setMuted(isMuteClicked);
-
-	//update the pattern editor
-	(HydrogenApp::getInstance())->getPatternEditor()->getPatternEditor()->updateEditor(true);
-
-	PatternEditorPanel *pPatternEditorPanel = ( HydrogenApp::getInstance() )->getPatternEditor();
-	if ( pPatternEditorPanel->getSelectedInstrument() != nLine ) {
-		pPatternEditorPanel->setSelectedInstrument( nLine );
-	}
+	//(HydrogenApp::getInstance())->setSelectedInstrument(nLine);
+	Hydrogen::getInstance()->setSelectedInstrumentNumber(nLine);
 }
 
 
 
-
 void Mixer::soloClicked(MixerLine* ref) {
 	Hydrogen *engine = Hydrogen::getInstance();
 	Song *song = engine->getSong();
@@ -270,41 +249,38 @@ void Mixer::soloClicked(MixerLine* ref) {
 
 
 	int nLine = findMixerLineByRef(ref);
+	Hydrogen::getInstance()->setSelectedInstrumentNumber( nLine );
 	bool isSoloClicked = ref->isSoloClicked();
 
 	if (isSoloClicked) {
 		for (uint i = 0; i < MAX_INSTRUMENTS; i++) {
-			mixerLine[i]->setSoloClicked( false );
-			mixerLine[i]->setMuteClicked( true );
+			m_pMixerLine[i]->setSoloClicked( false );
+			m_pMixerLine[i]->setMuteClicked( true );
 
 			Instrument *instr = instrList->get( i );
 			instr->setMuted( true );
 		}
-		mixerLine[nLine]->setSoloClicked( true );
-		mixerLine[nLine]->setMuteClicked( false );
+		m_pMixerLine[nLine]->setSoloClicked( true );
+		m_pMixerLine[nLine]->setMuteClicked( false );
 		Instrument *instr = instrList->get( nLine );
 		instr->setMuted( false );
 	}
 	else {
 		for (uint i = 0; i < MAX_INSTRUMENTS; i++) {
-			mixerLine[i]->setMuteClicked( false );
-			mixerLine[i]->setSoloClicked( false );
+			m_pMixerLine[i]->setMuteClicked( false );
+			m_pMixerLine[i]->setSoloClicked( false );
 
 			Instrument *instr = instrList->get( i );
 			instr->setMuted( false );
 		}
 	}
-	//update the pattern editor
-	(HydrogenApp::getInstance())->getPatternEditor()->getPatternEditor()->updateEditor(true);
 
-	PatternEditorPanel *pPatternEditorPanel = ( HydrogenApp::getInstance() )->getPatternEditor();
-	if ( pPatternEditorPanel->getSelectedInstrument() != nLine ) {
-		pPatternEditorPanel->setSelectedInstrument( nLine );
-	}
+	Hydrogen::getInstance()->setSelectedInstrumentNumber(nLine);
 }
 
 
-// used in PatternEditorInstrumentList
+
+/// used in PatternEditorInstrumentList
 void Mixer::soloClicked(uint nLine)
 {
 	Hydrogen *engine = Hydrogen::getInstance();
@@ -312,25 +288,25 @@ void Mixer::soloClicked(uint nLine)
 	InstrumentList *instrList = song->getInstrumentList();
 
 
-	bool isSoloClicked = (mixerLine[nLine])->isSoloClicked();
+	bool isSoloClicked = (m_pMixerLine[nLine])->isSoloClicked();
 
 	if (!isSoloClicked) {
 		for (uint i = 0; i < MAX_INSTRUMENTS; i++) {
-			mixerLine[i]->setSoloClicked( false );
-			mixerLine[i]->setMuteClicked( true );
+			m_pMixerLine[i]->setSoloClicked( false );
+			m_pMixerLine[i]->setMuteClicked( true );
 
 			Instrument *instr = instrList->get( i );
 			instr->setMuted( true );
 		}
-		mixerLine[nLine]->setSoloClicked( true );
-		mixerLine[nLine]->setMuteClicked( false );
+		m_pMixerLine[nLine]->setSoloClicked( true );
+		m_pMixerLine[nLine]->setMuteClicked( false );
 		Instrument *instr = instrList->get( nLine );
 		instr->setMuted( false );
 	}
 	else {
 		for (uint i = 0; i < MAX_INSTRUMENTS; i++) {
-			mixerLine[i]->setMuteClicked( false );
-			mixerLine[i]->setSoloClicked( false );
+			m_pMixerLine[i]->setMuteClicked( false );
+			m_pMixerLine[i]->setSoloClicked( false );
 
 			Instrument *instr = instrList->get( i );
 			instr->setMuted( false );
@@ -340,70 +316,49 @@ void Mixer::soloClicked(uint nLine)
 }
 
 
-void Mixer::loadClicked(MixerLine* ref) {
-	int nLine = findMixerLineByRef(ref);
-
-	(HydrogenApp::getInstance())->loadNewInstrument(nLine);
-
-	PatternEditorPanel *pPatternEditorPanel = ( HydrogenApp::getInstance() )->getPatternEditor();
-	if ( pPatternEditorPanel->getSelectedInstrument() != nLine ) {
-		pPatternEditorPanel->setSelectedInstrument( nLine );
-	}
-}
-
-
 
 void Mixer::noteOnClicked( MixerLine* ref )
 {
 	int nLine = findMixerLineByRef( ref );
+	Hydrogen::getInstance()->setSelectedInstrumentNumber( nLine );
 
 	Hydrogen *engine = Hydrogen::getInstance();
 	Song *song = engine->getSong();
 	InstrumentList *instrList = song->getInstrumentList();
 
-	Note *note = new Note( 0, 1.0, 1.0, 1.0 );
+	Note *note = new Note( 0, 1.0, 1.0f, 1.0f, -1 );
 	note->setInstrument( instrList->get(nLine) );
 
 	engine->noteOn( note );
 
-	PatternEditorPanel *pPatternEditorPanel = ( HydrogenApp::getInstance() )->getPatternEditor();
-	if ( pPatternEditorPanel->getSelectedInstrument() != nLine ) {
-		pPatternEditorPanel->setSelectedInstrument( nLine );
-	}
+	Hydrogen::getInstance()->setSelectedInstrumentNumber(nLine);
 }
 
 
 
-
-// Play sample button, right-clicked (note off)
+/// Play sample button, right-clicked (note off)
  void Mixer::noteOffClicked( MixerLine* ref )
 {
 	int nLine = findMixerLineByRef( ref );
+	Hydrogen::getInstance()->setSelectedInstrumentNumber( nLine );
 
 	Hydrogen *engine = Hydrogen::getInstance();
 	Song *song = engine->getSong();
 	InstrumentList *instrList = song->getInstrumentList();
 
-	Note *note = new Note( 0, 1.0, 1.0, 1.0 );
+	Note *note = new Note( 0, 1.0, 1.0, 1.0, -1 );
 	note->setInstrument( instrList->get( nLine ) );
 
 	engine->noteOff( note );
 
-	PatternEditorPanel *pPatternEditorPanel = ( HydrogenApp::getInstance() )->getPatternEditor();
-	if ( pPatternEditorPanel->getSelectedInstrument() != nLine ) {
-		pPatternEditorPanel->setSelectedInstrument( nLine );
-	}
+	Hydrogen::getInstance()->setSelectedInstrumentNumber(nLine);
 }
 
 
 
-
-/**
- *
- */
 uint Mixer::findMixerLineByRef(MixerLine* ref) {
 	for (uint i = 0; i < MAX_INSTRUMENTS; i++) {
-		if (mixerLine[i] == ref) {
+		if (m_pMixerLine[i] == ref) {
 			return i;
 		}
 	}
@@ -412,10 +367,10 @@ uint Mixer::findMixerLineByRef(MixerLine* ref) {
 
 
 
-
 void Mixer::volumeChanged(MixerLine* ref) {
 
 	int nLine = findMixerLineByRef(ref);
+	Hydrogen::getInstance()->setSelectedInstrumentNumber( nLine );
 
 	Hydrogen *engine = Hydrogen::getInstance();
 	Song *song = engine->getSong();
@@ -425,18 +380,12 @@ void Mixer::volumeChanged(MixerLine* ref) {
 
 	instr->setVolume(ref->getVolume());
 
-	PatternEditorPanel *pPatternEditorPanel = ( HydrogenApp::getInstance() )->getPatternEditor();
-	if ( pPatternEditorPanel->getSelectedInstrument() != nLine ) {
-		pPatternEditorPanel->setSelectedInstrument( nLine );
-	}
+	Hydrogen::getInstance()->setSelectedInstrumentNumber(nLine);
 }
 
 
 
 
-/**
- *
- */
 void Mixer::masterVolumeChanged(MasterMixerLine* ref) {
 	float volume = ref->getVolume();
 	Song *song = (HydrogenApp::getInstance())->getSong();
@@ -445,16 +394,12 @@ void Mixer::masterVolumeChanged(MasterMixerLine* ref) {
 
 
 
-
-/**
- *
- */
 void Mixer::updateMixer() {
-	if(!isVisible()) {
-		return;
-	}
+//	if(!isVisible()) {
+//		return;
+//	}
 
-	PreferencesMng *pPref = PreferencesMng::getInstance();
+	Preferences *pPref = Preferences::getInstance();
 	bool bShowPeaks = pPref->showInstrumentPeaks();
 
 	Hydrogen *engine = Hydrogen::getInstance();
@@ -465,9 +410,9 @@ void Mixer::updateMixer() {
 	//float fallOff = 1.1;	// normal
 	//float fallOff = 1.3;	// fast
 
-	uint nSelectedInstr = ( HydrogenApp::getInstance() )->getPatternEditor()->getSelectedInstrument();
+	uint nSelectedInstr = Hydrogen::getInstance()->getSelectedInstrumentNumber();
 
-	float fallOff = (PreferencesMng::getInstance())->getMixerFalloffSpeed();
+	float fallOff = (Preferences::getInstance())->getMixerFalloffSpeed();
 
 	uint nMuteClicked = 0;
 	uint nInstruments = instrList->getSize();
@@ -475,11 +420,11 @@ void Mixer::updateMixer() {
 		Instrument *instr = instrList->get(i);
 
 		// fader
-		float oldPeak_L = mixerLine[i]->getPeak_L();
+		float oldPeak_L = m_pMixerLine[i]->getPeak_L();
 		float newPeak_L = instr->getPeak_L();
 		instr->setPeak_L( 0.0f );	// reset instrument peak
 
-		float oldPeak_R = mixerLine[i]->getPeak_R();
+		float oldPeak_R = m_pMixerLine[i]->getPeak_R();
 		float newPeak_R = instr->getPeak_R();
 		instr->setPeak_R( 0.0f );	// reset instrument peak
 
@@ -489,31 +434,31 @@ void Mixer::updateMixer() {
 		}
 
 		if ( newPeak_L >= oldPeak_L) {	// LEFT peak
-			mixerLine[i]->setPeak_L( newPeak_L );
+			m_pMixerLine[i]->setPeak_L( newPeak_L );
 		}
 		else {
-			mixerLine[i]->setPeak_L( oldPeak_L / fallOff );
+			m_pMixerLine[i]->setPeak_L( oldPeak_L / fallOff );
 		}
 		if ( newPeak_R >= oldPeak_R) {	// Right peak
-			mixerLine[i]->setPeak_R( newPeak_R );
+			m_pMixerLine[i]->setPeak_R( newPeak_R );
 		}
 		else {
-			mixerLine[i]->setPeak_R( oldPeak_R / fallOff );
+			m_pMixerLine[i]->setPeak_R( oldPeak_R / fallOff );
 		}
 
 		// fader position
 		float newVolume = instr->getVolume();
-		mixerLine[i]->setVolume(newVolume);
+		m_pMixerLine[i]->setVolume(newVolume);
 
 		// mute
 		bool muted = instr->isMuted();
 		if (muted) {
 			nMuteClicked++;
 		}
-		mixerLine[i]->setMuteClicked( muted );
+		m_pMixerLine[i]->setMuteClicked( muted );
 
 		// instr name
-		mixerLine[i]->setName( instr->getName().c_str() );
+		m_pMixerLine[i]->setName( instr->getName().c_str() );
 
 		// pan
 		float panValue = 0.0;
@@ -527,29 +472,29 @@ void Mixer::updateMixer() {
 		}
 		panValue = panValue * 100.0;
 
-		mixerLine[i]->setPan((int)panValue);	// FIXME: perche' setPan prende un'intero???
+		m_pMixerLine[i]->setPan((int)panValue);	/// \todo perche' setPan prende un'intero???
 
 		// activity
-		if ( mixerLine[i]->getActivity() > 0 ) {
-			mixerLine[i]->setActivity( mixerLine[i]->getActivity() - 30 );
-			mixerLine[i]->setPlayClicked( true );
+		if ( m_pMixerLine[i]->getActivity() > 0 ) {
+			m_pMixerLine[i]->setActivity( m_pMixerLine[i]->getActivity() - 30 );
+			m_pMixerLine[i]->setPlayClicked( true );
 		}
 		else {
-			mixerLine[i]->setPlayClicked( false );
+			m_pMixerLine[i]->setPlayClicked( false );
 		}
 
 		for (uint nFX = 0; nFX < MAX_FX; nFX++) {
-			mixerLine[i]->setFXLevel( nFX, instr->getFXLevel( nFX ) );
+			m_pMixerLine[i]->setFXLevel( nFX, instr->getFXLevel( nFX ) );
 		}
 
 		if ( i == nSelectedInstr) {
-			mixerLine[i]->setSelected( true );
+			m_pMixerLine[i]->setSelected( true );
 		}
 		else {
-			mixerLine[i]->setSelected( false );
+			m_pMixerLine[i]->setSelected( false );
 		}
 
-		mixerLine[i]->updateMixerLine();
+		m_pMixerLine[i]->updateMixerLine();
 	}
 
 	if (nMuteClicked == MAX_INSTRUMENTS - 1) {
@@ -557,23 +502,23 @@ void Mixer::updateMixer() {
 		for (uint i = 0; i < nInstruments; i++) {
 			Instrument *instr = instrList->get(i);
 			if (instr->isMuted() == false) {
-				mixerLine[i]->setSoloClicked(true);
+				m_pMixerLine[i]->setSoloClicked(true);
 				break;
 			}
 		}
 	}
 	else {
 		for (uint i = 0; i < nInstruments; i++) {
-			mixerLine[i]->setSoloClicked(false);
+			m_pMixerLine[i]->setSoloClicked(false);
 		}
 	}
 
 
 	// update MasterPeak
-	float oldPeak_L = masterLine->getPeak_L();
+	float oldPeak_L = m_pMasterLine->getPeak_L();
 	float newPeak_L = engine->getMasterPeak_L();
 	engine->setMasterPeak_L(0.0);
-	float oldPeak_R = masterLine->getPeak_R();
+	float oldPeak_R = m_pMasterLine->getPeak_R();
 	float newPeak_R = engine->getMasterPeak_R();
 	engine->setMasterPeak_R(0.0);
 
@@ -583,16 +528,16 @@ void Mixer::updateMixer() {
 	}
 
 	if (newPeak_L >= oldPeak_L) {
-		masterLine->setPeak_L( newPeak_L );
+		m_pMasterLine->setPeak_L( newPeak_L );
 	}
 	else {
-		masterLine->setPeak_L( oldPeak_L / fallOff );
+		m_pMasterLine->setPeak_L( oldPeak_L / fallOff );
 	}
 	if (newPeak_R >= oldPeak_R) {
-		masterLine->setPeak_R(newPeak_R);
+		m_pMasterLine->setPeak_R(newPeak_R);
 	}
 	else {
-		masterLine->setPeak_R( oldPeak_R / fallOff );
+		m_pMasterLine->setPeak_R( oldPeak_R / fallOff );
 	}
 
 
@@ -600,39 +545,39 @@ void Mixer::updateMixer() {
 
 	// set master fader position
 	float newVolume = pSong->getVolume();
-	float oldVolume = masterLine->getVolume();
+	float oldVolume = m_pMasterLine->getVolume();
 	if (oldVolume != newVolume) {
-		masterLine->setVolume(newVolume);
+		m_pMasterLine->setVolume(newVolume);
 	}
-	masterLine->updateMixerLine();
+	m_pMasterLine->updateMixerLine();
 
 
 	// set humanize fx
-	humanizeTimeLine->setFxActive( pSong->isHumanizeTimeEnabled() );
-	if (humanizeTimeLine->getVolume() != pSong->getHumanizeTimeValue() ) {
-		humanizeTimeLine->setVolume( pSong->getHumanizeTimeValue() );
+	m_pHumanizeTimeLine->setFxActive( pSong->isHumanizeTimeEnabled() );
+	if (m_pHumanizeTimeLine->getVolume() != pSong->getHumanizeTimeValue() ) {
+		m_pHumanizeTimeLine->setVolume( pSong->getHumanizeTimeValue() );
 	}
-	humanizeTimeLine->setPeak_L( pSong->getHumanizeTimeValue() );
-	humanizeTimeLine->setPeak_R( pSong->getHumanizeTimeValue() );
-	humanizeTimeLine->updateMixerLine();
+	m_pHumanizeTimeLine->setPeak_L( pSong->getHumanizeTimeValue() );
+	m_pHumanizeTimeLine->setPeak_R( pSong->getHumanizeTimeValue() );
+	m_pHumanizeTimeLine->updateMixerLine();
 
 
-	humanizeVelocityLine->setFxActive( pSong->isHumanizeVelocityEnabled() );
-	if ( humanizeVelocityLine->getVolume() != pSong->getHumanizeVelocityValue() ) {
-		humanizeVelocityLine->setVolume( pSong->getHumanizeVelocityValue() );
+	m_pHumanizeVelocityLine->setFxActive( pSong->isHumanizeVelocityEnabled() );
+	if ( m_pHumanizeVelocityLine->getVolume() != pSong->getHumanizeVelocityValue() ) {
+		m_pHumanizeVelocityLine->setVolume( pSong->getHumanizeVelocityValue() );
 	}
-	humanizeVelocityLine->setPeak_L( pSong->getHumanizeVelocityValue() );
-	humanizeVelocityLine->setPeak_R( pSong->getHumanizeVelocityValue() );
-	humanizeVelocityLine->updateMixerLine();
+	m_pHumanizeVelocityLine->setPeak_L( pSong->getHumanizeVelocityValue() );
+	m_pHumanizeVelocityLine->setPeak_R( pSong->getHumanizeVelocityValue() );
+	m_pHumanizeVelocityLine->updateMixerLine();
 
 	// swing factor
-	swingFactorLine->setFxActive( pSong->isSwingEnabled() );
-	if ( swingFactorLine->getVolume() != pSong->getSwingFactor() ) {
-		swingFactorLine->setVolume( pSong->getSwingFactor() );
+	m_pSwingFactorLine->setFxActive( pSong->isSwingEnabled() );
+	if ( m_pSwingFactorLine->getVolume() != pSong->getSwingFactor() ) {
+		m_pSwingFactorLine->setVolume( pSong->getSwingFactor() );
 	}
-	swingFactorLine->setPeak_L ( pSong->getSwingFactor() );
-	swingFactorLine->setPeak_R ( pSong->getSwingFactor() );
-	swingFactorLine->updateMixerLine();
+	m_pSwingFactorLine->setPeak_L ( pSong->getSwingFactor() );
+	m_pSwingFactorLine->setPeak_R ( pSong->getSwingFactor() );
+	m_pSwingFactorLine->updateMixerLine();
 
 
 	// LADSPA
@@ -666,82 +611,60 @@ void Mixer::updateMixer() {
 
 
 
-
-/**
- *
- */
-void Mixer::updateStart(bool start) {
-	if (start) {
-//		cout << "mixer update start" << endl;
-		timer->start(50);	// update mixer at 20 fps
-	}
-	else {
-//		cout << "mixer update stop" << endl;
-		timer->stop();
-	}
-}
-
-
-
-
-/**
- * show event
- */
+/// show event
 void Mixer::showEvent ( QShowEvent *ev ) {
 	updateMixer();
-	updateStart(true);
 }
 
 
 
-
-/**
- * hide event
- */
+/// hide event
 void Mixer::hideEvent ( QHideEvent *ev ) {
-	updateStart(false);
 }
 
 
 
-
 void Mixer::nameClicked(MixerLine* ref) {
-	int nLine = findMixerLineByRef(ref);
-	PatternEditorPanel *pPatternEditorPanel = ( HydrogenApp::getInstance() )->getPatternEditor();
-	if ( pPatternEditorPanel->getSelectedInstrument() != nLine ) {
-		pPatternEditorPanel->setSelectedInstrument( nLine );
-	}
+	Hydrogen *pEngine = Hydrogen::getInstance();
 
-
-	Hydrogen *engine = Hydrogen::getInstance();
-	Song *song = engine->getSong();
+	Song *song = pEngine->getSong();
 	InstrumentList *instrList = song->getInstrumentList();
-
-	Instrument *instr = instrList->get(nLine);
-
-	InstrumentPropertiesDialog *dialog = new InstrumentPropertiesDialog(this, instr);
-	if (dialog->exec() == QDialog::Accepted) {
-		song->setModified(true);
+	int nSelectedInstr = pEngine->getSelectedInstrumentNumber();
+	if (nSelectedInstr == -1) {
+		return;
 	}
-	delete dialog;
-	dialog = NULL;
 
+	Instrument *pInstr = instrList->get( nSelectedInstr );
+	if (pInstr) {
+		bool bIsOkPressed;
+		QString sOldName = QString( pInstr->getName().c_str() );
+		QString text = QInputDialog::getText( "Hydrogen", trUtf8( "Instrument name" ), QLineEdit::Normal, sOldName, &bIsOkPressed, this );
+		if ( bIsOkPressed && !text.isEmpty() ) {
+			// user entered something and pressed OK
+			pEngine->lockEngine( "InstrumentPropertiesDialog::nameClicked" );
+			pInstr->setName( text.latin1() );
+			pEngine->unlockEngine();
+
+			HydrogenApp::getInstance()->getPatternEditorPanel()->getInstrumentList()->updateEditor();
+		}
+		else {
+			// user entered nothing or pressed Cancel
+		}
+	}
 }
 
 
+
 void Mixer::nameSelected(MixerLine* ref)
 {
 	int nLine = findMixerLineByRef(ref);
-	PatternEditorPanel *pPatternEditorPanel = ( HydrogenApp::getInstance() )->getPatternEditor();
-	if ( pPatternEditorPanel->getSelectedInstrument() != nLine ) {
-		pPatternEditorPanel->setSelectedInstrument( nLine );
-	}
+	Hydrogen::getInstance()->setSelectedInstrumentNumber( nLine );
+
+	Hydrogen::getInstance()->setSelectedInstrumentNumber(nLine);
 }
 
 
 
-
-
 void Mixer::panChanged(MixerLine* ref) {
 	float panValue = ref->getPan();
 
@@ -760,6 +683,8 @@ void Mixer::panChanged(MixerLine* ref) {
 	}
 
 	int nLine = findMixerLineByRef(ref);
+	Hydrogen::getInstance()->setSelectedInstrumentNumber( nLine );
+
 	Hydrogen *engine = Hydrogen::getInstance();
 	Song *song = engine->getSong();
 	InstrumentList *instrList = song->getInstrumentList();
@@ -768,17 +693,16 @@ void Mixer::panChanged(MixerLine* ref) {
 	instr->setPan_L( pan_L );
 	instr->setPan_R( pan_R );
 
-	PatternEditorPanel *pPatternEditorPanel = ( HydrogenApp::getInstance() )->getPatternEditor();
-	if ( pPatternEditorPanel->getSelectedInstrument() != nLine ) {
-		pPatternEditorPanel->setSelectedInstrument( nLine );
-	}
 
+	Hydrogen::getInstance()->setSelectedInstrumentNumber(nLine);
 }
 
 
 
 void Mixer::knobChanged(MixerLine* ref, int nKnob) {
 	int nLine = findMixerLineByRef(ref);
+	Hydrogen::getInstance()->setSelectedInstrumentNumber( nLine );
+
 	Hydrogen *engine = Hydrogen::getInstance();
 	Song *song = engine->getSong();
 	InstrumentList *instrList = song->getInstrumentList();
@@ -787,20 +711,11 @@ void Mixer::knobChanged(MixerLine* ref, int nKnob) {
 	QString sInfo = trUtf8( "Set FX %1 level ").arg( nKnob );
 	( HydrogenApp::getInstance() )->setStatusBarMessage( sInfo+ QString( "[%1]" ).arg( ref->getFXLevel(nKnob), 0, 'f', 2 ), 2000 );
 
-	PatternEditorPanel *pPatternEditorPanel = ( HydrogenApp::getInstance() )->getPatternEditor();
-	if ( pPatternEditorPanel->getSelectedInstrument() != nLine ) {
-		pPatternEditorPanel->setSelectedInstrument( nLine );
-	}
-
+	Hydrogen::getInstance()->setSelectedInstrumentNumber(nLine);
 }
 
 
 
-
-
-/**
- *
- */
 void Mixer::humanizeChanged(FxMixerLine* ref) {
 	Hydrogen *engine = Hydrogen::getInstance();
 	ref->setPeak_L( ref->getVolume() );
@@ -810,31 +725,24 @@ void Mixer::humanizeChanged(FxMixerLine* ref) {
 	float value = ref->getVolume();
 	sprintf( faderPos, "%#.2f",  value);
 
-	if (ref == humanizeTimeLine) {
+	if (ref == m_pHumanizeTimeLine) {
 		float humanizeValue = ref->getVolume();
 		engine->lockEngine("Mixer::humanizeChanged");
 		engine->getSong()->setHumanizeTimeValue( humanizeValue );
 		engine->unlockEngine();
 		( HydrogenApp::getInstance() )->setStatusBarMessage( trUtf8( "Set humanize time parameter [%1]").arg( faderPos ), 2000 );
 	}
-	else if (ref == humanizeVelocityLine) {
+	else if (ref == m_pHumanizeVelocityLine) {
 		float humanizeValue = ref->getVolume();
 		engine->lockEngine("Mixer::humanizeChanged");
 		engine->getSong()->setHumanizeVelocityValue( humanizeValue );
 		engine->unlockEngine();
 		( HydrogenApp::getInstance() )->setStatusBarMessage( trUtf8( "Set humanize velocity parameter [%1]").arg( faderPos ), 2000 );
 	}
-
-
 }
 
 
 
-
-
-/**
- *
- */
 void Mixer::swingChanged( FxMixerLine* ref) {
 	ref->setPeak_L( ref->getVolume() );
 	ref->setPeak_R( ref->getVolume() );
@@ -852,12 +760,7 @@ void Mixer::swingChanged( FxMixerLine* ref) {
 
 
 
-
-
-
-/**
- * This method is called from another thread (audio engine)
- */
+/// This method is called from another thread (audio engine)
 void Mixer::noteOn( Note *note ) {
 	H2TextEvent *ev = new H2TextEvent( "noteOn", note );
 	QApplication::postEvent(this, ev);
@@ -865,9 +768,6 @@ void Mixer::noteOn( Note *note ) {
 
 
 
-/**
- *
- */
 void Mixer::customEvent( QCustomEvent *ev ) {
 	if ( ev->type() != H2_TEXT_EVENT ) {	// Must be a H2TextEvent
 		return;
@@ -891,7 +791,7 @@ void Mixer::customEvent( QCustomEvent *ev ) {
 			}
 		}
 		if (instrLine != -1) {
-			mixerLine[instrLine]->setActivity( 100 );
+			m_pMixerLine[instrLine]->setActivity( 100 );
 		}
 
 		delete note;
@@ -902,14 +802,10 @@ void Mixer::customEvent( QCustomEvent *ev ) {
 
 
 
-
-/**
- *
- */
 void Mixer::activeBtnChanged( FxMixerLine *ref ) {
 	bool isActive = ref->isFxActive();
 	Song *song = ( Hydrogen::getInstance() )->getSong();
-	if ( ref == humanizeTimeLine ) {
+	if ( ref == m_pHumanizeTimeLine ) {
 		song->setHumanizeTimeEnabled( isActive );
 		if (isActive) {
 			( HydrogenApp::getInstance() )->setStatusBarMessage( trUtf8( "Humanize Time FX enabled" ), 2000 );
@@ -918,7 +814,7 @@ void Mixer::activeBtnChanged( FxMixerLine *ref ) {
 			( HydrogenApp::getInstance() )->setStatusBarMessage( trUtf8( "Humanize Time FX disabled" ), 2000 );
 		}
 	}
-	else if ( ref == humanizeVelocityLine ) {
+	else if ( ref == m_pHumanizeVelocityLine ) {
 		song->setHumanizeVelocityEnabled( isActive );
 		if (isActive) {
 			( HydrogenApp::getInstance() )->setStatusBarMessage( trUtf8( "Humanize Velocity FX enabled" ), 2000 );
@@ -927,7 +823,7 @@ void Mixer::activeBtnChanged( FxMixerLine *ref ) {
 			( HydrogenApp::getInstance() )->setStatusBarMessage( trUtf8( "Humanize Velocity FX disabled" ), 2000 );
 		}
 	}
-	else if ( ref == swingFactorLine ) {
+	else if ( ref == m_pSwingFactorLine ) {
 		song->setSwingEnabled( isActive );
 		if (isActive) {
 			( HydrogenApp::getInstance() )->setStatusBarMessage( trUtf8( "Swing factor FX enabled" ), 2000 );
@@ -942,24 +838,24 @@ void Mixer::activeBtnChanged( FxMixerLine *ref ) {
 }
 
 
-/**
- *
- */
+
 void Mixer::resizeEvent ( QResizeEvent *ev )
 {
-	m_pFaderScrollView->resize( width() - 60 - 50 - 5, mixerHeight );
-	m_pFXScrollView->resize( width() - 60 - 50 -5, mixerHeight );
+	m_pFaderScrollView->resize( width() - 60 - 5, m_nMixerHeight );
+	m_pFXScrollView->resize( width() - 60 - 5, m_nMixerHeight );
 
-	uint master_X = width() - MIXER_STRIP_WIDTH - 5;
+	uint nMaster_X = width() - MIXER_STRIP_WIDTH - 5;
 
-	masterLine->move( master_X, 4 );
-	resize(width(), mixerHeight);	// qt bug workaround
+	m_pMasterLine->move( nMaster_X, 4 );
+	m_pShowFaderPanelBtn->move( nMaster_X + 1, 20 );
+	m_pShowFXPanelBtn->move( nMaster_X + 1, 40 );
+	m_pShowPeaksBtn->move( nMaster_X + 1, 60 );
+
+	resize(width(), m_nMixerHeight);	// qt bug workaround
 }
 
 
-/**
- *
- */
+
 void Mixer::showFadersPanelClicked(Button* ref)
 {
 	m_pShowFaderPanelBtn->setPressed(true);
@@ -970,9 +866,6 @@ void Mixer::showFadersPanelClicked(Button* ref)
 
 
 
-/**
- *
- */
 void Mixer::showFXPanelClicked(Button* ref)
 {
 	m_pShowFXPanelBtn->setPressed(true);
@@ -983,12 +876,9 @@ void Mixer::showFXPanelClicked(Button* ref)
 
 
 
-/**
- *
- */
 void Mixer::showPeaksBtnClicked(Button* ref)
 {
-	PreferencesMng *pPref = PreferencesMng::getInstance();
+	Preferences *pPref = Preferences::getInstance();
 
 	if ( ref->isPressed() ) {
 		pPref->setInstrumentPeaks( true );
@@ -1024,6 +914,7 @@ void Mixer::ladspaActiveBtnClicked( LadspaFXMixerLine* ref )
 
 void Mixer::ladspaEditBtnClicked( LadspaFXMixerLine *ref )
 {
+	infoLog( "ladspaEditBtnClicked" );
 	for (uint nFX = 0; nFX < MAX_FX; nFX++) {
 		if (ref == m_pLadspaFXLine[ nFX ] ) {
 			( HydrogenApp::getInstance() )->getLadspaFXProperties(nFX)->hide();
@@ -1035,7 +926,6 @@ void Mixer::ladspaEditBtnClicked( LadspaFXMixerLine *ref )
 
 
 
-
 void Mixer::ladspaVolumeChanged( LadspaFXMixerLine* ref)
 {
 	Song *pSong = (Hydrogen::getInstance() )->getSong();
@@ -1056,3 +946,26 @@ void Mixer::ladspaVolumeChanged( LadspaFXMixerLine* ref)
 }
 
 
+
+void Mixer::selectedInstrumentChanged()
+{
+	//infoLog( "[selectedInstrumentChanged]" );
+	// do nothing: the selected instrument will be redrawn at next update cicle
+}
+
+
+
+void Mixer::getPeaksInMixerLine( uint nMixerLine, float& fPeak_L, float& fPeak_R )
+{
+	if ( (nMixerLine >= 0 ) && (nMixerLine < MAX_INSTRUMENTS) ) {
+		fPeak_L = m_pMixerLine[ nMixerLine ]->getPeak_L();
+		fPeak_R = m_pMixerLine[ nMixerLine ]->getPeak_R();
+	}
+	else {
+		fPeak_L = 0;
+		fPeak_R = 0;
+	}
+}
+
+
+
