@@ -18,17 +18,22 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: MixerLine.cpp,v 1.70 2004/02/27 13:17:56 comix Exp $
+ * $Id: MixerLine.cpp,v 1.72 2004/05/03 14:02:24 comix Exp $
  *
  */
 
 
 #include "MixerLine.h"
+#include "InstrumentPropertiesDialog.h"
+#include "Fader.h"
+#include "HydrogenApp.h"
+#include "Button.h"
+
+#include "lib/Hydrogen.h"
+#include "lib/Preferences.h"
+
 #include <stdio.h>
 
-#include "HydrogenApp.h"
-#include "lib/Hydrogen.h"
-#include "lib/PreferencesMng.h"
 
 
 #define MIXERLINE_WIDTH		42
@@ -39,17 +44,16 @@
 QPixmap* MixerLine::m_pMixerLineBackground = NULL;
 QPixmap* MixerLine::m_pMixerLineBackground_selected = NULL;
 
-/**
- * Constructor
- */
+
+
 MixerLine::MixerLine(QWidget* parent) : QWidget(parent), Object( "MixerLine" )
 {
 //	cout << "mixerLine init" << endl;
 
 	m_nWidth = MIXERLINE_WIDTH;
 	m_nHeight = MIXERLINE_HEIGHT;
-	maxPeak = 0.0;
-	activity = 0;
+	m_fMaxPeak = 0.0;
+	m_nActivity = 0;
 	m_bIsSelected = false;
 
 	setMinimumSize( m_nWidth, m_nHeight );
@@ -83,12 +87,13 @@ MixerLine::MixerLine(QWidget* parent) : QWidget(parent), Object( "MixerLine" )
 	string playSample_on_path = string(IMG_PATH).append("/img/mixerPanel/btn_play_on.png");
 	string playSample_off_path = string(IMG_PATH).append("/img/mixerPanel/btn_play_off.png");
 	string playSample_over_path = string(IMG_PATH).append("/img/mixerPanel/btn_play_over.png");
-	playSampleBtn = new Button(this, QSize( 18, 12 ), playSample_on_path, playSample_off_path, playSample_over_path);
-	playSampleBtn->move( 2, 5 );
-	QToolTip::add( playSampleBtn, trUtf8( "Play sample" ) );
-	connect(playSampleBtn, SIGNAL(clicked(Button*)), this, SLOT(click(Button*)));
-	connect(playSampleBtn, SIGNAL(rightClicked(Button*)), this, SLOT(rightClick(Button*)));
+	m_pPlaySampleBtn = new Button(this, QSize( 18, 12 ), playSample_on_path, playSample_off_path, playSample_over_path);
+	m_pPlaySampleBtn->move( 2, 5 );
+	QToolTip::add( m_pPlaySampleBtn, trUtf8( "Play sample" ) );
+	connect(m_pPlaySampleBtn, SIGNAL(clicked(Button*)), this, SLOT(click(Button*)));
+	connect(m_pPlaySampleBtn, SIGNAL(rightClicked(Button*)), this, SLOT(rightClick(Button*)));
 
+/*
 	// load button
 	string load_off_path = string(IMG_PATH).append("/img/mixerPanel/btn_load_off.png");
 	string load_over_path = string(IMG_PATH).append("/img/mixerPanel/btn_load_over.png");
@@ -96,30 +101,31 @@ MixerLine::MixerLine(QWidget* parent) : QWidget(parent), Object( "MixerLine" )
 	loadBtn->move( 22, 5 );
 	QToolTip::add( loadBtn, trUtf8( "Load external sample" ) );
 	connect(loadBtn, SIGNAL(clicked(Button*)), this, SLOT(click(Button*)));
+*/
 
 	// Mute button
 	string mute_on_path = string(IMG_PATH).append("/img/mixerPanel/btn_mute_on.png");
 	string mute_off_path = string(IMG_PATH).append("/img/mixerPanel/btn_mute_off.png");
 	string mute_over_path = string(IMG_PATH).append("/img/mixerPanel/btn_mute_over.png");
-	muteBtn = new ToggleButton(this, QSize( 18, 12 ), mute_on_path, mute_off_path, mute_over_path);
-	muteBtn->move( 2, 20 );
-	QToolTip::add( muteBtn, trUtf8( "Mute" ) );
-	connect(muteBtn, SIGNAL(clicked(Button*)), this, SLOT(click(Button*)));
+	m_pMuteBtn = new ToggleButton(this, QSize( 18, 12 ), mute_on_path, mute_off_path, mute_over_path);
+	m_pMuteBtn->move( 2, 20 );
+	QToolTip::add( m_pMuteBtn, trUtf8( "Mute" ) );
+	connect(m_pMuteBtn, SIGNAL(clicked(Button*)), this, SLOT(click(Button*)));
 
 	// Solo button
 	string solo_on_path = string(IMG_PATH).append("/img/mixerPanel/btn_solo_on.png");
 	string solo_off_path = string(IMG_PATH).append("/img/mixerPanel/btn_solo_off.png");
 	string solo_over_path = string(IMG_PATH).append("/img/mixerPanel/btn_solo_over.png");
-	soloBtn = new ToggleButton(this, QSize( 18, 12 ), solo_on_path, solo_off_path, solo_over_path);
-	soloBtn->move( 22, 20);
-	QToolTip::add( soloBtn, trUtf8( "Solo" ) );
-	connect(soloBtn, SIGNAL(clicked(Button*)), this, SLOT(click(Button*)));
+	m_pSoloBtn = new ToggleButton(this, QSize( 18, 12 ), solo_on_path, solo_off_path, solo_over_path);
+	m_pSoloBtn->move( 22, 20);
+	QToolTip::add( m_pSoloBtn, trUtf8( "Solo" ) );
+	connect(m_pSoloBtn, SIGNAL(clicked(Button*)), this, SLOT(click(Button*)));
 
-	// pan fader
-	panFader = new PanFader(this);
-	panFader->move( 2, 35 );
-	QToolTip::add( panFader, trUtf8( "Pan" ) );
-	connect( panFader, SIGNAL( valueChanged(PanFader*) ), this, SLOT( panFaderChanged(PanFader*) ) );
+	// pan m_pFader
+	m_pPanFader = new PanFader(this);
+	m_pPanFader->move( 2, 35 );
+	QToolTip::add( m_pPanFader, trUtf8( "Pan" ) );
+	connect( m_pPanFader, SIGNAL( valueChanged(PanFader*) ), this, SLOT( panFaderChanged(PanFader*) ) );
 
 	for (uint i = 0; i < MAX_FX; i++) {
 		m_pKnob[i] = new Knob(this);
@@ -132,7 +138,7 @@ MixerLine::MixerLine(QWidget* parent) : QWidget(parent), Object( "MixerLine" )
 		connect( m_pKnob[i], SIGNAL( valueChanged(Knob*) ), this, SLOT( knobChanged(Knob*) ) );
 	}
 
-	PreferencesMng *pref = PreferencesMng::getInstance();
+	Preferences *pref = Preferences::getInstance();
 	QString family = pref->getMixerFontFamily().c_str();
 	int size = pref->getMixerFontPointSize();
 	QFont mixerFont( family, size );
@@ -147,50 +153,42 @@ MixerLine::MixerLine(QWidget* parent) : QWidget(parent), Object( "MixerLine" )
 
 	// peak volume label
 	QFont font1( family, size );
-	volumeLbl = new QLabel( this );
-	volumeLbl->move( 2, MIXERLINE_LABEL_H );
-	volumeLbl->resize( 38, 20 );
-	volumeLbl->setText( "0.0" );
-	volumeLbl->setAlignment( AlignVCenter | AlignHCenter );
-	volumeLbl->setBackgroundPixmap( textBackground );
-	volumeLbl->setFont( font1 );
-	QToolTip::add( volumeLbl, trUtf8( "Peak volume" ) );
+	m_pVolumeLbl = new QLabel( this );
+	m_pVolumeLbl->move( 2, MIXERLINE_LABEL_H );
+	m_pVolumeLbl->resize( 38, 20 );
+	m_pVolumeLbl->setText( "0.0" );
+	m_pVolumeLbl->setAlignment( AlignVCenter | AlignHCenter );
+	m_pVolumeLbl->setBackgroundPixmap( textBackground );
+	m_pVolumeLbl->setFont( font1 );
+	QToolTip::add( m_pVolumeLbl, trUtf8( "Peak volume" ) );
 
 	// instrument name widget
-	nameWidget = new InstrumentNameWidget( this );
-	nameWidget->move( 2, MIXERLINE_FADER_H );
-	QToolTip::add( nameWidget, trUtf8( "Instrument name (double click to edit)" ) );
-	connect( nameWidget, SIGNAL( doubleClicked () ), this, SLOT( nameClicked() ) );
-	connect( nameWidget, SIGNAL( clicked () ), this, SLOT( nameSelected() ) );
+	m_pNameWidget = new InstrumentNameWidget( this );
+	m_pNameWidget->move( 2, MIXERLINE_FADER_H );
+	QToolTip::add( m_pNameWidget, trUtf8( "Instrument name (double click to edit)" ) );
+	connect( m_pNameWidget, SIGNAL( doubleClicked () ), this, SLOT( nameClicked() ) );
+	connect( m_pNameWidget, SIGNAL( clicked () ), this, SLOT( nameSelected() ) );
 
-	// fader
-	fader = new Fader(this);
-	fader->move( 22, MIXERLINE_FADER_H );
-	connect( fader, SIGNAL( valueChanged(Fader*) ), this, SLOT( faderChanged(Fader*) ) );
+	// m_pFader
+	m_pFader = new Fader(this);
+	m_pFader->move( 22, MIXERLINE_FADER_H );
+	connect( m_pFader, SIGNAL( valueChanged(Fader*) ), this, SLOT( faderChanged(Fader*) ) );
 }
 
 
 
-
-/**
- *
- */
 MixerLine::~MixerLine() {
 //	cout << "MixerLine destroy" << endl;
-	delete fader;
+	delete m_pFader;
 	delete m_pMixerLineBackground;
 	m_pMixerLineBackground = NULL;
 }
 
 
 
-
-/**
- *
- */
 void MixerLine::updateMixerLine() {
-	fader->updateFader();
-	panFader->updateFader();
+	m_pFader->updateFader();
+	m_pPanFader->updateFader();
 
 	for (uint nFX = 0; nFX < MAX_FX; nFX++) {
 		m_pKnob[nFX]->updateKnob();
@@ -199,41 +197,27 @@ void MixerLine::updateMixerLine() {
 
 
 
-
-
-/**
- *
- */
 void MixerLine::click(Button *ref) {
 	Song *song = (Hydrogen::getInstance())->getSong();
 
-	if (ref == muteBtn) {
+	if (ref == m_pMuteBtn) {
 		song->setModified(true);
 		emit muteBtnClicked(this);
 	}
-	else if (ref == soloBtn) {
+	else if (ref == m_pSoloBtn) {
 		song->setModified(true);
 		emit soloBtnClicked(this);
 	}
-	else if (ref == loadBtn) {
-		song->setModified(true);
-		emit loadBtnClicked(this);
-	}
-	else if (ref == playSampleBtn) {
+	else if (ref == m_pPlaySampleBtn) {
 		emit noteOnClicked(this);
 	}
 }
 
 
 
-
-
-/**
- *
- */
 void MixerLine::rightClick(Button *ref)
 {
-	if (ref == playSampleBtn) {
+	if (ref == m_pPlaySampleBtn) {
 		emit noteOffClicked(this);
 	}
 
@@ -241,134 +225,97 @@ void MixerLine::rightClick(Button *ref)
 
 
 
-/**
- *
- */
 void MixerLine::faderChanged(Fader *ref) {
-	maxPeak = 0.0f;
+	m_fMaxPeak = 0.0f;
 	char tmp[20];
-	sprintf(tmp, "%#.1f", maxPeak);
-	volumeLbl->setText(tmp);
+	sprintf(tmp, "%#.1f", m_fMaxPeak);
+	m_pVolumeLbl->setText(tmp);
 
 	Song *song = (Hydrogen::getInstance())->getSong();
 	song->setModified(true);
 	emit volumeChanged(this);
 
-	char faderPos[100];
+	char m_pFaderPos[100];
 	float value = ref->getValue() / 100.0f;
-	sprintf( faderPos, "%#.2f",  value);
-	( HydrogenApp::getInstance() )->setStatusBarMessage( trUtf8( "Set instrument volume [%1]" ).arg( faderPos ), 2000 );
+	sprintf( m_pFaderPos, "%#.2f",  value);
+	( HydrogenApp::getInstance() )->setStatusBarMessage( trUtf8( "Set instrument volume [%1]" ).arg( m_pFaderPos ), 2000 );
 }
 
 
 
-
-
-/**
- *
- */
 bool MixerLine::isMuteClicked() {
-	return muteBtn->isPressed();
+	return m_pMuteBtn->isPressed();
 }
 
 
 
-
-
-/**
- *
- */
 void MixerLine::setMuteClicked(bool isClicked) {
-	muteBtn->setPressed(isClicked);
+	m_pMuteBtn->setPressed(isClicked);
 }
 
 
 
-
-/**
- *
- */
 bool MixerLine::isSoloClicked() {
-	return soloBtn->isPressed();
+	return m_pSoloBtn->isPressed();
 }
 
 
 
-
-/**
- *
- */
 void MixerLine::setSoloClicked(bool isClicked) {
-	soloBtn->setPressed(isClicked);
+	m_pSoloBtn->setPressed(isClicked);
 }
 
 
 
-
-/**
- *
- */
 float MixerLine::getVolume() {
-	return (fader->getValue() / 100.0);
+	return (m_pFader->getValue() / 100.0);
 }
 
 
 
-/**
- *
- */
 void MixerLine::setVolume(float value) {
-	fader->setValue((int)(value * 100.0));
+	m_pFader->setValue((int)(value * 100.0));
 }
 
 
 
 void MixerLine::setPeak_L( float peak ) {
 	if (peak != getPeak_L() ) {
-		fader->setPeak_L( peak );
-		if (peak > maxPeak) {
+		m_pFader->setPeak_L( peak );
+		if (peak > m_fMaxPeak) {
 			char tmp[20];
 			sprintf(tmp, "%#.1f", peak);
-			volumeLbl->setText(tmp);
-			maxPeak = peak;
+			m_pVolumeLbl->setText(tmp);
+			m_fMaxPeak = peak;
 		}
 	}
 }
 
 
 
-/**
- *
- */
 float MixerLine::getPeak_L() {
-	return fader->getPeak_L();
+	return m_pFader->getPeak_L();
 }
 
 
 
 
-/**
- *
- */
 void MixerLine::setPeak_R( float peak ) {
 	if (peak != getPeak_R() ) {
-		fader->setPeak_R( peak );
-		if (peak > maxPeak) {
+		m_pFader->setPeak_R( peak );
+		if (peak > m_fMaxPeak) {
 			char tmp[20];
 			sprintf(tmp, "%#.1f", peak);
-			volumeLbl->setText(tmp);
-			maxPeak = peak;
+			m_pVolumeLbl->setText(tmp);
+			m_fMaxPeak = peak;
 		}
 	}
 }
 
 
 
-/**
- *
- */
 float MixerLine::getPeak_R() {
-	return fader->getPeak_R();
+	return m_pFader->getPeak_R();
 }
 
 
@@ -380,6 +327,7 @@ void MixerLine::nameClicked() {
 }
 
 
+
 void MixerLine::nameSelected() {
 	emit instrumentNameSelected(this);
 }
@@ -388,9 +336,6 @@ void MixerLine::nameSelected() {
 
 
 
-/**
- *
- */
 void MixerLine::panFaderChanged(PanFader *ref) {
 	Song *song = ( Hydrogen::getInstance() )->getSong();
 	song->setModified( true );
@@ -400,12 +345,12 @@ void MixerLine::panFaderChanged(PanFader *ref) {
 	float pan_L = (100.0 - panValue) / 100.0;
 	float pan_R = panValue / 100.0;
 
-	char faderPos[100];
-	sprintf( faderPos, "%#.2fL, %#.2fR",  pan_L, pan_R);
-	( HydrogenApp::getInstance() )->setStatusBarMessage( trUtf8( "Set instrument pan [%1]" ).arg( faderPos ), 2000 );
+	char m_pFaderPos[100];
+	sprintf( m_pFaderPos, "%#.2fL, %#.2fR",  pan_L, pan_R);
+	( HydrogenApp::getInstance() )->setStatusBarMessage( trUtf8( "Set instrument pan [%1]" ).arg( m_pFaderPos ), 2000 );
 
-	QToolTip::remove( panFader );
-	QToolTip::add( panFader, QString("Pan ") + QString( faderPos ) );
+	QToolTip::remove( m_pPanFader );
+	QToolTip::add( m_pPanFader, QString("Pan ") + QString( m_pFaderPos ) );
 
 }
 
@@ -413,34 +358,28 @@ void MixerLine::panFaderChanged(PanFader *ref) {
 
 
 
-/**
- *
- */
 int MixerLine::getPan() {
-	return (int)( panFader->getValue() );
+	return (int)( m_pPanFader->getValue() );
 }
 
 
 
-/**
- *
- */
 void MixerLine::setPan(int value) {
-	if ( value != panFader->getValue() ) {
-		panFader->setValue( value );
+	if ( value != m_pPanFader->getValue() ) {
+		m_pPanFader->setValue( value );
 
 		float pan_L = (100.0 - value) / 100.0;
 		float pan_R = value / 100.0;
-		char faderPos[100];
-		sprintf( faderPos, "Pan %#.2fL, %#.2fR",  pan_L, pan_R);
-		QToolTip::remove( panFader );
-		QToolTip::add( panFader, QString( faderPos ) );
+		char m_pFaderPos[100];
+		sprintf( m_pFaderPos, "Pan %#.2fL, %#.2fR",  pan_L, pan_R);
+		QToolTip::remove( m_pPanFader );
+		QToolTip::add( m_pPanFader, QString( m_pFaderPos ) );
 	}
 }
 
 
 void MixerLine::setPlayClicked( bool clicked ) {
-	playSampleBtn->setPressed( clicked );
+	m_pPlaySampleBtn->setPressed( clicked );
 }
 
 
@@ -489,12 +428,13 @@ void MixerLine::setSelected( bool bIsSelected )
 
 
 
-/////////////
 
 
-/**
- * Constructor
- */
+// ::::::::::::::::::::::::::::
+
+
+
+
 MasterMixerLine::MasterMixerLine(QWidget* parent) : QWidget(parent), Object( "MasterMixerLine" )
 {
 //	cout << "mixerLine init" << endl;
@@ -507,11 +447,11 @@ MasterMixerLine::MasterMixerLine(QWidget* parent) : QWidget(parent), Object( "Ma
 
 	// Background image
 	string background_path = string(IMG_PATH).append("/img/mixerPanel/mixerline_background.png");
-	bool ok = background.load(background_path.c_str());
+	bool ok = m_background.load(background_path.c_str());
 	if( ok == false ){
 		errorLog( string("Error loading pixmap ") + background_path );
 	}
-	setBackgroundPixmap(background);
+	setBackgroundPixmap(m_background);
 
 	// MixerLine LABEL Background image
 	QPixmap mixerLineLabelBackground;
@@ -530,105 +470,88 @@ MasterMixerLine::MasterMixerLine(QWidget* parent) : QWidget(parent), Object( "Ma
 	}
 
 
-	PreferencesMng *pref = PreferencesMng::getInstance();
+	Preferences *pref = Preferences::getInstance();
 	int size = pref->getMixerFontPointSize();
 	QString family = pref->getMixerFontFamily().c_str();
 	QFont font1( family, size );
 	// peak volume label
-	leftVolumeLbl = new QLabel(this);
-	leftVolumeLbl->move( 2, MIXERLINE_LABEL_H );
-	leftVolumeLbl->resize( 38, 20 );
-	leftVolumeLbl->setText( "0.0" );
-	leftVolumeLbl->setAlignment( AlignVCenter | AlignHCenter );
-	leftVolumeLbl->setBackgroundPixmap( textBackground );
-	leftVolumeLbl->setFont( font1 );
-	QToolTip::add( leftVolumeLbl, trUtf8( "Peak volume (left channel)" ) );
+	m_pLeftVolumeLbl = new QLabel(this);
+	m_pLeftVolumeLbl->move( 2, MIXERLINE_LABEL_H );
+	m_pLeftVolumeLbl->resize( 38, 20 );
+	m_pLeftVolumeLbl->setText( "0.0" );
+	m_pLeftVolumeLbl->setAlignment( AlignVCenter | AlignHCenter );
+	m_pLeftVolumeLbl->setBackgroundPixmap( textBackground );
+	m_pLeftVolumeLbl->setFont( font1 );
+	QToolTip::add( m_pLeftVolumeLbl, trUtf8( "Peak volume (left channel)" ) );
 
-	fader = new Fader( this );
-	fader->move( 22, MIXERLINE_FADER_H );
-	connect( fader, SIGNAL( valueChanged(Fader*) ), this, SLOT( faderChanged(Fader*) ) );
+	m_pFader = new Fader( this );
+	m_pFader->move( 22, MIXERLINE_FADER_H );
+	connect( m_pFader, SIGNAL( valueChanged(Fader*) ), this, SLOT( faderChanged(Fader*) ) );
 
 	QFont mixerFont( family, size );
 
-	InstrumentNameWidget *nameWidget;
+	InstrumentNameWidget *m_pNameWidget;
 	// instrument name widget
-	nameWidget = new InstrumentNameWidget( this );
-	nameWidget->move( 2, MIXERLINE_FADER_H );
-	nameWidget->setText( trUtf8( "Master output" ) );
+	m_pNameWidget = new InstrumentNameWidget( this );
+	m_pNameWidget->move( 2, MIXERLINE_FADER_H );
+	m_pNameWidget->setText( trUtf8( "Master output" ) );
 }
 
 
 
 
-/**
- *
- */
 MasterMixerLine::~MasterMixerLine() {
 //	cout << "MixerLine destroy" << endl;
-	maxPeak = 0.0;
+	m_fMaxPeak = 0.0;
 }
 
 
 
 
-
-/**
- *
- */
 void MasterMixerLine::faderChanged(Fader *ref) {
-	maxPeak = 0.0;
+	m_fMaxPeak = 0.0;
 
 	char tmp[20];
-	sprintf(tmp, "%#.1f", maxPeak);
-	leftVolumeLbl->setText(tmp);
-	fader->setValue(ref->getValue());
+	sprintf(tmp, "%#.1f", m_fMaxPeak);
+	m_pLeftVolumeLbl->setText(tmp);
+	m_pFader->setValue(ref->getValue());
 
 	emit volumeChanged(this);
 
 	Song *song = (Hydrogen::getInstance())->getSong();
 	song->setModified(true);
 
-	char faderPos[100];
+	char m_pFaderPos[100];
 	float value = ref->getValue() / 100.0;
-	sprintf( faderPos, "%#.2f",  value);
-	( HydrogenApp::getInstance() )->setStatusBarMessage( trUtf8( "Set master volume [%1]" ).arg( faderPos ), 2000 );
+	sprintf( m_pFaderPos, "%#.2f",  value);
+	( HydrogenApp::getInstance() )->setStatusBarMessage( trUtf8( "Set master volume [%1]" ).arg( m_pFaderPos ), 2000 );
 
 }
 
 
 
 
-/**
- *
- */
 float MasterMixerLine::getVolume() {
-	return (fader->getValue() / 100.0);
+	return (m_pFader->getValue() / 100.0);
 }
 
 
 
-/**
- *
- */
 void MasterMixerLine::setVolume(float value) {
-	fader->setValue((int)(value * 100.0));
+	m_pFader->setValue((int)(value * 100.0));
 //	rightFader->setValue((int)(value * 100.0));
 }
 
 
 
-
-/**
- *
- */
 void MasterMixerLine::setPeak_L(float peak) {
 	if ( peak != getPeak_L() ) {
-		fader->setPeak_L(peak);
-		if (peak > maxPeak) {
+		m_pFader->setPeak_L(peak);
+		if (peak > m_fMaxPeak) {
 			char tmp[20];
 			sprintf(tmp, "%#.1f", peak);
-			leftVolumeLbl->setText(tmp);
-			maxPeak = peak;
+			m_pLeftVolumeLbl->setText(tmp);
+			m_fMaxPeak = peak;
 		}
 	}
 }
@@ -636,50 +559,34 @@ void MasterMixerLine::setPeak_L(float peak) {
 
 
 
-/**
- *
- */
 float MasterMixerLine::getPeak_L() {
-	return fader->getPeak_L();
+	return m_pFader->getPeak_L();
 }
 
 
 
-
-/**
- *
- */
 void MasterMixerLine::setPeak_R(float peak) {
 	if ( peak != getPeak_R() ) {
-		fader->setPeak_R(peak);
-		if (peak > maxPeak) {
+		m_pFader->setPeak_R(peak);
+		if (peak > m_fMaxPeak) {
 			char tmp[20];
 			sprintf(tmp, "%#.1f", peak);
-			leftVolumeLbl->setText(tmp);
-			maxPeak = peak;
+			m_pLeftVolumeLbl->setText(tmp);
+			m_fMaxPeak = peak;
 		}
 	}
 }
 
 
 
-
-
-/**
- *
- */
 float MasterMixerLine::getPeak_R() {
-	return fader->getPeak_R();
+	return m_pFader->getPeak_R();
 }
 
 
 
-
-/**
- *
- */
 void MasterMixerLine::updateMixerLine() {
-	fader->updateFader();
+	m_pFader->updateFader();
 }
 
 
@@ -688,10 +595,6 @@ void MasterMixerLine::updateMixerLine() {
 /////////////////////////////////////////
 
 
-
-/**
- * Constructor
- */
 FxMixerLine::FxMixerLine(QWidget* parent) : QWidget(parent), Object( "FxMixerLine" )
 {
 //	cout << "mixerLine init" << endl;
@@ -703,15 +606,15 @@ FxMixerLine::FxMixerLine(QWidget* parent) : QWidget(parent), Object( "FxMixerLin
 	setMaximumSize( m_nWidth, m_nHeight );
 	resize( m_nWidth, m_nHeight );
 
-	maxPeak = 0.0;
+	m_fMaxPeak = 0.0;
 
 	// MixerLine Background image
 	string mixerLineBackground_path = string(IMG_PATH).append("/img/mixerPanel/mixerline_background.png");
-	bool ok = mixerLineBackground.load(mixerLineBackground_path.c_str());
+	bool ok = m_mixerLineBackground.load(mixerLineBackground_path.c_str());
 	if( ok == false ){
 		errorLog( string("Error loading pixmap ") + mixerLineBackground_path );
 	}
-	setBackgroundPixmap(mixerLineBackground);
+	setBackgroundPixmap(m_mixerLineBackground);
 
 	// MixerLine LABEL Background image
 	QPixmap mixerLineLabelBackground;
@@ -738,52 +641,43 @@ FxMixerLine::FxMixerLine(QWidget* parent) : QWidget(parent), Object( "FxMixerLin
 	QToolTip::add( activeBtn, trUtf8( "FX on/off") );
 	connect( activeBtn, SIGNAL( clicked(Button*) ), this, SLOT( click(Button*) ) );
 
-	PreferencesMng *pref = PreferencesMng::getInstance();
+	Preferences *pref = Preferences::getInstance();
 
 	// peak volume label
 	QString family = pref->getMixerFontFamily().c_str();
 	int size = pref->getMixerFontPointSize();
 	QFont font1( family, size);
-	volumeLbl = new QLabel( this );
-	volumeLbl->move( 2, MIXERLINE_LABEL_H );
-	volumeLbl->resize( 38, 18 );
-	volumeLbl->setText( "0.0" );
-	volumeLbl->setAlignment( AlignVCenter | AlignHCenter );
-	volumeLbl->setBackgroundPixmap( textBackground );
-	volumeLbl->setFont( font1 );
-//	QToolTip::add( volumeLbl, "Peak volume" );
+	m_pVolumeLbl = new QLabel( this );
+	m_pVolumeLbl->move( 2, MIXERLINE_LABEL_H );
+	m_pVolumeLbl->resize( 38, 18 );
+	m_pVolumeLbl->setText( "0.0" );
+	m_pVolumeLbl->setAlignment( AlignVCenter | AlignHCenter );
+	m_pVolumeLbl->setBackgroundPixmap( textBackground );
+	m_pVolumeLbl->setFont( font1 );
+//	QToolTip::add( m_pVolumeLbl, "Peak volume" );
 
-	// fader
-	fader = new Fader( this );
-	fader->move( 22, MIXERLINE_FADER_H );
-	connect( fader, SIGNAL( valueChanged(Fader*) ), this, SLOT( faderChanged(Fader*) ) );
+	// m_pFader
+	m_pFader = new Fader( this );
+	m_pFader->move( 22, MIXERLINE_FADER_H );
+	connect( m_pFader, SIGNAL( valueChanged(Fader*) ), this, SLOT( faderChanged(Fader*) ) );
 
 	QFont mixerFont( family, size );
 
 
-	nameWidget = new InstrumentNameWidget( this );
-	nameWidget->move( 2, MIXERLINE_FADER_H );
-	nameWidget->setText( trUtf8( "Master output" ) );
+	m_pNameWidget = new InstrumentNameWidget( this );
+	m_pNameWidget->move( 2, MIXERLINE_FADER_H );
+	m_pNameWidget->setText( trUtf8( "Master output" ) );
 }
 
 
 
-
-/**
- *
- */
 FxMixerLine::~FxMixerLine() {
 //	cout << "MixerLine destroy" << endl;
-	delete fader;
+	delete m_pFader;
 }
 
 
 
-
-
-/**
- *
- */
 void FxMixerLine::click(Button *ref) {
 	Song *song = (Hydrogen::getInstance())->getSong();
 
@@ -795,15 +689,11 @@ void FxMixerLine::click(Button *ref) {
 
 
 
-
-/**
- *
- */
 void FxMixerLine::faderChanged(Fader *ref) {
-	maxPeak = 0.0;
+	m_fMaxPeak = 0.0;
 	char tmp[20];
-	sprintf( tmp, "%#.1f", maxPeak );
-	volumeLbl->setText( tmp );
+	sprintf( tmp, "%#.1f", m_fMaxPeak );
+	m_pVolumeLbl->setText( tmp );
 
 	Song *song = ( Hydrogen::getInstance() )->getSong();
 	song->setModified( true );
@@ -813,67 +703,47 @@ void FxMixerLine::faderChanged(Fader *ref) {
 
 
 
-
-/**
- *
- */
 float FxMixerLine::getVolume() {
-	return (fader->getValue() / 100.0);
+	return (m_pFader->getValue() / 100.0);
 }
 
 
 
-
-
-/**
- *
- */
 void FxMixerLine::setVolume( float value ) {
-	fader->setValue( (int)(value * 100.0) );
+	m_pFader->setValue( (int)(value * 100.0) );
 }
 
 
 
-
-/**
- *
- */
 void FxMixerLine::setPeak_L( float peak ) {
 	if (peak != getPeak_L() ) {
-		fader->setPeak_L( peak );
-		if (peak > maxPeak) {
+		m_pFader->setPeak_L( peak );
+		if (peak > m_fMaxPeak) {
 			char tmp[20];
 			sprintf(tmp, "%#.1f", peak);
-			volumeLbl->setText(tmp);
-			maxPeak = peak;
+			m_pVolumeLbl->setText(tmp);
+			m_fMaxPeak = peak;
 		}
 	}
 }
 
 
 
-/**
- *
- */
 float FxMixerLine::getPeak_L() {
-	return fader->getPeak_L();
+	return m_pFader->getPeak_L();
 }
 
 
 
 
-
-/**
- *
- */
 void FxMixerLine::setPeak_R(float peak) {
 	if (peak != getPeak_R() ) {
-		fader->setPeak_R( peak );
-		if (peak > maxPeak) {
+		m_pFader->setPeak_R( peak );
+		if (peak > m_fMaxPeak) {
 			char tmp[20];
 			sprintf(tmp, "%#.1f", peak);
-			volumeLbl->setText(tmp);
-			maxPeak = peak;
+			m_pVolumeLbl->setText(tmp);
+			m_fMaxPeak = peak;
 		}
 	}
 }
@@ -881,12 +751,8 @@ void FxMixerLine::setPeak_R(float peak) {
 
 
 
-
-/**
- *
- */
 float FxMixerLine::getPeak_R() {
-	return fader->getPeak_R();
+	return m_pFader->getPeak_R();
 }
 
 
@@ -905,11 +771,8 @@ void FxMixerLine::setFxActive( bool active ) {
 
 
 
-/**
- *
- */
 void FxMixerLine::updateMixerLine() {
-	fader->updateFader();
+	m_pFader->updateFader();
 }
 
 
@@ -930,7 +793,7 @@ InstrumentNameWidget::InstrumentNameWidget(QWidget* parent)  : QWidget(parent),
 	m_nWidgetWidth = 18;
 	m_nWidgetHeight = 100;
 
-	PreferencesMng *pref = PreferencesMng::getInstance();
+	Preferences *pref = Preferences::getInstance();
 	QString family = pref->getMixerFontFamily().c_str();
 	int size = pref->getMixerFontPointSize();
 	m_mixerFont.setFamily( family );
@@ -954,6 +817,8 @@ InstrumentNameWidget::InstrumentNameWidget(QWidget* parent)  : QWidget(parent),
 }
 
 
+
+
 InstrumentNameWidget::~InstrumentNameWidget()
 {
 //	infoLog( "DESTROY" );
@@ -998,31 +863,32 @@ void InstrumentNameWidget::setText( QString text )
 	}
 }
 
+
+
 QString InstrumentNameWidget::text()
 {
 	return m_sInstrName;
 }
 
 
+
 void InstrumentNameWidget::mousePressEvent( QMouseEvent * e ) {
 	emit clicked();
 }
 
+
+
 void InstrumentNameWidget::mouseDoubleClickEvent( QMouseEvent * e ) {
 	emit doubleClicked();
 }
 
 
 
-/////////////
+// :::::::::::::::::::::
 
 
 
 
-
-
-////////////////
-
 QPixmap* LadspaFXMixerLine::m_pMixerLineBackground = NULL;
 
 LadspaFXMixerLine::LadspaFXMixerLine(QWidget* parent) : QWidget( parent ), Object( "LadspaFXMixerLine" )
@@ -1070,7 +936,7 @@ LadspaFXMixerLine::LadspaFXMixerLine(QWidget* parent) : QWidget( parent ), Objec
 	QToolTip::add( m_pNameWidget, trUtf8( "Ladspa FX name (double click to change FX)" ) );
 	connect( m_pNameWidget, SIGNAL( doubleClicked () ), this, SLOT( nameClicked() ) );
 
-	// fader
+	// m_pFader
 	m_pFader = new Fader(this);
 	m_pFader->move( 22, MIXERLINE_FADER_H );
 	connect( m_pFader, SIGNAL( valueChanged(Fader*) ), this, SLOT( faderChanged(Fader*) ) );
@@ -1078,6 +944,7 @@ LadspaFXMixerLine::LadspaFXMixerLine(QWidget* parent) : QWidget( parent ), Objec
 }
 
 
+
 LadspaFXMixerLine::~LadspaFXMixerLine()
 {
 //	infoLog( "DESTROY" );
@@ -1094,9 +961,7 @@ void LadspaFXMixerLine::nameClicked()
 }
 
 
-/**
- *
- */
+
 void LadspaFXMixerLine::click(Button *ref) {
 	if ( ref == m_pActiveBtn ) {
 		emit activeBtnClicked( this );
@@ -1123,10 +988,10 @@ void LadspaFXMixerLine::setFxActive( bool active ) {
 
 void LadspaFXMixerLine::faderChanged(Fader *ref) {
 	m_fMaxPeak = 0.0;
-// FIXME: aggiungere il volumeLabel
+/// \todo aggiungere il volumeLabel
 //	char tmp[20];
 //	sprintf(tmp, "%#.1f", fMaxPeak);
-//	volumeLbl->setText(tmp);
+//	m_pVolumeLbl->setText(tmp);
 
 	Song *song = (Hydrogen::getInstance())->getSong();
 	song->setModified(true);
@@ -1134,6 +999,7 @@ void LadspaFXMixerLine::faderChanged(Fader *ref) {
 }
 
 
+
 void LadspaFXMixerLine::setPeaks( float fPeak_L, float fPeak_R )
 {
 	m_pFader->setPeak_L( fPeak_L );
@@ -1142,6 +1008,7 @@ void LadspaFXMixerLine::setPeaks( float fPeak_L, float fPeak_R )
 }
 
 
+
 void LadspaFXMixerLine::getPeaks( float *fPeak_L, float *fPeak_R )
 {
 	(*fPeak_L) = m_pFader->getPeak_L();
@@ -1149,18 +1016,13 @@ void LadspaFXMixerLine::getPeaks( float *fPeak_L, float *fPeak_R )
 }
 
 
-/**
- *
- */
+
 float LadspaFXMixerLine::getVolume() {
 	return (m_pFader->getValue() / 100.0);
 }
 
 
 
-/**
- *
- */
 void LadspaFXMixerLine::setVolume(float value) {
 	m_pFader->setValue((int)(value * 100.0));
 	m_pFader->updateFader();
@@ -1168,4 +1030,3 @@ void LadspaFXMixerLine::setVolume(float value) {
 
 
 
-
