@@ -18,30 +18,36 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: PatternEditorPanel.cpp,v 1.55 2004/02/20 14:09:13 comix Exp $
+ * $Id: PatternEditorPanel.cpp,v 1.68 2004/09/06 09:41:49 comix Exp $
  *
  */
 
 
 #include "PatternEditorPanel.h"
+#include "MainForm.h"
+#include "Button.h"
+#include "Fader.h"
 
-#include "lib/PreferencesMng.h"
+#include "lib/Preferences.h"
 #include "lib/Hydrogen.h"
 
 #include <cmath>
 
-/**
- * Constructor
- */
-PatternEditorPanel::PatternEditorPanel(QWidget *parent) : QWidget(parent)
+#include "qlabel.h"
+#include "qcombobox.h"
+
+
+PatternEditorPanel::PatternEditorPanel( QWidget *parent )
+  : QWidget(parent)
+  , Object("PatEditPanel")
+  , m_pPattern( NULL )
 {
-//	cout << "PatternEditorPanel INIT" << endl;
-
+	//infoLog("INIT");
 	m_nPanelWidth = 706;
-	m_nPanelHeight = 302;
+	m_nPanelHeight = 352;
 
-	int nMaxHeight = 494;
-	m_nSelectedInstrument = 0;
+	int nMaxHeight = 544;
+	nMaxHeight = 850;
 
 	setMinimumSize( 200, 200 );
 	setMaximumSize( m_nPanelWidth, nMaxHeight );
@@ -51,7 +57,14 @@ PatternEditorPanel::PatternEditorPanel(QWidget *parent) : QWidget(parent)
 	setCaption( trUtf8( "Pattern Editor" ) );
 	setIcon( QPixmap( QString(IMG_PATH) + QString( "/img/icon32.png") ) );
 
+	bool bUseBackground = false;
 
+	// Load background image
+	string background_path = string(IMG_PATH) + string("/img/patternEditor/patternEditor_background.png");
+	bool ok = m_backgroundPixmap.load(background_path.c_str());
+	if ( ok == false ) {
+		errorLog( "[PatternEditorPanel] Error loading pixmap" );
+	}
 
 
 
@@ -64,10 +77,10 @@ PatternEditorPanel::PatternEditorPanel(QWidget *parent) : QWidget(parent)
 	m_pRulerScrollView->setHScrollBarMode( QScrollView::AlwaysOff );
 
 	// Ruler frame
-	m_pRulerFrame = new QFrame( m_pRulerScrollView->viewport() );
+	QFrame* m_pRulerFrame = new QFrame( m_pRulerScrollView->viewport() );
 
 	// Ruler
-	m_pPatternEditorRuler = new PatternEditorRuler( m_pRulerFrame );
+	m_pPatternEditorRuler = new PatternEditorRuler( m_pRulerFrame, this );
 	m_pPatternEditorRuler->move( 0, 0 );
 
 	m_pRulerFrame->resize( m_pPatternEditorRuler->width(), m_pPatternEditorRuler->height() );
@@ -99,7 +112,6 @@ PatternEditorPanel::PatternEditorPanel(QWidget *parent) : QWidget(parent)
 	m_pEditorFrame->resize( m_pPatternEditor->width(), m_pPatternEditor->height() );
 	m_pEditorScrollView->addChild( m_pEditorFrame );
 
-
 	QScrollBar *pEditorVScroll = m_pEditorScrollView->verticalScrollBar();
 	connect( pEditorVScroll , SIGNAL(valueChanged(int)), this, SLOT( contentsMoving(int) ) );
 
@@ -110,6 +122,7 @@ PatternEditorPanel::PatternEditorPanel(QWidget *parent) : QWidget(parent)
 
 
 	// INSTRUMENT LIST________________________________________
+
 	// Instrument list scrollview
 	m_pInstrListScrollView = new QScrollView( this );
 	m_pInstrListScrollView->setFrameShape( QFrame::NoFrame );
@@ -118,17 +131,15 @@ PatternEditorPanel::PatternEditorPanel(QWidget *parent) : QWidget(parent)
 	m_pInstrListScrollView->move( 5, 45 );
 
 	// Instrument list frame
-	m_pInstrListFrame = new QFrame( m_pInstrListScrollView->viewport() );
+	QFrame* m_pInstrListFrame = new QFrame( m_pInstrListScrollView->viewport() );
 
 	// Instrument list
-	m_pInstrumentList = new PatternEditorInstrumentList( m_pInstrListFrame, m_pPatternEditor, this );
+	m_pInstrumentList = new PatternEditorInstrumentList( m_pInstrListFrame, this );
 	m_pInstrumentList->move( 0, 0 );
 
 	m_pInstrListFrame->resize( m_pInstrumentList->width(), m_pPatternEditor->height() );
 	m_pInstrListScrollView->addChild( m_pInstrListFrame );
 
-	m_pPatternEditor->setPatternEditorInstrumentList( m_pInstrumentList );
-
 	QScrollBar *pInstrListVScroll = m_pInstrListScrollView->verticalScrollBar();
 	connect( pInstrListVScroll , SIGNAL(valueChanged(int)), this, SLOT( contentsMoving(int) ) );
 
@@ -138,26 +149,23 @@ PatternEditorPanel::PatternEditorPanel(QWidget *parent) : QWidget(parent)
 
 
 
-	// VELOCITY RULER______________________________________________
-	m_pVelocityRulerScrollView = new QScrollView( this );
-	m_pVelocityRulerScrollView->setFrameShape( QFrame::NoFrame );
-	m_pVelocityRulerScrollView->setVScrollBarMode( QScrollView::AlwaysOff );
-	m_pVelocityRulerScrollView->setHScrollBarMode( QScrollView::AlwaysOff );
-	m_pVelocityRulerScrollView->move( 5, 600 );
+	// NOTE PROPERTIES RULER______________________________________________
 
+	m_pNotePropertiesScrollView = new QScrollView( this );
+	m_pNotePropertiesScrollView->setFrameShape( QFrame::NoFrame );
+	m_pNotePropertiesScrollView->setVScrollBarMode( QScrollView::AlwaysOff );
+	m_pNotePropertiesScrollView->setHScrollBarMode( QScrollView::AlwaysOff );
+	m_pNotePropertiesScrollView->move( 5, 600 );
 
-	m_pVelocityRulerFrame = new QFrame( m_pVelocityRulerScrollView->viewport() );
+	QFrame* m_pNotePropertiesFrame = new QFrame( m_pNotePropertiesScrollView->viewport() );
 
+	m_pNotePropertiesRuler = new NotePropertiesRuler( m_pNotePropertiesFrame, this );
+	m_pNotePropertiesRuler->move(0,0);
 
-	m_pVelocityRuler = new PatternEditorVelocityRuler( m_pVelocityRulerFrame, m_pPatternEditor, this );
-	m_pVelocityRuler->move(0,0);
+	m_pNotePropertiesFrame->resize( m_pNotePropertiesRuler->width(), m_pNotePropertiesRuler->height() );
 
-	m_pVelocityRulerFrame->resize( m_pVelocityRuler->width(), m_pVelocityRuler->height() );
+	m_pNotePropertiesScrollView->addChild( m_pNotePropertiesFrame );
 
-	m_pVelocityRulerScrollView->addChild( m_pVelocityRulerFrame );
-
-
-	m_pPatternEditor->setPatternEditorVelocityRuler( m_pVelocityRuler );
 	//_____________________________________________________________
 
 
@@ -177,23 +185,10 @@ PatternEditorPanel::PatternEditorPanel(QWidget *parent) : QWidget(parent)
 
 
 
-	// Background image
-	string background_path = string(IMG_PATH) + string("/img/patternEditor/patternEditor_background.png");
-	bool ok = background.load(background_path.c_str());
-	if( ok == false ){
-		qWarning( "PatternEditorPanel: Error loading pixmap" );
-	}
-	setBackgroundPixmap(background);
-
-
-
-
 	QLabel *gridResolutionLbl = new QLabel(this);
 	gridResolutionLbl->setText(trUtf8( "Grid resolution" ));
 	gridResolutionLbl->move( 10, 5 );
 	gridResolutionLbl->resize( 100, 20 );
-	gridResolutionLbl->setBackgroundPixmap(background);
-
 
 	string hearBtn_on_path = string(IMG_PATH).append("/img/patternEditor/hearBtn_on.png");
 	string hearBtn_off_path = string(IMG_PATH).append("/img/patternEditor/hearBtn_off.png");
@@ -209,8 +204,6 @@ PatternEditorPanel::PatternEditorPanel(QWidget *parent) : QWidget(parent)
 	patternNameLbl->setText(trUtf8( "Pattern name") );
 	patternNameLbl->move( 284, 5 );
 	patternNameLbl->resize( 300, 20 );
-	patternNameLbl->setBackgroundPixmap(background);
-
 
 	// Grid resolution combo
 	gridResolutionCombo = new QComboBox( FALSE, this, "gridResolutionComboBox" );
@@ -219,7 +212,6 @@ PatternEditorPanel::PatternEditorPanel(QWidget *parent) : QWidget(parent)
 	gridResolutionCombo->insertItem( trUtf8( "16" ) );
 	gridResolutionCombo->insertItem( trUtf8( "32" ) );
 	gridResolutionCombo->insertItem( trUtf8( "64" ) );
-
 	gridResolutionCombo->insertItem( trUtf8( "4T" ) );	// triplets..
 	gridResolutionCombo->insertItem( trUtf8( "8T" ) );
 	gridResolutionCombo->insertItem( trUtf8( "16T" ) );
@@ -230,7 +222,7 @@ PatternEditorPanel::PatternEditorPanel(QWidget *parent) : QWidget(parent)
 	QToolTip::add( gridResolutionCombo, trUtf8( "Grid resolution" ) );
 	connect( gridResolutionCombo, SIGNAL( activated(const QString&) ), this, SLOT( gridResolutionChanged() ) );
 
-	PreferencesMng *pref = ( PreferencesMng::getInstance() );
+	Preferences *pref = ( Preferences::getInstance() );
 
 	// restore grid resolution
 	if ( pref->isPatternEditorUsingTriplets() == false ) {
@@ -325,6 +317,45 @@ PatternEditorPanel::PatternEditorPanel(QWidget *parent) : QWidget(parent)
 	QToolTip::add( quantizeEventsBtn, trUtf8( "Quantize keyboard/midi events to grid" ) );
 	connect( quantizeEventsBtn, SIGNAL(clicked(Button*)), this, SLOT( quantizeEventsBtnClick(Button*)));
 
+
+/*
+	// show velocity button
+	string sVelocityBtn_on_path = string(IMG_PATH).append("/img/patternEditor/quantBtn_on.png");
+	string sVelocityBtn_off_path = string(IMG_PATH).append("/img/patternEditor/quantBtn_off.png");
+	string sVelocityBtn_over_path = string(IMG_PATH).append("/img/patternEditor/quantBtn_over.png");
+	m_pShowVelocityBtn = new ToggleButton(this, QSize(40, 20), sVelocityBtn_on_path, sVelocityBtn_off_path, sVelocityBtn_over_path);
+	m_pShowVelocityBtn->move( 10, 600);
+	m_pShowVelocityBtn->setPressed( true );
+	QToolTip::add( m_pShowVelocityBtn, trUtf8( "Show velocity editor" ) );
+	connect( m_pShowVelocityBtn, SIGNAL(clicked(Button*)), this, SLOT( showVelocityBtnClick(Button*)));
+
+
+	// show pitch button
+	string sPitchBtn_on_path = string(IMG_PATH).append("/img/patternEditor/quantBtn_on.png");
+	string sPitchBtn_off_path = string(IMG_PATH).append("/img/patternEditor/quantBtn_off.png");
+	string sPitchBtn_over_path = string(IMG_PATH).append("/img/patternEditor/quantBtn_over.png");
+	m_pShowPitchBtn = new ToggleButton(this, QSize(40, 20), sPitchBtn_on_path, sPitchBtn_off_path, sPitchBtn_over_path);
+	m_pShowPitchBtn->move( 10, 630);
+	m_pShowPitchBtn->setPressed( false );
+	QToolTip::add( m_pShowPitchBtn, trUtf8( "Show pitch editor" ) );
+	connect( m_pShowPitchBtn, SIGNAL(clicked(Button*)), this, SLOT( showPitchBtnClick(Button*)));
+*/
+
+
+	if ( bUseBackground ) {
+		patternNameLbl->setBackgroundPixmap( m_backgroundPixmap );
+		gridResolutionLbl->setBackgroundPixmap( m_backgroundPixmap );
+		this->setBackgroundPixmap( m_backgroundPixmap );
+	}
+	else {
+		patternNameLbl->setEraseColor( QColor(131, 149, 180 ) );
+		gridResolutionLbl->setEraseColor( QColor(131, 149, 180 ) );
+		this->setEraseColor( QColor(131, 149, 180 ) );
+	}
+
+
+	setupPattern();
+
 	// we need to do all this to support the keyboard playing
 	// for all the window modes
 	pPatternSizeCombo->installEventFilter(HydrogenApp::getInstance()->getMainForm());
@@ -332,25 +363,71 @@ PatternEditorPanel::PatternEditorPanel(QWidget *parent) : QWidget(parent)
 
 	(Hydrogen::getInstance())->addEngineListener(this);
 
+	selectedPatternChanged(); // force an update
 }
 
 
 
 
-/**
- * Destructor
- */
 PatternEditorPanel::~PatternEditorPanel()
 {
+	(Hydrogen::getInstance())->removeEngineListener(this);
+	hide();
+	//infoLog("DESTROYING");
+
 	delete m_pPatternEditor;
 	delete m_pPatternEditorRuler;
 	delete m_pInstrumentList;
-	delete m_pVelocityRuler;
-//	cout << "PatternEditorPanel DESTROY" << endl;
+	delete m_pNotePropertiesRuler;
+	//infoLog("DESTROY");
 }
 
 
 
+void PatternEditorPanel::setupPattern()
+{
+	if (m_pPattern) {
+		string sCurrentPatternName = m_pPattern->getName();
+		this->setCaption( ( trUtf8( "Pattern editor - %1").arg(sCurrentPatternName.c_str()) ) );
+		patternNameLbl->setText( trUtf8( "Pattern name: <b>%1</b>").arg(sCurrentPatternName.c_str()) );
+
+		// update pattern size combobox
+		int nPatternSize = m_pPattern->getSize();
+		int nQuarter = MAX_NOTES / 8;
+		if (nPatternSize == nQuarter) {
+			pPatternSizeCombo->setCurrentItem( 0 );
+		}
+		else if (nPatternSize == nQuarter * 2) {
+			pPatternSizeCombo->setCurrentItem( 1 );
+		}
+		else if (nPatternSize == nQuarter * 3) {
+			pPatternSizeCombo->setCurrentItem( 2 );
+		}
+		else if ( nPatternSize == nQuarter * 4 ) {
+			pPatternSizeCombo->setCurrentItem( 3 );
+		}
+		else if ( nPatternSize == nQuarter * 5 ) {
+			pPatternSizeCombo->setCurrentItem( 4 );
+		}
+		else if ( nPatternSize == nQuarter * 6 ) {
+			pPatternSizeCombo->setCurrentItem( 5 );
+		}
+		else if ( nPatternSize == nQuarter * 7 ) {
+			pPatternSizeCombo->setCurrentItem( 6 );
+		}
+		else if ( nPatternSize == nQuarter * 8 ) {
+			pPatternSizeCombo->setCurrentItem( 7 );
+		}
+		else {
+			errorLog( "[setupPattern] unhandled case: nPatternSize = " + toString(nPatternSize) );
+		}
+	}
+	else {
+		this->setCaption( ( trUtf8( "Pattern editor - %1").arg(QString("NULL")) ) );
+		patternNameLbl->setText( trUtf8( "Pattern name: <b>%1</b>").arg(QString("NULL")) );
+	}
+}
+
 
 
 /**
@@ -390,7 +467,7 @@ void PatternEditorPanel::syncToExternalHorizontalScrollbar(int)
 
 	// Velocity ruler
 	nValue = m_pPatternEditorHScrollBar->value();
-	QScrollBar *pVelocityRulerHScroll = m_pVelocityRulerScrollView->horizontalScrollBar();
+	QScrollBar *pVelocityRulerHScroll = m_pNotePropertiesScrollView->horizontalScrollBar();
 	if ( pVelocityRulerHScroll->value() != nValue ) {
 		pVelocityRulerHScroll->setValue( nValue );
 	}
@@ -442,8 +519,8 @@ void PatternEditorPanel::gridResolutionChanged()
 	}
 	m_pPatternEditor->setResolution( nResolution, bUseTriplets );
 
-	( PreferencesMng::getInstance() )->setPatternEditorGridResolution( atoi( selected.c_str() ) );
-	( PreferencesMng::getInstance() )->setPatternEditorUsingTriplets( bUseTriplets );
+	( Preferences::getInstance() )->setPatternEditorGridResolution( atoi( selected.c_str() ) );
+	( Preferences::getInstance() )->setPatternEditorUsingTriplets( bUseTriplets );
 }
 
 
@@ -456,7 +533,7 @@ void PatternEditorPanel::patternSizeComboChanged()
 {
 	string selected = (pPatternSizeCombo->currentText()).latin1();
 
-	uint nQuarter = 192 / 8;
+	uint nQuarter = MAX_NOTES / 8;
 
 	uint nSize;
 	if (selected == "1") {
@@ -488,9 +565,8 @@ void PatternEditorPanel::patternSizeComboChanged()
 	}
 
 
-	Pattern *currentPattern = (Hydrogen::getInstance())->getCurrentPattern();
-	if (currentPattern != NULL) {
-		currentPattern->setSize( nSize );
+	if (m_pPattern != NULL) {
+		m_pPattern->setSize( nSize );
 	}
 
 	m_pPatternEditorRuler->updateEditor( true );	// redraw all
@@ -512,24 +588,21 @@ void PatternEditorPanel::updateStart( bool bStart )
 
 
 
-/**
- * This method is called from another thread (audio engine)
- */
-void PatternEditorPanel::patternChanged()
-{
-	H2TextEvent *ev = new H2TextEvent("patternChanged");
-	QApplication::postEvent(this, ev);
-}
-
-/**
- * This method is called from another thread (audio engine)
- */
+/// This method is called from another thread (audio engine)
 void PatternEditorPanel::patternModified()
 {
 	H2TextEvent *ev = new H2TextEvent("patternModified");
 	QApplication::postEvent(this, ev);
 }
 
+/// This method is called from another thread (audio engine)
+void PatternEditorPanel::selectedPatternChanged()
+{
+	H2TextEvent *ev = new H2TextEvent("selectedPatternChanged");
+	QApplication::postEvent(this, ev);
+}
+
+
 
 /**
  *
@@ -541,52 +614,7 @@ void PatternEditorPanel::customEvent( QCustomEvent *ev )
 	}
 	QString message = ((H2TextEvent*)ev)->getText();
 
-	if (message == QString( "patternChanged" ) ) {
-		// Audio engine current pattern
-		string currentPatternName;
-		Pattern *currentPattern = (Hydrogen::getInstance())->getCurrentPattern();
-		if (currentPattern != NULL) {
-			currentPatternName = currentPattern->getName();
-			this->setCaption( ( trUtf8( "Pattern editor - %1").arg(currentPatternName.c_str()) ) );
-
-			// update pattern size combobox
-			int nPatternSize = currentPattern->getSize();
-			int nQuarter = 192 / 8;
-			if (nPatternSize == nQuarter) {
-				pPatternSizeCombo->setCurrentItem( 0 );
-			}
-			else if (nPatternSize == nQuarter * 2) {
-				pPatternSizeCombo->setCurrentItem( 1 );
-			}
-			else if (nPatternSize == nQuarter * 3) {
-				pPatternSizeCombo->setCurrentItem( 2 );
-			}
-			else if ( nPatternSize == nQuarter * 4 ) {
-				pPatternSizeCombo->setCurrentItem( 3 );
-			}
-			else if ( nPatternSize == nQuarter * 5 ) {
-				pPatternSizeCombo->setCurrentItem( 4 );
-			}
-			else if ( nPatternSize == nQuarter * 6 ) {
-				pPatternSizeCombo->setCurrentItem( 5 );
-			}
-			else if ( nPatternSize == nQuarter * 7 ) {
-				pPatternSizeCombo->setCurrentItem( 6 );
-			}
-			else if ( nPatternSize == nQuarter * 8 ) {
-				pPatternSizeCombo->setCurrentItem( 7 );
-			}
-			else {
-				cout << "[PatternEditorPanel::customEvent()] unhandled case: nPatternSize = " << nPatternSize;
-			}
-		}
-		else {
-			currentPatternName = (trUtf8( "<b>No pattern selected! (NULL pattern)</b>" ) ).latin1();
-			this->setCaption( ( trUtf8( "Pattern editor - ") + trUtf8( "No pattern selected! (NULL pattern)")  ) );
-		}
-		patternNameLbl->setText( trUtf8( "Pattern name: <b>") + QString(currentPatternName.c_str()) + "</b>" );
-	}
-	else if (message == "enablePatternSizeCombo") {
+	if (message == "enablePatternSizeCombo") {
 		pPatternSizeCombo->setEnabled( true );
 	}
 	else if (message == "disablePatternSizeCombo") {
@@ -596,6 +624,22 @@ void PatternEditorPanel::customEvent( QCustomEvent *ev )
 		// full update of display
 		m_pPatternEditor->updateEditor(true);
 	}
+	else if (message == "selectedPatternChanged") {
+		// full update of display
+		m_pPatternEditor->updateEditor(true);
+		m_pNotePropertiesRuler->updateEditor();
+
+		Hydrogen *pEngine = Hydrogen::getInstance();
+		PatternList *pPatternList = pEngine->getSong()->getPatternList();
+		int nSelectedPatternNumber = pEngine->getSelectedPatternNumber();
+		if ( (nSelectedPatternNumber != -1) && ( (uint)nSelectedPatternNumber < pPatternList->getSize() ) ) {
+			m_pPattern = pPatternList->get( nSelectedPatternNumber );
+		}
+		else {
+			m_pPattern = NULL;
+		}
+		setupPattern();
+	}
 }
 
 
@@ -606,7 +650,7 @@ void PatternEditorPanel::customEvent( QCustomEvent *ev )
  */
 void PatternEditorPanel::hearNotesBtnClick(Button *ref)
 {
-	PreferencesMng *pref = ( PreferencesMng::getInstance() );
+	Preferences *pref = ( Preferences::getInstance() );
 	pref->setHearNewNotes( ref->isPressed() );
 
 	if (ref->isPressed() ) {
@@ -624,7 +668,7 @@ void PatternEditorPanel::hearNotesBtnClick(Button *ref)
  */
 void PatternEditorPanel::recordEventsBtnClick(Button *ref)
 {
-	PreferencesMng *pref = ( PreferencesMng::getInstance() );
+	Preferences *pref = ( Preferences::getInstance() );
 	pref->setRecordEvents( ref->isPressed() );
 
 	if (ref->isPressed() ) {
@@ -641,7 +685,7 @@ void PatternEditorPanel::recordEventsBtnClick(Button *ref)
  */
 void PatternEditorPanel::quantizeEventsBtnClick(Button *ref)
 {
-	PreferencesMng *pref = ( PreferencesMng::getInstance() );
+	Preferences *pref = ( Preferences::getInstance() );
 	pref->setQuantizeEvents( ref->isPressed() );
 
 	if (ref->isPressed() ) {
@@ -672,16 +716,13 @@ void PatternEditorPanel::stateChanged(int state)
 
 
 
-/**
- *
- */
 void PatternEditorPanel::resizeEvent( QResizeEvent *ev )
 {
 
 	m_nPanelHeight = height();
 	m_nPanelWidth = width();
 
-	m_pEditorScrollView->resize( m_nPanelWidth - 120, m_nPanelHeight - 110 );
+	m_pEditorScrollView->resize( m_nPanelWidth - 120, m_nPanelHeight - 160 );
 	m_pRulerScrollView->resize( m_pEditorScrollView->width(), m_pRulerScrollView->height() );
 	m_pInstrListScrollView->resize( m_pInstrListScrollView->width(), m_pEditorScrollView->height() );
 
@@ -702,9 +743,14 @@ void PatternEditorPanel::resizeEvent( QResizeEvent *ev )
 	m_pPatternEditorVScrollBar->setPageStep(300);
 
 
+	unsigned nNoteEditor_y = m_nPanelHeight - 115;
+
 	// Velocity ruler
-	m_pVelocityRulerScrollView->move( 105, m_nPanelHeight - 65 );
-	m_pVelocityRulerScrollView->resize( m_pEditorScrollView->width(), m_pVelocityRuler->height() );
+	m_pNotePropertiesScrollView->move( 105, nNoteEditor_y );
+	m_pNotePropertiesScrollView->resize( m_pEditorScrollView->width(), m_pNotePropertiesRuler->height() );
+
+//	m_pShowVelocityBtn->move( 10, nNoteEditor_y + 10 );
+//	m_pShowPitchBtn->move( 10, nNoteEditor_y + 10 + 30);
 
 }
 
@@ -728,12 +774,39 @@ void PatternEditorPanel::contentsMoving(int dummy)
 
 void PatternEditorPanel::setSelectedInstrument( int nInstr )
 {
-	m_nSelectedInstrument = nInstr;
+	//infoLog( "[setSelectedInstrument]" + toString( nInstr ) );
+	Hydrogen::getInstance()->setSelectedInstrumentNumber( nInstr );
 
 	m_pPatternEditor->updateEditor(true);	// force repaint
 	m_pInstrumentList->updateEditor();
-	m_pVelocityRuler->updateEditor();
-
+	m_pNotePropertiesRuler->updateEditor();
 }
 
 
+
+void PatternEditorPanel::selectedInstrumentChanged()
+{
+	// aggiorno tutti i componenti
+	m_pPatternEditor->updateEditor(true);	// force repaint
+	m_pInstrumentList->updateEditor();
+	m_pNotePropertiesRuler->updateEditor();
+}
+
+
+
+void PatternEditorPanel::showVelocityBtnClick(Button *ref)
+{
+	m_pShowVelocityBtn->setPressed( true );
+	m_pShowPitchBtn->setPressed( false );
+	m_pNotePropertiesRuler->setMode( NotePropertiesRuler::VELOCITY );
+}
+
+
+
+void PatternEditorPanel::showPitchBtnClick(Button *ref)
+{
+	m_pShowPitchBtn->setPressed( true );
+	m_pShowVelocityBtn->setPressed( false );
+	m_pNotePropertiesRuler->setMode( NotePropertiesRuler::PITCH );
+}
+
