@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: SongPropertiesDialog.h,v 1.5 2004/01/26 11:17:48 comix Exp $
+ * $Id: SongPropertiesDialog.h,v 1.6 2004/03/22 12:49:27 comix Exp $
  *
  */
 
@@ -38,9 +38,6 @@
  */
 class SongPropertiesDialog : public SongPropertiesDialog_UI {
 	Q_OBJECT
-	private:
-		/** ??? */
-		void languageChange();
 
 	public:
 		/** Constructor */
