@@ -101,6 +101,10 @@
         <source>&lt;i&gt;&lt;ul&gt;Bug fix, test&lt;/ul&gt;&lt;/i&gt;&lt;/p&gt;&lt;br&gt;</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>&lt;i&gt;&lt;ul&gt;Portuguese(Brazil) translation&lt;/ul&gt;&lt;/i&gt;&lt;/p&gt;&lt;br&gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>AboutDialog_UI</name>
@@ -510,7 +514,7 @@ Public License instead of this License.
     </message>
     <message>
         <source>Current pattern</source>
-        <translation>Motif courant</translation>
+        <translation type="obsolete">Motif courant</translation>
     </message>
     <message>
         <source>Audio engine state</source>
@@ -554,12 +558,24 @@ Public License instead of this License.
     </message>
     <message>
         <source>Close</source>
-        <translation>Ferme</translation>
+        <translation type="obsolete">Ferme</translation>
     </message>
     <message>
         <source>Song position</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Patterns</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Selected pattern</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Selected instrument</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>DelayFxMixerLine</name>
@@ -778,7 +794,7 @@ http://hydrogen.sf.net
     </message>
     <message>
         <source>Size -</source>
-        <translation>Taille -</translation>
+        <translation type="obsolete">Taille -</translation>
     </message>
     <message>
         <source>Size: %1 bytes</source>
@@ -788,6 +804,14 @@ http://hydrogen.sf.net
         <source>Size: - </source>
         <translation>Taille: -</translation>
     </message>
+    <message>
+        <source>Samplerate: %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Samplerate: - </source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>FxMixerLine</name>
@@ -797,7 +821,7 @@ http://hydrogen.sf.net
     </message>
     <message>
         <source>Master output</source>
-        <translation>Niveau général de sortie</translation>
+        <translation>Niveau gén. de sortie</translation>
     </message>
 </context>
 <context>
@@ -823,7 +847,7 @@ http://hydrogen.sf.net
     </message>
     <message>
         <source>Hydrogen - Load instrument</source>
-        <translation>Hydrogen - Charger instrument</translation>
+        <translation type="obsolete">Hydrogen - Charger instrument</translation>
     </message>
     <message>
         <source>No OSS driver support</source>
@@ -863,7 +887,7 @@ http://hydrogen.sf.net
     </message>
     <message>
         <source>Audio files (*.wav *.WAV *.au *.AU *.aiff *.AIFF)</source>
-        <translation>Fichiers Audio (*.wav *.WAV *.au *.AU *.aiff *.AIFF)</translation>
+        <translation type="obsolete">Fichiers Audio (*.wav *.WAV *.au *.AU *.aiff *.AIFF)</translation>
     </message>
 </context>
 <context>
@@ -876,6 +900,26 @@ http://hydrogen.sf.net
         <source>Instrument properties</source>
         <translation>Propriétés de l&apos;Instrument</translation>
     </message>
+    <message>
+        <source>Audio files (*.wav *.WAV *.au *.AU *.aiff *.AIFF *.flac *.FLAC)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Hydrogen - Load instrument</source>
+        <translation type="unfinished">Hydrogen - Charger instrument</translation>
+    </message>
+    <message>
+        <source>Set FX %1 level </source>
+        <translation type="unfinished">Régler le niveau de l&apos;effet %1</translation>
+    </message>
+    <message>
+        <source>Empty layer</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Instrument name</source>
+        <translation type="unfinished">Nom de l&apos;instrument</translation>
+    </message>
 </context>
 <context>
     <name>InstrumentPropertiesDialog_UI</name>
@@ -885,11 +929,11 @@ http://hydrogen.sf.net
     </message>
     <message>
         <source>Instrument name</source>
-        <translation>Nom de l&apos;instrument</translation>
+        <translation type="obsolete">Nom de l&apos;instrument</translation>
     </message>
     <message>
         <source>Sample filename</source>
-        <translation>Nom du fichier échantillon</translation>
+        <translation type="obsolete">Nom du fichier échantillon</translation>
     </message>
     <message>
         <source>Browse</source>
@@ -897,15 +941,76 @@ http://hydrogen.sf.net
     </message>
     <message>
         <source>Drumkit</source>
-        <translation>Kit de Batterie</translation>
+        <translation type="obsolete">Kit de Batterie</translation>
     </message>
     <message>
         <source>Cancel</source>
-        <translation>Annuler</translation>
+        <translation type="obsolete">Annuler</translation>
     </message>
     <message>
         <source>Ok</source>
-        <translation>OK</translation>
+        <translation type="obsolete">OK</translation>
+    </message>
+    <message>
+        <source>1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>2</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>3</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>4</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>5</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>6</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>7</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>8</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Play layer</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Gain</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Pitch</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>End velocity</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Start velocity</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>sample size in frames</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Delete</source>
+        <translation type="unfinished">Effacer
+</translation>
     </message>
 </context>
 <context>
@@ -1104,11 +1209,11 @@ http://hydrogen.sf.net
     </message>
     <message>
         <source>Open</source>
-        <translation>Ouvrir</translation>
+        <translation type="obsolete">Ouvrir</translation>
     </message>
     <message>
         <source>Open Demo</source>
-        <translation>Ouvrir une démo</translation>
+        <translation type="obsolete">Ouvrir une démo</translation>
     </message>
     <message>
         <source>Exit</source>
@@ -1116,43 +1221,43 @@ http://hydrogen.sf.net
     </message>
     <message>
         <source>New</source>
-        <translation>Nouveau</translation>
+        <translation type="obsolete">Nouveau</translation>
     </message>
     <message>
         <source>Save as...</source>
-        <translation>Enregistrer sous...</translation>
+        <translation type="obsolete">Enregistrer sous...</translation>
     </message>
     <message>
         <source>Export</source>
-        <translation>Exporter</translation>
+        <translation type="obsolete">Exporter</translation>
     </message>
     <message>
         <source>Preferences</source>
-        <translation>Préférences</translation>
+        <translation type="obsolete">Préférences</translation>
     </message>
     <message>
         <source>Show mixer</source>
-        <translation>Montrer la table de mixage</translation>
+        <translation type="obsolete">Montrer la table de mixage</translation>
     </message>
     <message>
         <source>Show audio engine info</source>
-        <translation>Montrer les infos du système audio</translation>
+        <translation type="obsolete">Montrer les infos du système audio</translation>
     </message>
     <message>
         <source>Show song editor</source>
-        <translation>Montrer l&apos;éditeur de morceau</translation>
+        <translation type="obsolete">Montrer l&apos;éditeur de morceau</translation>
     </message>
     <message>
         <source>Show drumkit manager</source>
-        <translation>Montrer le gestionnaire de kit de batterie</translation>
+        <translation type="obsolete">Montrer le gestionnaire de kit de batterie</translation>
     </message>
     <message>
         <source>User manual</source>
-        <translation>Manuel Utilisateur</translation>
+        <translation type="obsolete">Manuel Utilisateur</translation>
     </message>
     <message>
         <source>About</source>
-        <translation>A propos</translation>
+        <translation type="obsolete">A propos</translation>
     </message>
     <message>
         <source>&amp;File</source>
@@ -1218,15 +1323,95 @@ Voulez-vous enregistrer les changements avant de quitter?</translation>
     </message>
     <message>
         <source>Quit</source>
-        <translation>Quitter</translation>
+        <translation type="obsolete">Quitter</translation>
     </message>
     <message>
         <source>Open recent</source>
-        <translation>Récemment ouvert</translation>
+        <translation type="obsolete">Récemment ouvert</translation>
     </message>
     <message>
         <source>Save</source>
-        <translation>Sauvegarde</translation>
+        <translation type="obsolete">Sauvegarde</translation>
+    </message>
+    <message>
+        <source>Export MIDI file</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Midi file (*.mid)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;New</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Open</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Open &amp;Demo</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Open &amp;recent</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Save &amp;as...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Export</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Export &amp;MIDI file</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Preferences</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Quit</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Show &amp;mixer</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Show &amp;song editor</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Show &amp;drumkit manager</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Show &amp;instrument editor</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Show &amp;audio engine info</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;User manual</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;About</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Cancel</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Debug</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -1366,6 +1551,10 @@ Voulez-vous enregistrer les changements avant de quitter?</translation>
         <source>Set LADSPA FX ( %1 ) volume</source>
         <translation>Régler le volume de l&apos;effet LADSPA (%1)</translation>
     </message>
+    <message>
+        <source>Instrument name</source>
+        <translation type="unfinished">Nom de l&apos;instrument</translation>
+    </message>
 </context>
 <context>
     <name>MixerLine</name>
@@ -1375,7 +1564,7 @@ Voulez-vous enregistrer les changements avant de quitter?</translation>
     </message>
     <message>
         <source>Load external sample</source>
-        <translation>Charger un échantillon externe</translation>
+        <translation type="obsolete">Charger un échantillon externe</translation>
     </message>
     <message>
         <source>Mute</source>
@@ -1430,7 +1619,7 @@ Voulez-vous enregistrer les changements avant de quitter?</translation>
     </message>
     <message>
         <source>Grid resolution</source>
-        <translation>Résolution de la grille</translation>
+        <translation>Résol. de la grille</translation>
     </message>
     <message>
         <source>Hear new notes</source>
@@ -1506,19 +1695,19 @@ Voulez-vous enregistrer les changements avant de quitter?</translation>
     </message>
     <message>
         <source>Pattern editor - </source>
-        <translation>Editeur de Motif - </translation>
+        <translation type="obsolete">Editeur de Motif - </translation>
     </message>
     <message>
         <source>&lt;b&gt;No pattern selected! (NULL pattern)&lt;/b&gt;</source>
-        <translation>&lt;b&gt;Aucun motif sélectionné ! (motif VIDE)&lt;/b&gt;</translation>
+        <translation type="obsolete">&lt;b&gt;Aucun motif sélectionné ! (motif VIDE)&lt;/b&gt;</translation>
     </message>
     <message>
         <source>No pattern selected! (NULL pattern)</source>
-        <translation>Aucun motif sélectionné ! (motif VIDE)</translation>
+        <translation type="obsolete">Aucun motif sélectionné ! (motif VIDE)</translation>
     </message>
     <message>
         <source>Pattern name: &lt;b&gt;</source>
-        <translation>Nom du Motif : &lt;b&gt;</translation>
+        <translation type="obsolete">Nom du Motif : &lt;b&gt;</translation>
     </message>
     <message>
         <source>Hear new notes = On</source>
@@ -1556,6 +1745,10 @@ Voulez-vous enregistrer les changements avant de quitter?</translation>
         <source>Quantize incoming keyboard/midi events = Off</source>
         <translation>Quantifier les évenements clavier/MIDI entrant = Off</translation>
     </message>
+    <message>
+        <source>Pattern name: &lt;b&gt;%1&lt;/b&gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>PatternPropertiesDialog</name>
@@ -1937,7 +2130,7 @@ Voulez-vous enregistrer les changements avant de quitter?</translation>
     </message>
     <message>
         <source>LADSPA Plugin path</source>
-        <translation>Chemin des plugins LADSPA</translation>
+        <translation type="obsolete">Chemin des plugins LADSPA</translation>
     </message>
     <message>
         <source>Application</source>
@@ -1947,6 +2140,10 @@ Voulez-vous enregistrer les changements avant de quitter?</translation>
         <source>Style</source>
         <translation>Style</translation>
     </message>
+    <message>
+        <source>Single paned</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SongEditorPanel</name>
@@ -2012,7 +2209,7 @@ Voulez-vous enregistrer les changements avant de quitter?</translation>
     </message>
     <message>
         <source>Can&apos;t delete the pattern while the audio engine is playing</source>
-        <translation>Impossible d&apos;effacer le motif alors que le système audio est actif</translation>
+        <translation type="obsolete">Impossible d&apos;effacer le motif alors que le système audio est actif</translation>
     </message>
 </context>
 <context>
