@@ -101,6 +101,10 @@
         <source>&lt;i&gt;&lt;ul&gt;Bug fix, test&lt;/ul&gt;&lt;/i&gt;&lt;/p&gt;&lt;br&gt;</source>
         <translation></translation>
     </message>
+    <message>
+        <source>&lt;i&gt;&lt;ul&gt;Portuguese(Brazil) translation&lt;/ul&gt;&lt;/i&gt;&lt;/p&gt;&lt;br&gt;</source>
+        <translation>&lt;i&gt;&lt;ul&gt;Traduzione in Portoghese(Brasile)&lt;/ul&gt;&lt;/i&gt;&lt;/p&gt;&lt;br&gt;</translation>
+    </message>
 </context>
 <context>
     <name>AboutDialog_UI</name>
@@ -506,7 +510,7 @@ Public License instead of this License.
     </message>
     <message>
         <source>Current pattern</source>
-        <translation>Pattern corrente</translation>
+        <translation type="obsolete">Pattern corrente</translation>
     </message>
     <message>
         <source>Audio engine state</source>
@@ -550,7 +554,7 @@ Public License instead of this License.
     </message>
     <message>
         <source>Close</source>
-        <translation>Chiudi</translation>
+        <translation type="obsolete">Chiudi</translation>
     </message>
     <message>
         <source>###</source>
@@ -560,6 +564,18 @@ Public License instead of this License.
         <source>Song position</source>
         <translation>Posizione canzone</translation>
     </message>
+    <message>
+        <source>Patterns</source>
+        <translation>Pattern</translation>
+    </message>
+    <message>
+        <source>Selected pattern</source>
+        <translation>Pattern selezionato</translation>
+    </message>
+    <message>
+        <source>Selected instrument</source>
+        <translation>Strumento selezionato</translation>
+    </message>
 </context>
 <context>
     <name>DelayFxMixerLine</name>
@@ -786,7 +802,7 @@ http://hydrogen.sf.net
     </message>
     <message>
         <source>Size -</source>
-        <translation>Dimensioni -</translation>
+        <translation type="obsolete">Dimensioni -</translation>
     </message>
     <message>
         <source>Size: %1 bytes</source>
@@ -796,6 +812,14 @@ http://hydrogen.sf.net
         <source>Size: - </source>
         <translation>Dimensioni -</translation>
     </message>
+    <message>
+        <source>Samplerate: %1</source>
+        <translation></translation>
+    </message>
+    <message>
+        <source>Samplerate: - </source>
+        <translation></translation>
+    </message>
 </context>
 <context>
     <name>FxMixerLine</name>
@@ -823,7 +847,7 @@ http://hydrogen.sf.net
     <name>HydrogenApp</name>
     <message>
         <source>Hydrogen - Load instrument</source>
-        <translation>Hydrogen - Carica strumento</translation>
+        <translation type="obsolete">Hydrogen - Carica strumento</translation>
     </message>
     <message>
         <source>Song Info:</source>
@@ -875,7 +899,7 @@ http://hydrogen.sf.net
     </message>
     <message>
         <source>Audio files (*.wav *.WAV *.au *.AU *.aiff *.AIFF)</source>
-        <translation>File audio (*.wav *.WAV *.au *.AU *.aiff *.AIFF)</translation>
+        <translation type="obsolete">File audio (*.wav *.WAV *.au *.AU *.aiff *.AIFF)</translation>
     </message>
 </context>
 <context>
@@ -888,6 +912,26 @@ http://hydrogen.sf.net
         <source>Instrument properties</source>
         <translation>Proprieta&apos; strumento</translation>
     </message>
+    <message>
+        <source>Audio files (*.wav *.WAV *.au *.AU *.aiff *.AIFF *.flac *.FLAC)</source>
+        <translation></translation>
+    </message>
+    <message>
+        <source>Hydrogen - Load instrument</source>
+        <translation>Hydrogen - Carica strumento</translation>
+    </message>
+    <message>
+        <source>Set FX %1 level </source>
+        <translation>Imposta livello FX %1</translation>
+    </message>
+    <message>
+        <source>Empty layer</source>
+        <translation>Layer vuoto</translation>
+    </message>
+    <message>
+        <source>Instrument name</source>
+        <translation>Nome strumento</translation>
+    </message>
 </context>
 <context>
     <name>InstrumentPropertiesDialog_UI</name>
@@ -897,11 +941,11 @@ http://hydrogen.sf.net
     </message>
     <message>
         <source>Instrument name</source>
-        <translation>Nome strumento</translation>
+        <translation type="obsolete">Nome strumento</translation>
     </message>
     <message>
         <source>Sample filename</source>
-        <translation>Filename del sample</translation>
+        <translation type="obsolete">Filename del sample</translation>
     </message>
     <message>
         <source>Browse</source>
@@ -909,15 +953,79 @@ http://hydrogen.sf.net
     </message>
     <message>
         <source>Drumkit</source>
-        <translation>Drumkit</translation>
+        <translation type="obsolete">Drumkit</translation>
     </message>
     <message>
         <source>Cancel</source>
-        <translation>Annulla</translation>
+        <translation type="obsolete">Annulla</translation>
     </message>
     <message>
         <source>Ok</source>
-        <translation>Ok</translation>
+        <translation type="obsolete">Ok</translation>
+    </message>
+    <message>
+        <source>Instrument</source>
+        <translation type="obsolete">Strumento</translation>
+    </message>
+    <message>
+        <source>1</source>
+        <translation></translation>
+    </message>
+    <message>
+        <source>2</source>
+        <translation></translation>
+    </message>
+    <message>
+        <source>3</source>
+        <translation></translation>
+    </message>
+    <message>
+        <source>4</source>
+        <translation></translation>
+    </message>
+    <message>
+        <source>5</source>
+        <translation></translation>
+    </message>
+    <message>
+        <source>6</source>
+        <translation></translation>
+    </message>
+    <message>
+        <source>7</source>
+        <translation></translation>
+    </message>
+    <message>
+        <source>8</source>
+        <translation></translation>
+    </message>
+    <message>
+        <source>Play layer</source>
+        <translation>Suona layer</translation>
+    </message>
+    <message>
+        <source>Gain</source>
+        <translation></translation>
+    </message>
+    <message>
+        <source>Pitch</source>
+        <translation></translation>
+    </message>
+    <message>
+        <source>End velocity</source>
+        <translation></translation>
+    </message>
+    <message>
+        <source>Start velocity</source>
+        <translation></translation>
+    </message>
+    <message>
+        <source>sample size in frames</source>
+        <translation>Grandezza sample in frame</translation>
+    </message>
+    <message>
+        <source>Delete</source>
+        <translation>Elimina</translation>
     </message>
 </context>
 <context>
@@ -1100,12 +1208,12 @@ http://hydrogen.sf.net
     <name>MainForm</name>
     <message>
         <source>Open</source>
-        <translation>Apri
+        <translation type="obsolete">Apri
 </translation>
     </message>
     <message>
         <source>Open Demo</source>
-        <translation>Apri Demo</translation>
+        <translation type="obsolete">Apri Demo</translation>
     </message>
     <message>
         <source>Exit</source>
@@ -1113,46 +1221,46 @@ http://hydrogen.sf.net
     </message>
     <message>
         <source>New</source>
-        <translation>Nuova canzone</translation>
+        <translation type="obsolete">Nuova canzone</translation>
     </message>
     <message>
         <source>Save as...</source>
-        <translation>Salva come...
+        <translation type="obsolete">Salva come...
 </translation>
     </message>
     <message>
         <source>Export</source>
-        <translation>Esporta</translation>
+        <translation type="obsolete">Esporta</translation>
     </message>
     <message>
         <source>Preferences</source>
-        <translation>Preferenze</translation>
+        <translation type="obsolete">Preferenze</translation>
     </message>
     <message>
         <source>Show mixer</source>
-        <translation>Mostra mixer</translation>
+        <translation type="obsolete">Mostra mixer</translation>
     </message>
     <message>
         <source>Show audio engine info</source>
-        <translation>Mostra informazioni audio engine</translation>
+        <translation type="obsolete">Mostra informazioni audio engine</translation>
     </message>
     <message>
         <source>Show song editor</source>
-        <translation>Mostra Editor di canzone
+        <translation type="obsolete">Mostra Editor di canzone
 </translation>
     </message>
     <message>
         <source>Show drumkit manager</source>
-        <translation>Mostra gestore Drumkit</translation>
+        <translation type="obsolete">Mostra gestore Drumkit</translation>
     </message>
     <message>
         <source>User manual</source>
-        <translation>Manuale utente
+        <translation type="obsolete">Manuale utente
 </translation>
     </message>
     <message>
         <source>About</source>
-        <translation>Informazioni su</translation>
+        <translation type="obsolete">Informazioni su</translation>
     </message>
     <message>
         <source>File</source>
@@ -1244,15 +1352,99 @@ Vuoi salvare la canzone prima di uscire dal programma?
     </message>
     <message>
         <source>Quit</source>
-        <translation>Esci</translation>
+        <translation type="obsolete">Esci</translation>
     </message>
     <message>
         <source>Open recent</source>
-        <translation>Apri recenti</translation>
+        <translation type="obsolete">Apri recenti</translation>
     </message>
     <message>
         <source>Save</source>
-        <translation>Salva</translation>
+        <translation type="obsolete">Salva</translation>
+    </message>
+    <message>
+        <source>Show instrument editor</source>
+        <translation type="obsolete">Apri editor di strumenti</translation>
+    </message>
+    <message>
+        <source>&amp;Debug</source>
+        <translation>&amp;Debug</translation>
+    </message>
+    <message>
+        <source>Export MIDI file</source>
+        <translation>Esporta MIDI file</translation>
+    </message>
+    <message>
+        <source>Midi file (*.mid)</source>
+        <translation>File MIDI (*.mid)</translation>
+    </message>
+    <message>
+        <source>&amp;New</source>
+        <translation>&amp;Nuova canzone</translation>
+    </message>
+    <message>
+        <source>&amp;Open</source>
+        <translation>&amp;Apri</translation>
+    </message>
+    <message>
+        <source>Open &amp;Demo</source>
+        <translation>Apri &amp;demo</translation>
+    </message>
+    <message>
+        <source>Open &amp;recent</source>
+        <translation>Apri &amp;recenti</translation>
+    </message>
+    <message>
+        <source>Save &amp;as...</source>
+        <translation>Salva &amp;come...</translation>
+    </message>
+    <message>
+        <source>&amp;Export</source>
+        <translation>&amp;Esporta</translation>
+    </message>
+    <message>
+        <source>Export &amp;MIDI file</source>
+        <translation>Esporta file &amp;MIDI</translation>
+    </message>
+    <message>
+        <source>&amp;Preferences</source>
+        <translation>&amp;Preferenze</translation>
+    </message>
+    <message>
+        <source>&amp;Quit</source>
+        <translation>&amp;Esci</translation>
+    </message>
+    <message>
+        <source>Show &amp;mixer</source>
+        <translation>Visualizza &amp;mixer</translation>
+    </message>
+    <message>
+        <source>Show &amp;song editor</source>
+        <translation>Visualizza editor di &amp;canzoni</translation>
+    </message>
+    <message>
+        <source>Show &amp;drumkit manager</source>
+        <translation>Visualizza gestore &amp;drumkit</translation>
+    </message>
+    <message>
+        <source>Show &amp;instrument editor</source>
+        <translation>Visualizza editor di &amp;strumenti</translation>
+    </message>
+    <message>
+        <source>Show &amp;audio engine info</source>
+        <translation>Visualizza informazioni &amp;audio engine</translation>
+    </message>
+    <message>
+        <source>&amp;User manual</source>
+        <translation>&amp;Manuale utente</translation>
+    </message>
+    <message>
+        <source>&amp;About</source>
+        <translation>&amp;Informazioni su</translation>
+    </message>
+    <message>
+        <source>&amp;Cancel</source>
+        <translation>&amp;Annulla</translation>
     </message>
 </context>
 <context>
@@ -1404,6 +1596,10 @@ Vuoi salvare la canzone prima di uscire dal programma?
         <source>Set LADSPA FX ( %1 ) volume</source>
         <translation>Imposta volume LADSPA FX ( %1 )</translation>
     </message>
+    <message>
+        <source>Instrument name</source>
+        <translation>Nome strumento</translation>
+    </message>
 </context>
 <context>
     <name>MixerLine</name>
@@ -1413,7 +1609,7 @@ Vuoi salvare la canzone prima di uscire dal programma?
     </message>
     <message>
         <source>Load external sample</source>
-        <translation>Carica sample esterno</translation>
+        <translation type="obsolete">Carica sample esterno</translation>
     </message>
     <message>
         <source>Mute</source>
@@ -1528,7 +1724,7 @@ Vuoi salvare la canzone prima di uscire dal programma?
     </message>
     <message>
         <source>Grid resolution</source>
-        <translation>Risoluzione griglia</translation>
+        <translation>Risol. griglia</translation>
     </message>
     <message>
         <source>Hear new notes</source>
@@ -1544,19 +1740,19 @@ Vuoi salvare la canzone prima di uscire dal programma?
     </message>
     <message>
         <source>Pattern editor - </source>
-        <translation>Editor di pattern - </translation>
+        <translation type="obsolete">Editor di pattern - </translation>
     </message>
     <message>
         <source>&lt;b&gt;No pattern selected! (NULL pattern)&lt;/b&gt;</source>
-        <translation>&lt;b&gt;Nessun pattern selezionato! (NULL pattern)&lt;/b&gt;</translation>
+        <translation type="obsolete">&lt;b&gt;Nessun pattern selezionato! (NULL pattern)&lt;/b&gt;</translation>
     </message>
     <message>
         <source>No pattern selected! (NULL pattern)</source>
-        <translation>Nessun pattern selezionato! (NULL pattern)</translation>
+        <translation type="obsolete">Nessun pattern selezionato! (NULL pattern)</translation>
     </message>
     <message>
         <source>Pattern name: &lt;b&gt;</source>
-        <translation>Nome pattern: &lt;b&gt;</translation>
+        <translation type="obsolete">Nome pattern: &lt;b&gt;</translation>
     </message>
     <message>
         <source>Hear new notes = On</source>
@@ -1594,6 +1790,10 @@ Vuoi salvare la canzone prima di uscire dal programma?
         <source>Quantize incoming keyboard/midi events = Off</source>
         <translation>Quantizza eventi in arrivo da tastiera/midi = Off</translation>
     </message>
+    <message>
+        <source>Pattern name: &lt;b&gt;%1&lt;/b&gt;</source>
+        <translation>Nome pattern: &lt;b&gt;%1&lt;/b&gt;</translation>
+    </message>
 </context>
 <context>
     <name>PatternPropertiesDialog</name>
@@ -1991,7 +2191,7 @@ Vuoi salvare la canzone prima di uscire dal programma?
     </message>
     <message>
         <source>LADSPA Plugin path</source>
-        <translation>Directory Plugin LADSPA</translation>
+        <translation type="obsolete">Directory Plugin LADSPA</translation>
     </message>
     <message>
         <source>Application</source>
@@ -2001,6 +2201,10 @@ Vuoi salvare la canzone prima di uscire dal programma?
         <source>Style</source>
         <translation>Stile interfaccia</translation>
     </message>
+    <message>
+        <source>Single paned</source>
+        <translation>Singola finestra</translation>
+    </message>
 </context>
 <context>
     <name>SongEditorPanel</name>
@@ -2065,7 +2269,7 @@ Vuoi salvare la canzone prima di uscire dal programma?
     </message>
     <message>
         <source>Can&apos;t delete the pattern while the audio engine is playing</source>
-        <translation>Non e&apos; possibile eliminare un pattern mentre e&apos; in esecuzione</translation>
+        <translation type="obsolete">Non e&apos; possibile eliminare un pattern mentre e&apos; in esecuzione</translation>
     </message>
 </context>
 <context>
