@@ -9,6 +9,8 @@ $CMD i18n/hydrogen.it.ts
 $CMD i18n/hydrogen.es.ts
 $CMD i18n/hydrogen.ru.ts
 $CMD i18n/hydrogen.fr.ts
+$CMD i18n/hydrogen.pt_BR.ts
+$CMD i18n/hydrogen.hu_HU.ts
 
 echo "Creating *.qm files"
 cd i18n
