@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: Globals.h,v 1.3 2004/01/26 11:16:58 comix Exp $
+ * $Id: Globals.h,v 1.7 2004/07/06 10:39:15 comix Exp $
  *
  */
 #ifndef ENGINE_GLOBALS_H
@@ -29,12 +29,12 @@
 #define MONO			1
 #define STEREO			2
 
-#define MAX_TRACKS		32
+#define MAX_INSTRUMENTS	32
 #define MAX_NOTES		192
+
 #define MAX_FX			4
 
-#define PATTERN_MODE	1
-#define SONG_MODE		2
+#define MAX_LAYERS		16
 
 
 #endif
