@@ -18,30 +18,23 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: Song.cpp,v 1.9 2004/02/20 14:09:20 comix Exp $
+ * $Id: Song.cpp,v 1.30 2004/09/06 09:40:37 comix Exp $
  *
  */
 
 #include "Song.h"
 #include "config.h"
 
-//----------------------------------------------------------------------------
-//	Implementation of SequenceList class
-//----------------------------------------------------------------------------
-/**
- * Constructor
- */
-SequenceList::SequenceList() : Object( "SequenceList" )
+#include <assert.h>
+
+SequenceList::SequenceList()
+ : Object( "SequenceList" )
 {
 //	infoLog("Init");
 }
 
 
 
-
-/**
- * Destructor
- */
 SequenceList::~SequenceList() {
 //	infoLog("destroy");
 	for (unsigned int i = 0; i < list.size(); i++) {
@@ -54,39 +47,34 @@ SequenceList::~SequenceList() {
 
 
 
-
-/**
- *
- */
 void SequenceList::add(Sequence* newSequence) {
 	list.push_back(newSequence);
 }
 
 
 
+Sequence* SequenceList::get(int pos) {
+	assert( ( pos >= 0 ) && ( pos < (int)list.size() ) );
+/*	if ( pos < 0 ) {
+		errorLog( "[get] pos < 0 - pos = " + toString( pos ) );
+		return NULL;
+	}
+	if (pos > list.size() ) {
+		errorLog( "[get] pos > list.size - pos = " + toString( pos ) + " list.size=" + toString(list.size()) );
+		return NULL;
+	}*/
 
-/**
- *
- */
-Sequence* SequenceList::get(unsigned int pos) {
 	return list[pos];
 }
 
 
 
-
-/**
- *
- */
 unsigned int SequenceList::getSize() {
 	return list.size();
 }
 
 
 
-/**
- *
- */
 SequenceList* SequenceList::copy() {
 	SequenceList *newSequenceList = new SequenceList();
 
@@ -102,23 +90,19 @@ SequenceList* SequenceList::copy() {
 
 
 
-//----------------------------------------------------------------------------
-//	Implementation of PatternList class
-//----------------------------------------------------------------------------
-/**
- * Constructor
- */
-PatternList::PatternList() : Object( "PatternList" )
+//:::::::::::::::::::::::
+
+
+
+
+PatternList::PatternList()
+ : Object( "PatternList" )
 {
 //	infoLog("Init");
 }
 
 
 
-
-/**
- * Destructor
- */
 PatternList::~PatternList() {
 //	infoLog("destroy");
 
@@ -152,57 +136,36 @@ PatternList::~PatternList() {
 
 
 
-
-/**
- *
- */
 void PatternList::add(Pattern* newPattern) {
 	list.push_back(newPattern);
 }
 
 
 
-
-
-/**
- *
- */
-Pattern* PatternList::get(unsigned int pos) {
-	if (pos > list.size()) {
-		char tmp[200];
-		sprintf( tmp, "Pattern index out of bounds. index = %d", pos );
-		errorLog( tmp );
+Pattern* PatternList::get(int nPos) {
+	if (nPos > (int)list.size()) {
+		errorLog( "[get] Pattern index out of bounds. nPos > list.size() - " + toString( nPos ) + " > " + toString( list.size() ) );
 		return NULL;
 	}
-	return list[pos];
+//	assert( nPos < (int)list.size() );
+	return list[ nPos ];
 }
 
 
 
-
-/**
- *
- */
 unsigned int PatternList::getSize() {
 	return list.size();
 }
 
 
 
-
-/**
- *
- */
 void PatternList::clear() {
 	list.clear();
 }
 
 
 
-
-/**
- * Replace an existent pattern with another one
- */
+/// Replace an existent pattern with another one
 void PatternList::replace( Pattern* newPattern, unsigned int pos ) {
 	list.insert( list.begin() + pos, newPattern );	// insert the new pattern
 	// remove the old pattern
@@ -211,13 +174,9 @@ void PatternList::replace( Pattern* newPattern, unsigned int pos ) {
 
 
 
-
-/**
- * Remove a pattern from the list (every instance in the list)
- * Note: the pattern is not deleted!!!
- */
+/// Remove a pattern from the list (every instance in the list), the pattern is not deleted!!!
 void PatternList::del(Pattern *pattern) {
-//	infoLog("Delete pattern " + pattern->getName());
+	//infoLog("[del] Delete pattern " + pattern->getName());
 	// create the new pattern list
 	vector<Pattern*> newList;
 	for (uint i = 0; i < list.size(); i++) {
@@ -237,12 +196,7 @@ void PatternList::del(Pattern *pattern) {
 
 
 
-
-
-/**
- * Remove one pattern from the list
- * Note: the pattern is not deleted!!!
- */
+/// Remove one pattern from the list, the pattern is not deleted!!!
 void PatternList::del(uint index) {
 	// create the new pattern list
 	vector<Pattern*> newList;
@@ -263,40 +217,27 @@ void PatternList::del(uint index) {
 
 
 
+//::::::::::::::::::
 
 
-//----------------------------------------------------------------------------
-//	Implementation of InstrumentList class
-//----------------------------------------------------------------------------
-/**
- * Constructor
- */
-InstrumentList::InstrumentList() : Object( "InstrumentList" )
+
+InstrumentList::InstrumentList()
+ : Object( "InstrumentList" )
 {
-//	infoLog("Init");
+//	infoLog("INIT");
 }
 
 
 
-/**
- * Destructor
- */
 InstrumentList::~InstrumentList() {
-//	infoLog("destroy");
+//	infoLog("DESTROY");
 	for (unsigned int i = 0; i < list.size(); i++) {
-		if( list[i] != NULL ){
-			delete list[i];
-			list[i] = NULL;
-		}
+		delete list[i];
 	}
 }
 
 
 
-
-/**
- *
- */
 void InstrumentList::add(Instrument* newInstrument) {
 	list.push_back(newInstrument);
 	posmap[newInstrument] = list.size() - 1;
@@ -304,17 +245,21 @@ void InstrumentList::add(Instrument* newInstrument) {
 
 
 
-/**
- *
- */
 Instrument* InstrumentList::get(unsigned int pos) {
+	if ( pos > list.size() ) {
+		errorLog( "[get] pos > list.size(). pos = " + toString(pos) );
+		return NULL;
+	}
+	else if ( pos < 0 ) {
+		errorLog( "[get] pos < 0. pos = " + toString(pos) );
+		return NULL;
+	}
 	return list[pos];
 }
 
-/**
- * returns index of instrument in list
- * if instrument not found, returns -1
- */
+
+
+/// Returns index of instrument in list, if instrument not found, returns -1
 int InstrumentList::getPos(Instrument * inst) {
 	if (posmap.find(inst) == posmap.end())
 		return -1;
@@ -322,76 +267,42 @@ int InstrumentList::getPos(Instrument * inst) {
 }
 
 
-/**
- *
- */
+
 unsigned int InstrumentList::getSize() {
 	return list.size();
 }
 
 
 
-
-/**
- * Replace the instrument sample
- */
-void InstrumentList::replaceSample(Instrument* newInstrument, int pos) {
-	Instrument *oldInstr = list[pos];
-
-	// delete old sample
-	Sample *oldSample = oldInstr->getSample();
-	delete oldSample;
-
-	// insert new sample from newInstrument
-	Sample *newSample = Sample::load(newInstrument->getSample()->getFilename());
-	oldInstr->setSample(newSample);
-
-	delete newInstrument;
-	newInstrument = NULL;
-}
+//::::::::::::::::::::::::::
 
 
 
-
-//----------------------------------------------------------------------------
-//	IMPLEMENTATION OF SONG CLASS
-//----------------------------------------------------------------------------
-
-
-
-//----------------------------------------------------------------------------
-/**
- * Constructor
- */
-Song::Song(string id, string name, string author, float bpm, float volume) : Object( "Song     " )
+Song::Song(string sId, string sName, string sAuthor, float fBpm, float fVolume)
+ : Object( "Song     " )
+ , m_sId ( sId )
+ , m_fBpm( fBpm )
+ , m_nResolution( 48 )
+ , m_fVolume( fVolume )
+ , m_fMetronomeVolume( 0.5 )
+ , m_sName( sName )
+ , m_sAuthor( sAuthor )
+ , m_sNotes( "Song info" )	///\todo: attenzione..questo non verra' tradotto
+ , m_pPatternList( NULL )
+ , m_pPatternSequence( NULL )
+ , m_pInstrumentList( NULL )
+ , m_sFilename( "" )
+ , m_bIsModified( false )
+ , m_bIsLoopEnabled( false )
+ , m_bIsHumanizeTimeEnabled( false )
+ , m_fHumanizeTimeValue( 0.0 )
+ , m_bIsHumanizeVelocityEnabled( false )
+ , m_fHumanizeVelocityValue( 0.0 )
+ , m_bIsSwingEnabled( false )
+ , m_fSwingFactor( 0.0 )
+ , m_songMode( PATTERN_MODE )
 {
-	infoLog( "init \"" + name + "\"" );
-
-	instrumentList = NULL;
-	patternList = NULL;
-	patternSequence = NULL;
-
-	this->id = id;
-	this->name = name;
-	this->author = author;
-	this->resolution = 48;	// number of ticks per quarter
-	this->humanizeTimeValue = 0.0;
-	this->humanizeVelocityValue = 0.0;
-
-	setBpm( bpm) ;
-	setVolume( volume );
-	setMetronomeVolume( 0.50f );	// default
-	setNotes( "Song info" );
-	setFilename( "" );
-	setModified( false );
-	setLoopEnabled( false );
-	setSwingFactor( 0.0 );
-	setMode( PATTERN_MODE );
-	setHumanizeTimeEnabled( false );
-	setHumanizeVelocityEnabled( false );
-	setSwingEnabled( false );
-	setPatternList( NULL );
-	setPatternSequence( NULL );
+	infoLog( "init \"" + m_sName + "\"" );
 
 	for (uint nFX = 0; nFX < MAX_FX; nFX++) {
 		setLadspaFX( nFX, NULL );
@@ -400,47 +311,32 @@ Song::Song(string id, string name, string author, float bpm, float volume) : Obj
 
 
 
-
-//----------------------------------------------------------------------------
-/**
- * Destructor
- */
-Song::~Song(){
+Song::~Song()
+{
 	// delete all patterns
-	delete patternList;
+	delete m_pPatternList;
 
-	if (patternSequence) {
-		patternSequence->clear();
-		delete patternSequence;
+	if (m_pPatternSequence) {
+		for (uint i = 0; i < m_pPatternSequence->size(); i++) {
+			PatternList *pPatternList = (*m_pPatternSequence)[i];
+			pPatternList->clear();	// pulisco tutto, i pattern non vanno distrutti qua
+			delete pPatternList;
+		}
+		delete m_pPatternSequence;
 	}
 
-	delete instrumentList;
+	delete m_pInstrumentList;
 
 	for (uint nFX = 0; nFX < MAX_FX; nFX++) {
 		delete m_pLadspaFX[nFX];
 	}
 
-	infoLog( "destroy \"" + name + "\"" );
+	infoLog( "destroy \"" + m_sName + "\"" );
 }
 
 
 
-
-//----------------------------------------------------------------------------
-/**
- * Set bpm.
- */
-void Song::setBpm(float bpm) {
-	this->bpm = bpm;
-}
-
-
-
-
-//----------------------------------------------------------------------------
-/**
- * Load a song form file
- */
+///Load a song from file
 Song* Song::load(string filename) {
 	Song *song = NULL;
 	LocalFileMng mng;
@@ -451,10 +347,8 @@ Song* Song::load(string filename) {
 
 
 
-//----------------------------------------------------------------------------
-/**
- * Save a song to file
- */
+
+/// Save a song to file
 void Song::save(string filename) {
 	LocalFileMng mng;
 	mng.saveSong(this, filename);
@@ -462,25 +356,7 @@ void Song::save(string filename) {
 
 
 
-
-//----------------------------------------------------------------------------
-/**
- *
- */
-unsigned int Song::estimateSongSize() {
-	unsigned int nPatterns = patternSequence->getSize();	// number of patterns in the song
-	unsigned int ticks = MAX_NOTES * nPatterns;
-
-	return ticks;
-}
-
-
-
-
-
-/**
- * Return an empty song
- */
+/// Return an empty song
 Song* Song::getEmptySong() {
 	string dataDir = DATA_DIR;
 	string filename = dataDir + "/DefaultSong.h2song";
@@ -492,27 +368,6 @@ Song* Song::getEmptySong() {
 
 
 
-float Song::getHumanizeTimeValue() {
-	return humanizeTimeValue;
-}
-
-
-
-void Song::setHumanizeTimeValue(float value) {
-	humanizeTimeValue = value;
-}
-
-
-float Song::getHumanizeVelocityValue() {
-	return humanizeVelocityValue;
-}
-
-
-
-void Song::setHumanizeVelocityValue(float value) {
-	humanizeVelocityValue = value;
-}
-
 
 void Song::setSwingFactor( float factor ) {
 	if (factor < 0.0) {
@@ -522,46 +377,32 @@ void Song::setSwingFactor( float factor ) {
 		factor = 1.0;
 	}
 
-	swingFactor = factor;
+	m_fSwingFactor = factor;
 }
 
 
 
-//----------------------------------------------------------------------------
-//	IMPLEMENTATION OF SEQUENCE CLASS
-//----------------------------------------------------------------------------
+//:::::::::::::::::::::::::
 
 
 
-//----------------------------------------------------------------------------
-/**
- * Constructor
- */
-Sequence::Sequence(string name) : Object( "Sequence" )
+Sequence::Sequence() : Object( "Sequence" )
 {
 //	logger.info(this, "INIT " + name);
-	setName( name );
+//	setName( name );
 
 	for (int i = 0; i < MAX_NOTES; i++) {
-		noteList[i] = NULL;
+		m_noteList[i] = NULL;
 	}
 }
 
 
 
-
-
-//----------------------------------------------------------------------------
-/**
- * Destructor
- */
 Sequence::~Sequence(){
 	// delete all notes
 	for( unsigned int i = 0; i < MAX_NOTES; i++ ){
-		if( noteList[i] != NULL ){
-			delete noteList[i];
-			noteList[i] = NULL;
-		}
+		delete m_noteList[i];
+		m_noteList[i] = NULL;
 	}
 
 //	logger.info(this, "DESTROY " + name);
@@ -571,18 +412,17 @@ Sequence::~Sequence(){
 
 
 
-
 Sequence* Sequence::copy() {
-	Sequence *newSequence = new Sequence(this->getName());
+	Sequence *newSequence = new Sequence();
 
 	for (uint nNote = 0; nNote < MAX_NOTES; nNote++) {
-		Note *oldNote = this->noteList[nNote];
+		Note *oldNote = m_noteList[nNote];
 		if (oldNote == NULL) {
-			newSequence->noteList[nNote] = NULL;
+			newSequence->m_noteList[nNote] = NULL;
 		}
 		else {
 			Note *newNote = oldNote->copy();
-			newSequence->noteList[nNote] = newNote;
+			newSequence->m_noteList[nNote] = newNote;
 		}
 	}
 
@@ -591,100 +431,46 @@ Sequence* Sequence::copy() {
 
 
 
+//:::::::::::::::::::::::::::
 
 
 
-
-//----------------------------------------------------------------------------
-//	IMPLEMENTATION OF INSTRUMENT CLASS
-//----------------------------------------------------------------------------
-
-//----------------------------------------------------------------------------
-/**
- * Constructor
- */
-Instrument::Instrument( string id, string name, string author, int type, float volume ) : Object( "Instrument" )
+Instrument::Instrument( string sId, string sName, string sAuthor, float fVolume, bool bMuted, float fPan_L, float fPan_R, string sDrumkitName )
+ : Object( "Instrument" )
+ , m_sId( sId )
+ , m_fVolume( fVolume )
+ , m_sName( sName )
+ , m_sAuthor( sAuthor )
+ , m_bMuted( bMuted )
+ , m_sDrumkitName( sDrumkitName )
+ , m_bActive( true )
 {
+//	infoLog( "INIT @" + toString( (int)this ) );
 
-//	logger.info(this, "INIT " + name);
-	this->id = id;
-	this->name = name;
-	this->author = author;
-	this->volume = volume;
-	sample = NULL;
-	setMuted( false );
+	setPan_L( fPan_L );
+	setPan_R( fPan_R );
 	setPeak_L( 0.0 );
 	setPeak_R( 0.0 );
-	setPan_L( 1.0 );
-	setPan_R( 1.0 );
-	setDrumkitName( "" );
 	for (uint nFX = 0; nFX < MAX_FX; nFX++) {
 		setFXLevel( nFX, 0.0 );
 	}
+
+	for (uint nLayer = 0; nLayer < MAX_LAYERS; nLayer++) {
+		m_layers[ nLayer ] = NULL;
+	}
 }
 
 
 
-
-
-
-//----------------------------------------------------------------------------
-/**
- * Destructor
- */
 Instrument::~Instrument(){
-	if (sample != NULL) {
-		delete sample;
-		sample = NULL;
+//	infoLog( "DESTROY @" + toString( (int)this ) );
+	for (uint nLayer = 0; nLayer < MAX_LAYERS; nLayer++) {
+		delete m_layers[ nLayer ];
 	}
-//	logger.info(this, "DESTROY " + name);
 }
 
 
 
-
-
-
-//----------------------------------------------------------------------------
-/**
- * Load an instrument from file
- */
-Instrument* Instrument::load(string filename) {
-	Logger logger;
-//	logger.log("Instrument::load() loading " + filename);
-
-	Instrument *instr = NULL;
-
-	string id = filename;	// FIXME: per ora l'ID e' il filename, bisogna calcolarlo in maniera relativa
-	string name = "undefined instrument name";
-	string author = "undefined author";
-	uint type = 0;	// not used
-	float volume = 0.8;
-
-	std::ifstream verify(filename.c_str() , std::ios::in | std::ios::binary);
-	if (verify == NULL){
-		logger.log( "Instrument::load() Load Instrument: Data file " + filename + " not found." );
-		return NULL;
-	}
-
-	instr = new Instrument(id, name, author, type, volume);
-
-	Sample *sample = Sample::load(filename);
-	if (sample == NULL) {
-		logger.log( "Instrument::load() Load Instrument: Sample NULL" );
-	}
-	instr->setSample(sample);
-
-	return instr;
-}
-
-
-
-
-
-/**
- *
- */
 void Instrument::setVolume(float volume) {
 	if (volume > 1.0) {
 		volume = 1.0;
@@ -692,27 +478,11 @@ void Instrument::setVolume(float volume) {
 	else if (volume < 0.0) {
 		volume = 0.0;
 	}
-	this->volume = volume;
+	m_fVolume = volume;
 }
 
 
 
-
-
-//----------------------------------------------------------------------------
-/**
- * Save an instrument to file
- */
-void Instrument::save(string filename) {
-	sample->save( filename );
-}
-
-
-
-
-/**
- *
- */
 void Instrument::setPan_L( float val ) {
 	if (val < 0.0) {
 		val = 0.0;
@@ -722,16 +492,11 @@ void Instrument::setPan_L( float val ) {
 		errorLog("setPan_L() val > 1.0");
 		val = 1.0;
 	}
-	pan_L = val;
+	m_fPan_L = val;
 }
 
 
 
-
-
-/**
- *
- */
 void Instrument::setPan_R( float val ) {
 	if (val < 0.0) {
 		val = 0.0;
@@ -741,7 +506,7 @@ void Instrument::setPan_R( float val ) {
 		val = 1.0;
 		errorLog("setPan_R() val > 1.0");
 	}
-	pan_R = val;
+	m_fPan_R = val;
 }
 
 
@@ -762,9 +527,11 @@ void Instrument::setPeak_L( float fPeak )
 		fPeak = 1.0f;
 	}
 
-	this->peak_L = fPeak;
+	m_fPeak_L = fPeak;
 }
 
+
+
 void Instrument::setPeak_R( float fPeak )
 {
 	if (fPeak < 0.0f) {
@@ -781,71 +548,78 @@ void Instrument::setPeak_R( float fPeak )
 		fPeak = 1.0f;
 	}
 
-	this->peak_R = fPeak;
+	m_fPeak_R = fPeak;
 }
 
 
 
-
-
-//----------------------------------------------------------------------------
-//	IMPLEMENTATION OF NOTE CLASS
-//----------------------------------------------------------------------------
-
-/**
- * Constructor
- */
-Note::Note(	unsigned int position,
-			float velocity,
-			float pan_L,
-			float pan_R,
-			float nPitch
-		) : Object( "Note" )
+InstrumentLayer* Instrument::getLayer( int nLayer )
 {
-	//infoLog("INIT");
+	if (nLayer < 0 ) {
+		errorLog( "[getLayer] nLayer < 0 (nLayer=" + toString(nLayer) + ")" );
+		return NULL;
+	}
+	if (nLayer > MAX_LAYERS ) {
+		errorLog( "[getLayer] nLayer > MAX_LAYERS (nLayer=" + toString(nLayer) + ")" );
+		return NULL;
+	}
 
-	this->position = position;
-	this->instrument = NULL;
-	setVelocity( velocity );
-	setPan_L( pan_L );
-	setPan_R( pan_R );
-	setPitch( nPitch );
+	return m_layers[ nLayer ];
+}
 
 
-	samplePosition = 0.0;
-	humanizeDelay = 0;
+
+void Instrument::setLayer( InstrumentLayer* pLayer, uint nLayer )
+{
+	if (nLayer < MAX_LAYERS) {
+		m_layers[ nLayer ] = pLayer;
+	}
+	else {
+		errorLog( "[setLayer] nLayer > MAX_LAYER" );
+	}
 }
 
 
 
 
+//::::::::::::::::::::::::
+
+
+
+Note::Note(	unsigned nPosition,
+			float fVelocity,
+			float fPan_L,
+			float fPan_R,
+			int nLength,
+			float fPitch
+		)
+ : Object( "Note" )
+ , m_fSamplePosition( 0.0 )
+ , m_nPosition( nPosition )
+ , m_fVelocity( fVelocity )
+ , m_fPan_L( fPan_L )
+ , m_fPan_R( fPan_R )
+ , m_nLength( nLength )
+ , m_fPitch( fPitch )
+ , m_pInstrument( NULL )
+ , m_nHumanizeDelay( 0 )
+{
+}
+
 
 
-//----------------------------------------------------------------------------
-/**
- * Destructor
- */
 Note::~Note(){
 	//infoLog("DESTROY");
 }
 
 
 
-
-
-/**
- *
- */
-void Note::setInstrument(Instrument* instrument) {
-	this->instrument = instrument;
+void Note::setInstrument(Instrument* pInstrument) {
+	m_pInstrument = pInstrument;
 }
 
 
 
-
-/**
- *
- */
 void Note::setVelocity( float val ) {
 	if (val < 0.0) {
 		char tmp[100];
@@ -860,15 +634,11 @@ void Note::setVelocity( float val ) {
 		val = 1.0;
 	}
 
-	velocity = val;
+	m_fVelocity = val;
 }
 
 
 
-
-/**
- *
- */
 void Note::setPan_L( float val ) {
 	if (val < 0.0) {
 		char tmp[100];
@@ -883,16 +653,11 @@ void Note::setPan_L( float val ) {
 		val = 1.0;
 	}
 
-	pan_L = val;
+	m_fPan_L = val;
 }
 
 
 
-
-
-/**
- *
- */
 void Note::setPan_R( float val ) {
 	if (val < 0.0) {
 		char tmp[100];
@@ -907,17 +672,13 @@ void Note::setPan_R( float val ) {
 		val = 1.0;
 	}
 
-	pan_R = val;
+	m_fPan_R = val;
 }
 
 
 
-
-/**
- *
- */
 Instrument* Note::getInstrument() {
-	return instrument;
+	return m_pInstrument;
 }
 
 
@@ -928,6 +689,7 @@ Note* Note::copy() {
 		this->getVelocity(),
 		this->getPan_L(),
 		this->getPan_R(),
+		this->getLength(),
 		this->getPitch()
 	);
 	newNote->setInstrument(this->getInstrument());
@@ -936,15 +698,11 @@ Note* Note::copy() {
 }
 
 
-//----------------------------------------------------------------------------
-//	IMPLEMENTATION OF PATTERN CLASS
-//----------------------------------------------------------------------------
+
+//:::::::::::::::::::::
+
 
 
-//----------------------------------------------------------------------------
-/**
- * Constructor
- */
 Pattern::Pattern( string name, uint nSize ) : Object( "Pattern" )
 {
 //	infoLog("init");
@@ -954,59 +712,33 @@ Pattern::Pattern( string name, uint nSize ) : Object( "Pattern" )
 
 
 
-
-//----------------------------------------------------------------------------
-/**
- * Destructor
- */
 Pattern::~Pattern() {
 //	infoLog("destroy");
 
 	// delete all Sequences
-	if (sequenceList != NULL) {
-		delete sequenceList;
-		sequenceList = NULL;
-	}
-
+	delete m_pSequenceList;
 }
 
 
 
-
-
-//----------------------------------------------------------------------------
-/**
- *
- */
-void Pattern::setName(string name) {
-	this->name = name;
+void Pattern::setName(string sName) {
+	m_sName = sName;
 }
 
 
 
-
-
-//----------------------------------------------------------------------------
-/**
- *
- */
 string Pattern::getName() {
-	return name;
+	return m_sName;
 }
 
 
 
-
-
-//----------------------------------------------------------------------------
-/**
- * Return an empty Pattern
- */
+/// Returns an empty Pattern
 Pattern* Pattern::getEmptyPattern()
 {
 	SequenceList *sequenceList = new SequenceList();
-	for (uint i = 0; i < MAX_TRACKS; i++) {
-		Sequence *trk0 = new Sequence("sequence");
+	for (uint i = 0; i < MAX_INSTRUMENTS; i++) {
+		Sequence *trk0 = new Sequence();
 		sequenceList->add(trk0);
 	}
 
@@ -1018,7 +750,6 @@ Pattern* Pattern::getEmptyPattern()
 
 
 
-
 Pattern* Pattern::copy()
 {
 	Pattern *newPat = new Pattern(this->getName());
@@ -1031,60 +762,143 @@ Pattern* Pattern::copy()
 
 
 
+//::::::::::::::::::::
 
 
 
-//////////////////////////
-
-
-
-
-
-/**
- *
- */
-DrumkitInfo::DrumkitInfo() : Object( "DrumkitInfo" )
+DrumkitInfo::DrumkitInfo()
+ : Object( "DrumkitInfo" )
+ , instrumentList( NULL )
 {
-//	infoLog( "init" );
-	instrumentList = NULL;
+//	infoLog( "INIT @" + toString( (int)this ) );
 }
 
 
 
-/**
- *
- */
 DrumkitInfo::~DrumkitInfo()
 {
-//	infoLog( "Destroy" );
-
-	if (instrumentList) {
-		delete instrumentList;
-		instrumentList = NULL;
-	}
-
+//	infoLog( "DESTROY @" + toString( (int)this ) );
+	delete instrumentList;
 }
 
 
-/**
- *
- */
+
 void DrumkitInfo::dump()
 {
-	cout << "Drumkit dump" << endl;
-	cout << "\tName = " << name << endl;
-	cout << "\tAuthor = " << author << endl;
-	cout << "\tInfo = " << info << endl;
+	infoLog( "Drumkit dump" );
+	infoLog( "\t|- Name = " + name );
+	infoLog( "\t|- Author = " + author );
+	infoLog( "\t|- Info = " + info );
 
-	cout << "\tInstrument list" << endl;
-	for ( uint i = 0; i < instrumentList->getSize(); i++) {
-		Instrument *instr = instrumentList->get( i );
-		cout << "\t\t" << i << " - " << instr->getSample()->getFilename() << endl;
+	infoLog( "\t|- Instrument list" );
+	for ( unsigned nInstrument = 0; nInstrument < instrumentList->getSize(); nInstrument++) {
+		Instrument *pInstr = instrumentList->get( nInstrument );
+		infoLog( "\t\t|- (" + toString( nInstrument ) + " of " + toString( instrumentList->getSize() ) + ") Name = " + pInstr->getName() );
+		for ( unsigned nLayer = 0; nLayer < MAX_LAYERS; nLayer++ ) {
+			InstrumentLayer *pLayer = pInstr->getLayer( nLayer );
+			if ( pLayer ) {
+				Sample *pSample = pLayer->getSample();
+				if ( pSample ) {
+					infoLog( "\t\t   |- " + pSample->getFilename() );
+				}
+				else {
+					infoLog( "\t\t   |- NULL sample" );
+				}
+			}
+			else {
+				infoLog( "\t\t   |- NULL Layer" );
+			}
 
+		}
+//		cout << "\t\t" << i << " - " << instr->getSample()->getFilename() << endl;
 	}
-
 }
 
 
 
+//:::::::::::::::::::::
+
+
+
+InstrumentLayer::InstrumentLayer( Sample *pSample )
+ : Object( "InstrumentLayer" )
+ , m_pSample( pSample )
+ , m_fStartVelocity( 0.0 )
+ , m_fEndVelocity( 1.0 )
+ , m_fPitch( 0.0 )
+ , m_fGain( 1.0 )
+{
+	//infoLog( "INIT" );
+}
+
+
+
+InstrumentLayer::~InstrumentLayer()
+{
+	delete m_pSample;
+	//infoLog( "DESTROY" );
+}
+
+
+
+void InstrumentLayer::setSample( Sample *pSample )
+{
+//	infoLog( "[setSample]" );
+	m_pSample = pSample;
+}
+
+
+
+void InstrumentLayer::setStartVelocity( float fVel )
+{
+//	infoLog( "[setStartVelocity] " + toString( fVel ) );
+
+	if (fVel > 1.0) {
+		fVel = 1.0;
+	}
+	else if (fVel < 0.0) {
+		fVel = 0.0;
+	}
+
+	m_fStartVelocity = fVel;
+}
+
+
+
+void InstrumentLayer::setEndVelocity( float fVel ) {
+//	infoLog( "[setEndVelocity] " + toString( fVel ) );
+
+	if (fVel > 1.0) {
+		fVel = 1.0;
+	}
+	else if (fVel < 0.0) {
+		fVel = 0.0;
+	}
+
+	m_fEndVelocity = fVel;
+}
+
+
+
+void InstrumentLayer::setGain( float fGain )
+{
+	//infoLog( "[setGain] " + toString( fGain ) );
+//	if (fGain > 1.0) {
+//		fGain = 1.0;
+//	}
+//	else if (fGain < 0.0) {
+	if (fGain < 0.0) {
+		fGain = 0.0;
+	}
+	m_fGain = fGain;
+}
+
+
+
+void InstrumentLayer::setPitch( float fPitch )
+{
+//	infoLog( "[setPitch] " + toString( fPitch ) );
+	m_fPitch = fPitch;
+}
+
 
